-- This is an SQL code of the Cash Flow Summary statement.
-- You may edit the code and insert it into the QueryList table in the payments-configuration-en.xlsx workbook.
-- The code used two parameters: @Year and @DataLanguage.

SELECT
    p.RowNumber AS N
    , MAX(p.[Level]) AS [Level]
    , p.ItemType
    , p.ItemName
    , p.CompanyName
    , COALESCE(MAX(t.TRANSLATED_NAME), MAX(p.Name)) AS Name
    , SUM(p.Total) AS Total
    , SUM(p.Jan) AS Jan
    , SUM(p.Feb) AS Feb
    , SUM(p.Mar) AS Mar
    , SUM(p.Apr) AS Apr
    , SUM(p.May) AS May
    , SUM(p.Jun) AS Jun
    , SUM(p.Jul) AS Jul
    , SUM(p.Aug) AS Aug
    , SUM(p.Sep) AS Sep
    , SUM(p.Oct) AS Oct
    , SUM(p.Nov) AS Nov
    , SUM(p.[Dec]) AS [Dec]
FROM
    (
    -- Total Items
    SELECT
        p.RowNumber
        , 1 AS [Level]
        , p.ItemType
        , p.ItemName
        , NULL AS CompanyName
        , p.ItemName AS [Name]
        , p.Period
        , SUM(p.[Sum]) AS [Total]
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            CAST(CASE WHEN p.[Sum]<0 THEN 2 ELSE 1 END AS int) AS RowNumber
            , CAST(CASE WHEN p.[Sum]<0 THEN N'Expences' ELSE N'Income' END AS NVARCHAR(50)) AS ItemType
            , p.ItemName
            , DATEPART(MONTH, p.[Date]) AS Period
            , p.[Sum]
        FROM
            Payments p
        WHERE
            p.ItemName IS NOT NULL
            AND DATEPART(YEAR, p.[Date]) = @Year
        ) p
    GROUP BY
        p.Period,
        p.RowNumber,
        p.ItemType,
        p.ItemName

    -- Total Income/Expenses
    UNION ALL
    SELECT
        p.RowNumber
        , 2 AS [Level]
        , p.ItemType
        , NULL AS ItemName
        , NULL AS CompanyName
        , N'Total ' + p.ItemType AS Name
        , p.Period
        , SUM(p.[Sum]) AS [Total]
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            CAST(CASE WHEN p.[Sum]<0 THEN 2 ELSE 1 END AS int) AS RowNumber
            , CAST(CASE WHEN p.[Sum]<0 THEN N'Expences' ELSE N'Income' END AS NVARCHAR(50)) AS ItemType
            , DATEPART(MONTH, p.[Date]) AS Period
            , p.[Sum]
        FROM
            Payments p
        WHERE
            DATEPART(YEAR, p.[Date]) = @Year
        ) p
    GROUP BY
        p.Period,
        p.RowNumber,
        p.ItemType

    -- Net Chanhge
    UNION ALL
    SELECT
        3 AS RowNumber
        , 2 AS [Level]
        , N'Net Change' AS ItemType
        , NULL AS ItemName
        , NULL AS CompanyName
        , N'Net Change' AS Name
        , p.Period
        , SUM(p.[Sum]) AS [Total]
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            DATEPART(MONTH, p.[Date]) AS Period
            , p.[Sum]
        FROM
            Payments p
        WHERE
            DATEPART(YEAR, p.[Date]) = @Year
        ) p
    GROUP BY
        p.Period

    -- Opening balance
    UNION ALL
    SELECT
        0 AS RowNumber
        , 3 AS [Level]
        , N'Opening Balance' AS ItemType
        , NULL AS ItemName
        , NULL AS CompanyName
        , N'Opening Balance' AS Name
        , p.Period
        , NULL AS Total
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            DATEPART(MONTH, d.[Date]) AS Period
            , SUM(p.[Sum]) AS [Sum]
        FROM
            Payments p
            CROSS JOIN (
                SELECT DATEADD(YEAR, @Year - 1900, 0) AS [Date]
                UNION SELECT DATEADD(MONTH, 1, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 2, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 3, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 4, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 5, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 6, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 7, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 8, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 9, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 10, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 11, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
            ) d
        WHERE
            p.[Date] < d.[Date]
        GROUP BY
            d.[Date]
        ) p
    GROUP BY
        p.Period

    -- Closing balance
    UNION ALL
    SELECT
        4 AS RowNumber
        , 3 AS [Level]
        , N'Closing Balance' AS ItemType
        , NULL AS ItemName
        , NULL AS CompanyName
        , N'Closing Balance' AS Name
        , p.Period
        , NULL AS Total
        , CASE p.Period WHEN  2 THEN SUM(p.[Sum]) ELSE NULL END AS Jan
        , CASE p.Period WHEN  3 THEN SUM(p.[Sum]) ELSE NULL END AS Feb
        , CASE p.Period WHEN  4 THEN SUM(p.[Sum]) ELSE NULL END AS Mar
        , CASE p.Period WHEN  5 THEN SUM(p.[Sum]) ELSE NULL END AS Apr
        , CASE p.Period WHEN  6 THEN SUM(p.[Sum]) ELSE NULL END AS May
        , CASE p.Period WHEN  7 THEN SUM(p.[Sum]) ELSE NULL END AS Jun
        , CASE p.Period WHEN  8 THEN SUM(p.[Sum]) ELSE NULL END AS Jul
        , CASE p.Period WHEN  9 THEN SUM(p.[Sum]) ELSE NULL END AS Aug
        , CASE p.Period WHEN 10 THEN SUM(p.[Sum]) ELSE NULL END AS Sep
        , CASE p.Period WHEN 11 THEN SUM(p.[Sum]) ELSE NULL END AS Oct
        , CASE p.Period WHEN 12 THEN SUM(p.[Sum]) ELSE NULL END AS Nov
        , CASE p.Period WHEN  1 THEN SUM(p.[Sum]) ELSE NULL END AS [Dec]
    FROM
        (
        SELECT
            DATEPART(MONTH, d.[Date]) AS Period
            , SUM(p.[Sum]) AS [Sum]
        FROM
            Payments p
            CROSS JOIN (
                SELECT DATEADD(MONTH, 1, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 2, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 3, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 4, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 5, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 6, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 7, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 8, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 9, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 10, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 11, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
                UNION SELECT DATEADD(MONTH, 12, DATEADD(YEAR, @Year - 1900, 0)) AS [Date]
            ) d
        WHERE
            p.[Date] < d.[Date]
        GROUP BY
            d.[Date]
        ) p
    GROUP BY
        p.Period
    ) p
    LEFT OUTER JOIN ColumnTranslation t ON t.TABLE_NAME = 'ItemName' AND t.COLUMN_NAME = p.Name
        AND UPPER(t.LANGUAGE_NAME) = UPPER(@DataLanguage)
GROUP BY
    p.RowNumber,
    p.ItemType,
    p.ItemName,
    p.CompanyName
ORDER BY
    p.RowNumber,
    p.ItemType,
    p.ItemName,
    p.CompanyName