﻿SELECT
    c.ID
    , NULL AS ContactStatus
    , CASE WHEN dn.ID IS NULL THEN NULL ELSE DoubleNameCount END AS IsDoubleName
    , c.ContactCategory
    , n.FirstName
    , n.LastName
    , e.Email
    , m.Mobile
    , p.Phone
    , r.Country
    , LOWER(SUBSTRING(e.email, CHARINDEX('@', e.email) + 1, 255)) AS Domain
    , w.Website
    , y.Company
    , i.JobTitle
    , l2.SourceHeadline AS LinkedInHeadline
    , l2.SourceIndustry AS Industry
    , l2.SourceLocationName AS LocationName
    , l2.SourceProfileUrl AS LinkedInProfileUrl
    , g2.SourceProfileUrl AS GooglePlusProfileUrl
    , c.String1
    , c.String2
    , c.String3
    , c.Number1
    , c.Number2
    , c.Number3
FROM
    (
        SELECT
            c.ID
            , l2.[Source] AS lSource
            , MIN(l2.SourceID) AS lSourceID
            , g2.[Source] AS gSource
            , MIN(g2.SourceID) AS gSourceID
        FROM
            Contacts c
            LEFT OUTER JOIN SourceContactID l1 ON l1.ContactID = c.ID AND l1.[Source] = 'LinkedIn'
            LEFT OUTER JOIN SourceContacts l2 ON l2.[Source] = l1.[Source] AND l2.SourceID = l1.SourceID
            LEFT OUTER JOIN SourceContactID g1 ON g1.ContactID = c.ID AND g1.[Source] = 'GoogleCSV'
            LEFT OUTER JOIN SourceContacts g2 ON g2.[Source] = g1.[Source] AND g2.SourceID = g1.SourceID
        GROUP BY
            c.ID
            , l2.[Source]
            , g2.[Source]
    ) t
    INNER JOIN Contacts c ON c.ID = t.ID

    LEFT OUTER JOIN ContactNames    n ON n.ID = c.ID
    LEFT OUTER JOIN ContactEmail    e ON e.ID = c.ID
    LEFT OUTER JOIN ContactMobile   m ON m.ID = c.ID
    LEFT OUTER JOIN ContactPhone    p ON p.ID = c.ID
    LEFT OUTER JOIN ContactCountry  r ON r.ID = c.ID
    LEFT OUTER JOIN ContactWebsite  w ON w.ID = c.ID
    LEFT OUTER JOIN ContactCompany  y ON y.ID = c.ID
    LEFT OUTER JOIN ContactJobTitle i ON i.ID = c.ID

    LEFT OUTER JOIN SourceContacts l2 ON l2.[Source] = t.lSource AND l2.SourceID = t.lSourceID
    LEFT OUTER JOIN SourceContacts g2 ON g2.[Source] = t.gSource AND g2.SourceID = t.gSourceID
    
    LEFT OUTER JOIN (
        SELECT TOP 1000000
            c.ID
            , t.DoubleNameCount
        FROM
            (
                SELECT
                    c.FirstName
                    , c.LastName
                    , COUNT(*) AS DoubleNameCount
                FROM
                    ContactNames c
                WHERE
                    c.FirstName IS NOT NULL
                GROUP BY
                    c.FirstName
                    , c.LastName
                HAVING
                    COUNT(*) > 1
            ) t
            LEFT OUTER JOIN ContactNames c ON t.FirstName = c.FirstName AND t.LastName = c.LastName
        ORDER BY
            c.ID
    ) dn ON dn.ID = c.ID

WHERE
    r.Country = @CountryName