﻿SELECT
    c.ID
    , NULL AS ContactStatus
    , CASE WHEN dn.ID IS NULL THEN NULL ELSE DoubleNameCount END AS IsDoubleName
    , c.ContactCategory
    , CASE WHEN n.ID IS NOT NULL THEN n.FirstName ELSE t.FirstName END AS FirstName
    , CASE WHEN n.ID IS NOT NULL THEN n.LastName ELSE t.LastName END AS LastName
    , CASE WHEN e.ID IS NOT NULL THEN e.Email ELSE t.Email END AS Email
    , CASE WHEN m.ID IS NOT NULL THEN m.Mobile ELSE t.Mobile END AS Mobile
    , CASE WHEN p.ID IS NOT NULL THEN p.Phone ELSE t.Phone END AS Phone
    , COALESCE(r.Country, rs.CountryName) AS Country
    , LOWER(SUBSTRING(e.email, CHARINDEX('@', e.email) + 1, 255)) AS Domain
    , CASE WHEN w.ID IS NOT NULL THEN w.Website WHEN ws.Domain IS NOT NULL THEN ws.Website WHEN e.Email IS NULL THEN NULL ELSE 'www.' + LOWER(SUBSTRING(e.email, CHARINDEX('@', e.email) + 1, 255)) END AS Website
    , CASE WHEN y.ID IS NOT NULL THEN y.Company ELSE t.Company END AS Company
    , CASE WHEN i.ID IS NOT NULL THEN i.JobTitle ELSE t.JobTitle END AS JobTitle
    , l2.SourceHeadline AS LinkedInHeadline
    , l2.SourceIndustry AS Industry
    , l2.SourceLocationName AS LocationName
    , l2.SourceProfileUrl AS LinkedInProfileUrl
    , g2.SourceProfileUrl AS GooglePlusProfileUrl
    , c.String1
    , c.String2
    , c.String3
    , c.Number1
    , c.Number2
    , c.Number3
FROM
    (
        SELECT
            c.ID
            , l2.[Source] AS lSource
            , MIN(l2.SourceID) AS lSourceID
            , g2.[Source] AS gSource
            , MIN(g2.SourceID) AS gSourceID
            , MIN(s.SourceFirstName) AS FirstName
            , MIN(s.SourceLastName) AS LastName
            , MIN(s.SourceEmail) AS Email
            , MIN(s.SourceMobile) AS Mobile
            , MIN(s.SourcePhone) AS Phone
            , MIN(s.SourceCompany) AS Company
            , MIN(s.SourceJobTitle) AS JobTitle
            , MIN(s.SourceCountryCode) AS CountryCode
        FROM
            Contacts c
            LEFT OUTER JOIN SourceContactID l1 ON l1.ContactID = c.ID AND l1.[Source] = 'LinkedIn'
            LEFT OUTER JOIN SourceContacts l2 ON l2.[Source] = l1.[Source] AND l2.SourceID = l1.SourceID
            LEFT OUTER JOIN SourceContactID g1 ON g1.ContactID = c.ID AND g1.[Source] = 'GoogleCSV'
            LEFT OUTER JOIN SourceContacts g2 ON g2.[Source] = g1.[Source] AND g2.SourceID = g1.SourceID
            LEFT OUTER JOIN SourceContactID d ON d.ContactID = c.ID
            LEFT OUTER JOIN SourceContacts s ON s.[Source] = d.[Source] AND s.SourceID = d.SourceID
        GROUP BY
            c.ID
            , l2.[Source]
            , g2.[Source]
    ) t
    INNER JOIN Contacts c ON c.ID = t.ID

    LEFT OUTER JOIN ContactNames    n ON n.ID = c.ID
    LEFT OUTER JOIN ContactEmail    e ON e.ID = c.ID
    LEFT OUTER JOIN ContactMobile   m ON m.ID = c.ID
    LEFT OUTER JOIN ContactPhone    p ON p.ID = c.ID
    LEFT OUTER JOIN ContactCountry  r ON r.ID = c.ID
    LEFT OUTER JOIN ContactWebsite  w ON w.ID = c.ID
    LEFT OUTER JOIN ContactCompany  y ON y.ID = c.ID
    LEFT OUTER JOIN ContactJobTitle i ON i.ID = c.ID

    LEFT OUTER JOIN Websites ws ON ws.Domain = LOWER(SUBSTRING(e.email, CHARINDEX('@', e.email) + 1, 255))
    LEFT OUTER JOIN Countries rs ON rs.CountryCode = t.CountryCode

    LEFT OUTER JOIN SourceContacts l2 ON l2.[Source] = t.lSource AND l2.SourceID = t.lSourceID
    LEFT OUTER JOIN SourceContacts g2 ON g2.[Source] = t.gSource AND g2.SourceID = t.gSourceID
    
    LEFT OUTER JOIN (
        SELECT TOP 1000000
            c.ID
            , t.DoubleNameCount
        FROM
            (
                SELECT
                    c.FirstName
                    , c.LastName
                    , COUNT(*) AS DoubleNameCount
                FROM
                    ContactNames c
                WHERE
                    c.FirstName IS NOT NULL
                GROUP BY
                    c.FirstName
                    , c.LastName
                HAVING
                    COUNT(*) > 1
            ) t
            LEFT OUTER JOIN ContactNames c ON t.FirstName = c.FirstName AND t.LastName = c.LastName
        ORDER BY
            c.ID
    ) dn ON dn.ID = c.ID
