-- Social Contacts Application
-- July 15, 2014

-- This SQL code must be executed after SaveToDB Framework installation!

--DROP TABLE Countries;
CREATE TABLE [Countries](
    [CountryCode] [nchar](2) NOT NULL,
    [CountryName] [nvarchar](255),
    [Checked] [tinyint],
    CONSTRAINT [PK_Countries] PRIMARY KEY
(
    [CountryCode]
)
);
GO

--DROP INDEX [Countries].[IX_Countries_CountryName];
CREATE UNIQUE INDEX [IX_Countries_CountryName]
    ON [Countries] (
    [CountryName]
);
GO

--DROP TABLE Websites;
CREATE TABLE [Websites](
    [Domain] [nvarchar](255) NOT NULL,
    [Website] [nvarchar](255),
    [Comment] [nvarchar](255),
    [Checked] [tinyint],
    CONSTRAINT [PK_ChangeWebsites] PRIMARY KEY
(
    [Domain]
)
);
GO

--DROP TABLE SourceContacts;
CREATE TABLE [SourceContacts](
    [Source] [nvarchar](50) NOT NULL,
    [SourceID] [nvarchar](50) NOT NULL,
    [MergeDate] [datetime],
    [IsJunk] [tinyint],
    [SourceFirstName] [nvarchar](255),
    [SourceLastName] [nvarchar](255),
    [SourceEmail] [nvarchar](255),
    [SourceSecondaryEmail] [nvarchar](255),
    [SourceMobile] [nvarchar](255),
    [SourcePhone] [nvarchar](255),
    [SourceCompany] [nvarchar](255),
    [SourceJobTitle] [nvarchar](255),
    [SourceHeadline] [nvarchar](255),
    [SourceIndustry] [nvarchar](255),
    [SourceLocationName] [nvarchar](255),
    [SourceCountryCode] [nchar](2),
    [SourceProfileUrl] [nvarchar](255),
    CONSTRAINT [PK_SourceContacts] PRIMARY KEY
(
    [Source],
    [SourceID]
)
);
GO

--DROP INDEX [SourceContacts].[IX_SourceContacts_Email]
CREATE INDEX [IX_SourceContacts_Email]
    ON [SourceContacts] (
    [SourceEmail]
);
GO

--DROP INDEX [SourceContacts].[IX_SourceContacts_SecondaryEmail]
CREATE INDEX [IX_SourceContacts_SecondaryEmail]
    ON [SourceContacts] (
    [SourceSecondaryEmail]
);
GO

--DROP INDEX [SourceContacts].[IX_SourceContacts_Source_FirstName_LastName]
CREATE INDEX [IX_SourceContacts_Source_FirstName_LastName]
    ON [SourceContacts] (
    [Source], 
    [SourceFirstName], 
    [SourceLastName]
);
GO

--DROP TABLE Contacts;
CREATE TABLE [Contacts] (
    [ID] int NOT NULL IDENTITY,
    [SourceID] [nvarchar](50) NOT NULL,
    [ContactCategory] nvarchar(255),
    [String1] nvarchar(255),
    [String2] nvarchar(255),
    [String3] nvarchar(255),
    [Number1] float,
    [Number2] float,
    [Number3] float,
    CONSTRAINT [PK_Contacts] PRIMARY KEY
(
    [ID]
)
);
GO

--DROP INDEX [Contacts].[IX_Contacts_SourceID]
CREATE UNIQUE INDEX [IX_Contacts_SourceID]
    ON [Contacts] (
    [SourceID]
);
GO

--DROP TABLE [SourceContactID];
CREATE TABLE [SourceContactID] (
    [Source] nvarchar(50) NOT NULL, 
    [SourceID] nvarchar(50) NOT NULL, 
    [ContactID] int NOT NULL,
    CONSTRAINT [PK_SourceContactID] PRIMARY KEY
(
    [Source],
    [SourceID]
),
    CONSTRAINT [FK_SourceContactID_SourceContacts] FOREIGN KEY
(
    [Source],
    [SourceID]
)
    REFERENCES [SourceContacts] ([Source], [SourceID])
        ON UPDATE CASCADE ON DELETE CASCADE,
    CONSTRAINT [FK_SourceContactID_ContactID] FOREIGN KEY
(
    [ContactID]
)
    REFERENCES [Contacts] ([ID])
        ON UPDATE CASCADE ON DELETE CASCADE
);
GO

-- DROP INDEX [SourceContactID].[IX_SourceContactID_ContactID]
CREATE INDEX [IX_SourceContactID_ContactID]
    ON [SourceContactID] (
    [ContactID]
);
GO

--DROP TABLE ContactNames;
CREATE TABLE [ContactNames] (
    [ID] int NOT NULL,
    [FirstName] nvarchar(255),
    [LastName] nvarchar(255),
    CONSTRAINT [PK_ContactNames] PRIMARY KEY
(
    [ID]
),
    CONSTRAINT [FK_ContactNames_ID] FOREIGN KEY
(
    [ID]
)
    REFERENCES [Contacts] ([ID])
        ON UPDATE CASCADE ON DELETE CASCADE
);
GO

--DROP INDEX [ContactNames].[IX_ContactNames_FirstName_LastName];
CREATE INDEX [IX_ContactNames_FirstName_LastName]
    ON [ContactNames] (
    [FirstName]
    , [LastName]
);
GO

--DROP TABLE ContactCompany;
CREATE TABLE [ContactCompany] (
    [ID] int NOT NULL,
    [Company] nvarchar(255),
    CONSTRAINT [PK_ContactCompany] PRIMARY KEY
(
    [ID]
),
    CONSTRAINT [FK_ContactCompany_ID] FOREIGN KEY
(
    [ID]
)
    REFERENCES [Contacts] ([ID])
        ON UPDATE CASCADE ON DELETE CASCADE
);
GO

--DROP TABLE ContactCountry;
CREATE TABLE [ContactCountry] (
    [ID] int NOT NULL,
    [Country] nvarchar(255),
    CONSTRAINT [PK_ContactCountry] PRIMARY KEY
(
    [ID]
),
    CONSTRAINT [FK_ContactCountry_ID] FOREIGN KEY
(
    [ID]
)
    REFERENCES [Contacts] ([ID])
        ON UPDATE CASCADE ON DELETE CASCADE
);
GO

--DROP TABLE ContactEmail;
CREATE TABLE [ContactEmail] (
    [ID] int NOT NULL,
    [Email] nvarchar(255),
    CONSTRAINT [PK_ContactEmail] PRIMARY KEY
(
    [ID]
),
    CONSTRAINT [FK_ContactEmail_ID] FOREIGN KEY
(
    [ID]
)
    REFERENCES [Contacts] ([ID])
        ON UPDATE CASCADE ON DELETE CASCADE
);
GO

--DROP TABLE ContactMobile;
CREATE TABLE [ContactMobile] (
    [ID] int NOT NULL,
    [Mobile] nvarchar(255),
    CONSTRAINT [PK_ContactMobile] PRIMARY KEY
(
    [ID]
),
    CONSTRAINT [FK_ContactMobile_ID] FOREIGN KEY
(
    [ID]
)
    REFERENCES [Contacts] ([ID])
        ON UPDATE CASCADE ON DELETE CASCADE
);
GO

--DROP TABLE ContactPhone;
CREATE TABLE [ContactPhone] (
    [ID] int NOT NULL,
    [Phone] nvarchar(255),
    CONSTRAINT [PK_ContactPhone] PRIMARY KEY
(
    [ID]
),
    CONSTRAINT [FK_ContactPhone_ID] FOREIGN KEY
(
    [ID]
)
    REFERENCES [Contacts] ([ID])
        ON UPDATE CASCADE ON DELETE CASCADE
);
GO

--DROP TABLE ContactJobTitle;
CREATE TABLE [ContactJobTitle] (
    [ID] int NOT NULL,
    [JobTitle] nvarchar(255),
    CONSTRAINT [PK_ContactJobTitle] PRIMARY KEY
(
    [ID]
),
    CONSTRAINT [FK_ContactJobTitle_ID] FOREIGN KEY
(
    [ID]
)
    REFERENCES [Contacts] ([ID])
        ON UPDATE CASCADE ON DELETE CASCADE
);
GO

--DROP TABLE ContactWebsite;
CREATE TABLE [ContactWebsite] (
    [ID] int NOT NULL,
    [Website] nvarchar(255),
    CONSTRAINT [PK_ContactWebsite] PRIMARY KEY
(
    [ID]
),
    CONSTRAINT [FK_ContactWebsite_ID] FOREIGN KEY
(
    [ID]
)
    REFERENCES [Contacts] ([ID])
        ON UPDATE CASCADE ON DELETE CASCADE
);
GO
-- print Tables have been created

INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('ae','United Arab Emirates',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('af','Afghanistan',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('ar','Argentina',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('at','Austria',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('au','Australia',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('bd','Bangladesh',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('be','Belgium',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('bg','Bulgaria',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('bh','Bahrain',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('br','Brazil',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('bs','Bahamas',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('by','Belarus',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('ca','Canada',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('ch','Switzerland',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('cl','Chile',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('cn','China',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('cy','Cyprus',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('cz','Czech Republic',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('de','Germany',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('dk','Denmark',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('dz','Algeria',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('eg','Egypt',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('es','Spain',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('et','Ethiopia',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('fi','Finland',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('fr','France',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('gb','United Kingdom',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('gh','Ghana',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('gr','Greece',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('hk','Hong Kong',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('hr','Croatia',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('hu','Hungary',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('id','Indonesia',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('ie','Ireland',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('il','Israel',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('in','India',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('ir','Iran',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('it','Italy',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('jm','Jamaica',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('jp','Japan',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('ke','Kenya',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('kh','Cambodia',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('kr','Korea',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('kz','Kazakhstan',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('lb','Lebanon',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('li','Liechtenstein',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('lk','Sri Lanka',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('lt','Lithuania',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('lu','Luxembourg',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('ma','Morocco',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('mm','Myanmar',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('mx','Mexico',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('my','Malaysia',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('nc','New Caledonia',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('ng','Nigeria',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('ni','Nicaragua',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('nl','Netherlands',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('no','Norway',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('np','Nepal',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('nz','New Zealand',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('oo','Other',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('pa','Panama',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('ph','Philippines',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('pk','Pakistan',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('pl','Poland',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('pt','Portugal',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('qa','Qatar',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('ro','Romania',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('ru','Russian Federation',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('sa','Saudi Arabia',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('sc','Seychelles',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('sd','Sudan',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('se','Sweden',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('sg','Singapore',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('si','Slovenia',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('sk','Slovak Republic',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('sy','Syria',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('th','Thailand',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('tr','Turkey',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('tt','Trinidad and Tobago',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('tz','Tanzania',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('ua','Ukraine',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('ug','Uganda',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('us','United States',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('vn','Vietnam',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('za','South Africa',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('zm','Zambia',1);
GO
INSERT INTO [Countries] ([CountryCode],[CountryName],[Checked]) VALUES ('kw','Kuwait',NULL);
GO
-- print Countries have been inserted

INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('126.com',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('aol.com',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('att.net',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('bk.ru',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('btinternet.com',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('comcast.net',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('cox.net',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('cs.com',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('d.com',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('europe.com',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('free.fr',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('gmail.com',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('gmx.de',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('gmx.net',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('googlemail.com',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('hotbox.ru',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('hotmail.co.uk',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('hotmail.com',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('inbox.ru',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('land.ru',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('libero.it',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('list.ru',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('live.cn',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('live.co.uk',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('live.com',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('live.com.au',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('live.de',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('live.it',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('mac.com',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('mail.ru',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('me.com',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('msn.com',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('nm.ru',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('oncallmail.com',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('outlook.com',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('pochta.ru',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('rambler.ru',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('seznam.cz',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('sympatico.ca',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('teleworm.us',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('tiscali.it',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('tut.by',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('ukr.net',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('uol.com.br',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('verizon.net',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('virgin.net',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('y7mail.com',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('ya.ru',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('yahoo.ca',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('yahoo.co.in',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('yahoo.co.jp',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('yahoo.co.uk',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('yahoo.com',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('yahoo.com.au',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('yahoo.com.br',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('yahoo.com.cn',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('yahoo.com.vn',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('yahoo.de',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('yahoo.es',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('yahoo.fr',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('yahoo.ie',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('yahoo.in',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('yahoo.nl',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('yahoo.no',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('yahoo.pt',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('yandex.ru',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('ymail.com',NULL,'Public emails',1);
GO
INSERT INTO [Websites] ([Domain],[Website],[Comment],[Checked]) VALUES ('yopmail.com',NULL,'Public emails',1);
GO
-- print Websites have been inserted

INSERT INTO [QueryList] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_TYPE],[INSERT_PROCEDURE],[UPDATE_PROCEDURE],[DELETE_PROCEDURE]) VALUES ('{FileName=google.csv};CodePage={CodePage=1251}','Google - CSV','TEXT','SourceContacts','SourceContacts','SourceContacts');
GO
INSERT INTO [QueryList] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_TYPE],[INSERT_PROCEDURE],[UPDATE_PROCEDURE],[DELETE_PROCEDURE]) VALUES ('{FileName=linkedin_connections_export_microsoft_outlook.csv};CodePage={CodePage=1251}','LinkedIn - CSV','TEXT','SourceContacts','SourceContacts','SourceContacts');
GO
INSERT INTO [QueryList] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_TYPE],[INSERT_PROCEDURE],[UPDATE_PROCEDURE],[DELETE_PROCEDURE]) VALUES ('{FileName=outlook.csv};CodePage={CodePage=1251}','Outlook - CSV','TEXT','SourceContacts','SourceContacts','SourceContacts');
GO
INSERT INTO [QueryList] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_TYPE],[INSERT_PROCEDURE],[UPDATE_PROCEDURE],[DELETE_PROCEDURE]) VALUES ('{FileName=YahooAddressBook.htm};CodePage={CodePage=65001}','Yahoo! - HTM','TEXT','SourceContacts','SourceContacts','SourceContacts');
GO
INSERT INTO [QueryList] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_TYPE],[INSERT_PROCEDURE],[UPDATE_PROCEDURE],[DELETE_PROCEDURE]) VALUES ('http://api.linkedin.com/v1/people/~/connections','LinkedIn - API','HTTP','SourceContacts','SourceContacts','SourceContacts');
GO
INSERT INTO [QueryList] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_TYPE],[INSERT_PROCEDURE],[UPDATE_PROCEDURE],[DELETE_PROCEDURE]) VALUES ('http://social.yahooapis.com/v1/user/me/contacts','Yahoo! - API','HTTP','SourceContacts','SourceContacts','SourceContacts');
GO
INSERT INTO [QueryList] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_TYPE],[INSERT_PROCEDURE],[UPDATE_PROCEDURE],[DELETE_PROCEDURE]) VALUES ('http://www.google.com/m8/feeds/contacts/default/base?alt=json{}','Google - API','HTTP','SourceContacts','SourceContacts','SourceContacts');
GO
INSERT INTO [QueryList] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_TYPE],[INSERT_PROCEDURE],[UPDATE_PROCEDURE],[DELETE_PROCEDURE]) VALUES ('SELECT
    c.ID
    , NULL AS ContactStatus
    , CASE WHEN dn.ID IS NULL THEN NULL ELSE DoubleNameCount END AS IsDoubleName
    , c.ContactCategory
    , CASE WHEN n.ID IS NOT NULL THEN n.FirstName ELSE t.FirstName END AS FirstName
    , CASE WHEN n.ID IS NOT NULL THEN n.LastName ELSE t.LastName END AS LastName
    , CASE WHEN e.ID IS NOT NULL THEN e.Email ELSE t.Email END AS Email
    , CASE WHEN m.ID IS NOT NULL THEN m.Mobile ELSE t.Mobile END AS Mobile
    , CASE WHEN p.ID IS NOT NULL THEN p.Phone ELSE t.Phone END AS Phone
    , COALESCE(r.Country, rs.CountryName) AS Country
    , LOWER(SUBSTRING(e.email, CHARINDEX(''@'', e.email) + 1, 255)) AS Domain
    , CASE WHEN w.ID IS NOT NULL THEN w.Website WHEN ws.Domain IS NOT NULL THEN ws.Website WHEN e.Email IS NULL THEN NULL ELSE ''www.'' + LOWER(SUBSTRING(e.email, CHARINDEX(''@'', e.email) + 1, 255)) END AS Website
    , CASE WHEN y.ID IS NOT NULL THEN y.Company ELSE t.Company END AS Company
    , CASE WHEN i.ID IS NOT NULL THEN i.JobTitle ELSE t.JobTitle END AS JobTitle
    , l2.SourceHeadline AS LinkedInHeadline
    , l2.SourceIndustry AS Industry
    , l2.SourceLocationName AS LocationName
    , l2.SourceProfileUrl AS LinkedInProfileUrl
    , g2.SourceProfileUrl AS GooglePlusProfileUrl
    , c.String1
    , c.String2
    , c.String3
    , c.Number1
    , c.Number2
    , c.Number3
FROM
 (
  SELECT
   c.ID
   , l2.[Source] AS lSource
   , MIN(l2.SourceID) AS lSourceID
   , g2.[Source] AS gSource
   , MIN(g2.SourceID) AS gSourceID
            , MIN(s.SourceFirstName) AS FirstName
            , MIN(s.SourceLastName) AS LastName
            , MIN(s.SourceEmail) AS Email
            , MIN(s.SourceMobile) AS Mobile
            , MIN(s.SourcePhone) AS Phone
            , MIN(s.SourceCompany) AS Company
            , MIN(s.SourceJobTitle) AS JobTitle
            , MIN(s.SourceCountryCode) AS CountryCode
  FROM
   Contacts c
   LEFT OUTER JOIN SourceContactID l1 ON l1.ContactID = c.ID AND l1.[Source] = ''LinkedIn''
   LEFT OUTER JOIN SourceContacts l2 ON l2.[Source] = l1.[Source] AND l2.SourceID = l1.SourceID
   LEFT OUTER JOIN SourceContactID g1 ON g1.ContactID = c.ID AND g1.[Source] = ''GoogleCSV''
   LEFT OUTER JOIN SourceContacts g2 ON g2.[Source] = g1.[Source] AND g2.SourceID = g1.SourceID
            LEFT OUTER JOIN SourceContactID d ON d.ContactID = c.ID
            LEFT OUTER JOIN SourceContacts s ON s.[Source] = d.[Source] AND s.SourceID = d.SourceID
  GROUP BY
   c.ID
   , l2.[Source]
   , g2.[Source]
 ) t
 INNER JOIN Contacts c ON c.ID = t.ID

 LEFT OUTER JOIN ContactNames    n ON n.ID = c.ID
 LEFT OUTER JOIN ContactEmail    e ON e.ID = c.ID
 LEFT OUTER JOIN ContactMobile   m ON m.ID = c.ID
 LEFT OUTER JOIN ContactPhone    p ON p.ID = c.ID
 LEFT OUTER JOIN ContactCountry  r ON r.ID = c.ID
 LEFT OUTER JOIN ContactWebsite  w ON w.ID = c.ID
 LEFT OUTER JOIN ContactCompany  y ON y.ID = c.ID
 LEFT OUTER JOIN ContactJobTitle    i ON i.ID = c.ID

    LEFT OUTER JOIN Websites ws ON ws.Domain = LOWER(SUBSTRING(e.email, CHARINDEX(''@'', e.email) + 1, 255))
    LEFT OUTER JOIN Countries rs ON rs.CountryCode = t.CountryCode

 LEFT OUTER JOIN SourceContacts l2 ON l2.[Source] = t.lSource AND l2.SourceID = t.lSourceID
 LEFT OUTER JOIN SourceContacts g2 ON g2.[Source] = t.gSource AND g2.SourceID = t.gSourceID
 
 LEFT OUTER JOIN (
  SELECT TOP 1000000
   c.ID
   , t.DoubleNameCount
  FROM
   (
    SELECT
     c.FirstName
     , c.LastName
     , COUNT(*) AS DoubleNameCount
    FROM
     ContactNames c
    WHERE
     c.FirstName IS NOT NULL
    GROUP BY
     c.FirstName
     , c.LastName
    HAVING
     COUNT(*) > 1
   ) t
   LEFT OUTER JOIN ContactNames c ON t.FirstName = c.FirstName AND t.LastName = c.LastName
  ORDER BY
   c.ID
 ) dn ON dn.ID = c.ID
','View Contacts','CODE','INSERT INTO [Contacts]
    ( [ContactCategory]
    , [String1]
    , [String2]
    , [String3]
    , [Number1]
    , [Number2]
    , [Number3]
    )
VALUES
    ( @ContactCategory
    , @String1
    , @String2
    , @String3
    , @Number1
    , @Number2
    , @Number3
    );
GO

UPDATE [Contacts]
SET
    [SourceID] = CAST(@@IDENTITY AS nvarchar(50))
WHERE
    ID = @@IDENTITY;
GO
    
INSERT INTO [ContactNames]
    ( [ID]
    , [FirstName]
    , [LastName]
    )
VALUES
    ( @@IDENTITY
    , @FirstName
    , @LastName
    );
GO

INSERT INTO [ContactEmail]
    ( [ID]
    , [Email]
    )
VALUES
    ( @@IDENTITY
    , @Email
    );
GO

INSERT INTO [ContactMobile]
    ( [ID]
    , [Mobile]
    )
VALUES
    ( @@IDENTITY
    , @Mobile
    );
GO

INSERT INTO [ContactPhone]
    ( [ID]
    , [Phone]
    )
VALUES
    ( @@IDENTITY
    , @Phone
    );
GO
    
INSERT INTO [ContactCompany]
    ( [ID]
    , [Company]
    )
VALUES
    ( @@IDENTITY
    , @Company
    );
GO

INSERT INTO [ContactTitle]
    ( [ID]
    , [Title]
    )
VALUES
    ( @@IDENTITY
    , @Title
    );
GO

INSERT INTO [ContactCountry]
    ( [ID]
    , [Country]
    )
VALUES
    ( @@IDENTITY
    , @Country
    );
GO
    
INSERT INTO [ContactWebsite]
    ( [ID]
    , [Website]
    )
VALUES
    ( @@IDENTITY
    , @Website
    );
GO','-- This code updates Contacts as the record must be in the table

UPDATE [Contacts]
SET
    [ContactCategory] = @ContactCategory
    , [String1] = @String1
    , [String2] = @String2
    , [String3] = @String3
    , [Number1] = @Number1
    , [Number2] = @Number2
    , [Number3] = @Number3
WHERE
    ID = @ID;
GO

-- The code below has UPDATE and INSERT commands
-- UPDATE is used to update existing data with any value
-- INSERT is used to insert new non-NULL values

-- Contact tables: Names, Emails, Mobile, Phone, Company, Title, Country, Website
-- These tables are separate to make possible to update tables using nested queries as
-- SQLCE does not support the FROM clause for UPDATE and supports it for INSERT.

UPDATE [ContactNames]
SET
    [FirstName] = @FirstName
    ,[LastName] = @LastName
WHERE
    ID = @ID;
GO

INSERT INTO [ContactNames]
    ( [ID]
    , [FirstName]
    , [LastName]
    )
SELECT
    s.[ID]
    , s.[FirstName]
    , s.[LastName]
FROM
    (
    SELECT
        @ID AS ID
        , @FirstName AS FirstName
        , @LastName AS LastName
    ) s
    LEFT OUTER JOIN [ContactNames] c ON c.ID = s.ID
WHERE
    s.ID IS NOT NULL
    AND c.ID IS NULL;
GO

UPDATE [ContactEmail]
SET
    [Email] = @Email
WHERE
    ID = @ID;
GO

INSERT INTO [ContactEmail]
    ( [ID]
    , [Email]
    )
SELECT
    s.[ID]
    , s.[Email]
FROM
    (
    SELECT
        @ID AS ID
        , @Email AS Email
    ) s
    LEFT OUTER JOIN [ContactEmail] c ON c.ID = s.ID
WHERE
    s.ID IS NOT NULL
    AND s.Email IS NOT NULL
    AND c.ID IS NULL;
GO
    
UPDATE [ContactMobile]
SET
    [Mobile] = @Mobile
WHERE
    ID = @ID;
GO

INSERT INTO [ContactMobile]
    ( [ID]
    , [Mobile]
    )
SELECT
    s.[ID]
    , s.[Mobile]
FROM
    (
    SELECT
        @ID AS ID
        , @Mobile AS Mobile
    ) s
    LEFT OUTER JOIN [ContactMobile] c ON c.ID = s.ID
WHERE
    s.ID IS NOT NULL
    AND s.Mobile IS NOT NULL
    AND c.ID IS NULL;
GO

UPDATE [ContactPhone]
SET
    [Phone] = @Phone
WHERE
    ID = @ID;
GO

INSERT INTO [ContactPhone]
    ( [ID]
    , [Phone]
    )
SELECT
    s.[ID]
    , s.[Phone]
FROM
    (
    SELECT
        @ID AS ID
        , @Phone AS Phone
    ) s
    LEFT OUTER JOIN [ContactPhone] c ON c.ID = s.ID
WHERE
    s.ID IS NOT NULL
    AND s.Phone IS NOT NULL
    AND c.ID IS NULL;
GO
    
UPDATE [ContactCompany]
SET
    [Company] = @Company
WHERE
    ID = @ID;
GO

INSERT INTO [ContactCompany]
    ( [ID]
    , [Company]
    )
SELECT
    s.[ID]
    , s.[Company]
FROM
    (
    SELECT
        @ID AS ID
        , @Company AS Company
    ) s
    LEFT OUTER JOIN [ContactCompany] c ON c.ID = s.ID
WHERE
    s.ID IS NOT NULL
    AND s.Company IS NOT NULL
    AND c.ID IS NULL;
GO

UPDATE [ContactTitle]
SET
    [Title] = @Title
WHERE
    ID = @ID;
GO

INSERT INTO [ContactTitle]
    ( [ID]
    , [Title]
    )
SELECT
    s.[ID]
    , s.[Title]
FROM
    (
    SELECT
        @ID AS ID
        , @Title AS Title
    ) s
    LEFT OUTER JOIN [ContactTitle] c ON c.ID = s.ID
WHERE
    s.ID IS NOT NULL
    AND s.Title IS NOT NULL
    AND c.ID IS NULL;
GO

UPDATE [ContactCountry]
SET
    [Country] = @Country
WHERE
    ID = @ID;
GO

INSERT INTO [ContactCountry]
    ( [ID]
    , [Country]
    )
SELECT
    s.[ID]
    , s.[Country]
FROM
    (
    SELECT
        @ID AS ID
        , @Country AS Country
    ) s
    LEFT OUTER JOIN [ContactCountry] c ON c.ID = s.ID
WHERE
    s.ID IS NOT NULL
    AND s.Country IS NOT NULL
    AND c.ID IS NULL;
GO
    
UPDATE [ContactWebsite]
SET
    [Website] = @Website
WHERE
    ID = @ID;
GO

INSERT INTO [ContactWebsite]
    ( [ID]
    , [Website]
    )
SELECT
    s.[ID]
    , s.[Website]
FROM
    (
    SELECT
        @ID AS ID
        , @Website AS Website
    ) s
    LEFT OUTER JOIN [ContactWebsite] c ON c.ID = s.ID
WHERE
    s.ID IS NOT NULL
    AND s.Website IS NOT NULL
    AND c.ID IS NULL;
GO','DELETE FROM [Contacts] WHERE ID = @ID;
GO
');
GO
INSERT INTO [QueryList] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_TYPE],[INSERT_PROCEDURE],[UPDATE_PROCEDURE],[DELETE_PROCEDURE]) VALUES ('SELECT
 s.Source
 , s.SourceID
 , s.MergeDate
 , s.IsJunk
 , d.ContactID
 , s.SourceFirstName
 , s.SourceLastName
 , s.SourceEmail
 , s.SourceSecondaryEmail
 , s.SourceMobile
 , s.SourcePhone
 , s.SourceCompany
 , s.SourceJobTitle
 , s.SourceHeadline
 , s.SourceIndustry
 , s.SourceLocationName
 , s.SourceCountryCode
 , s.SourceProfileUrl    
FROM
    SourceContacts s
 LEFT OUTER JOIN SourceContactID d ON d.Source = s.Source AND d.SourceID = s.SourceID','View Source Contacts','CODE','SourceContacts','SourceContacts','SourceContacts');
GO
INSERT INTO [QueryList] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_TYPE],[INSERT_PROCEDURE],[UPDATE_PROCEDURE],[DELETE_PROCEDURE]) VALUES ('SELECT
    w.*
    , s.SourceDomainContactCount
    , c.DomainContactCount
    , t.WebsiteContactCount
    , CASE WHEN w.Checked IS NULL THEN 1 ELSE NULL END AS HasErrors
FROM
    Websites w

    LEFT OUTER JOIN (
        SELECT
            LOWER(SUBSTRING(c.SourceEmail, CHARINDEX(''@'', c.SourceEmail) + 1, 255)) AS Domain
            , COUNT(*) AS SourceDomainContactCount
        FROM
            SourceContacts c
        GROUP BY
            LOWER(SUBSTRING(c.SourceEmail, CHARINDEX(''@'', c.SourceEmail) + 1, 255))
    ) s ON s.Domain = w.Domain

    LEFT OUTER JOIN (
        SELECT
            LOWER(SUBSTRING(e.Email, CHARINDEX(''@'', e.Email) + 1, 255)) AS Domain
            , COUNT(*) AS DomainContactCount
        FROM
            Contacts c
            INNER JOIN ContactEmail e ON e.ID = c.ID
        GROUP BY
            LOWER(SUBSTRING(e.Email, CHARINDEX(''@'', e.Email) + 1, 255))
    ) c ON c.Domain = w.Domain

    LEFT OUTER JOIN (
        SELECT
            w.Website
            , COUNT(*) AS WebsiteContactCount
        FROM
            Contacts c
            INNER JOIN ContactWebsite w ON w.ID = c.ID
        GROUP BY
            w.Website
    ) t ON t.Website = w.Website','View Websites','CODE','Websites','Websites','Websites');
GO
INSERT INTO [QueryList] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_TYPE],[INSERT_PROCEDURE],[UPDATE_PROCEDURE],[DELETE_PROCEDURE]) VALUES ('SELECT
    c.*
    , COALESCE(l.ContactCount, 0) + COALESCE(r.ContactCount, 0) AS ContactCount
    , CASE WHEN c.Checked IS NULL THEN 1 ELSE NULL END AS HasErrors
FROM
    Countries c
    LEFT OUTER JOIN (
        SELECT
            r.Country
            , COUNT(*) AS ContactCount
        FROM
            Contacts c
            INNER JOIN ContactCountry r ON r.ID = c.ID
        GROUP BY
            r.Country
    ) l ON l.Country = c.CountryName
    LEFT OUTER JOIN (
        SELECT
            s.SourceCountryCode AS CountryCode
            , COUNT(*) AS ContactCount
        FROM
            SourceContacts s
            INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
            LEFT OUTER JOIN ContactCountry r ON r.ID = d.ContactID
        WHERE
            d.ContactID IS NOT NULL
            AND r.ID IS NULL
        GROUP BY
            s.SourceCountryCode
    ) r ON r.CountryCode = c.CountryCode','View Countries','CODE','Countries','Countries','Countries');
GO
INSERT INTO [QueryList] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_TYPE],[INSERT_PROCEDURE],[UPDATE_PROCEDURE],[DELETE_PROCEDURE]) VALUES ('SELECT
    c.ID
    , NULL AS ContactStatus
    , CASE WHEN dn.ID IS NULL THEN NULL ELSE DoubleNameCount END AS IsDoubleName
    , c.ContactCategory
    , n.FirstName
    , n.LastName
    , e.Email
    , m.Mobile
    , p.Phone
    , r.Country
    , LOWER(SUBSTRING(e.email, CHARINDEX(''@'', e.email) + 1, 255)) AS Domain
    , w.Website
    , y.Company
    , i.JobTitle
    , l2.SourceHeadline AS LinkedInHeadline
    , l2.SourceIndustry AS Industry
    , l2.SourceLocationName AS LocationName
    , l2.SourceProfileUrl AS LinkedInProfileUrl
    , g2.SourceProfileUrl AS GooglePlusProfileUrl
    , c.String1
    , c.String2
    , c.String3
    , c.Number1
    , c.Number2
    , c.Number3
FROM
    (
        SELECT
            c.ID
            , l2.[Source] AS lSource
            , MIN(l2.SourceID) AS lSourceID
            , g2.[Source] AS gSource
            , MIN(g2.SourceID) AS gSourceID
        FROM
            Contacts c
            LEFT OUTER JOIN SourceContactID l1 ON l1.ContactID = c.ID AND l1.[Source] = ''LinkedIn''
            LEFT OUTER JOIN SourceContacts l2 ON l2.[Source] = l1.[Source] AND l2.SourceID = l1.SourceID
            LEFT OUTER JOIN SourceContactID g1 ON g1.ContactID = c.ID AND g1.[Source] = ''GoogleCSV''
            LEFT OUTER JOIN SourceContacts g2 ON g2.[Source] = g1.[Source] AND g2.SourceID = g1.SourceID
        GROUP BY
            c.ID
            , l2.[Source]
            , g2.[Source]
    ) t
    INNER JOIN Contacts c ON c.ID = t.ID

    LEFT OUTER JOIN ContactNames    n ON n.ID = c.ID
    LEFT OUTER JOIN ContactEmail    e ON e.ID = c.ID
    LEFT OUTER JOIN ContactMobile   m ON m.ID = c.ID
    LEFT OUTER JOIN ContactPhone    p ON p.ID = c.ID
    LEFT OUTER JOIN ContactCountry  r ON r.ID = c.ID
    LEFT OUTER JOIN ContactWebsite  w ON w.ID = c.ID
    LEFT OUTER JOIN ContactCompany  y ON y.ID = c.ID
    LEFT OUTER JOIN ContactJobTitle    i ON i.ID = c.ID

    LEFT OUTER JOIN SourceContacts l2 ON l2.[Source] = t.lSource AND l2.SourceID = t.lSourceID
    LEFT OUTER JOIN SourceContacts g2 ON g2.[Source] = t.gSource AND g2.SourceID = t.gSourceID
    
    LEFT OUTER JOIN (
        SELECT TOP 1000000
            c.ID
            , t.DoubleNameCount
        FROM
            (
                SELECT
                    c.FirstName
                    , c.LastName
                    , COUNT(*) AS DoubleNameCount
                FROM
                    ContactNames c
                WHERE
                    c.FirstName IS NOT NULL
                GROUP BY
                    c.FirstName
                    , c.LastName
                HAVING
                    COUNT(*) > 1
            ) t
            LEFT OUTER JOIN ContactNames c ON t.FirstName = c.FirstName AND t.LastName = c.LastName
        ORDER BY
            c.ID
    ) dn ON dn.ID = c.ID

    LEFT OUTER JOIN Websites ws ON ws.Domain = @Domain AND ws.Website = w.Website
WHERE
    LOWER(SUBSTRING(e.Email, CHARINDEX(''@'', e.Email) + 1, 255)) = @Domain','Contacts By Domain','CODE','Contacts','Contacts','Contacts');
GO
INSERT INTO [QueryList] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_TYPE],[INSERT_PROCEDURE],[UPDATE_PROCEDURE],[DELETE_PROCEDURE]) VALUES ('SELECT
    c.ID
    , NULL AS ContactStatus
    , CASE WHEN dn.ID IS NULL THEN NULL ELSE DoubleNameCount END AS IsDoubleName
    , c.ContactCategory
    , n.FirstName
    , n.LastName
    , e.Email
    , m.Mobile
    , p.Phone
    , r.Country
    , LOWER(SUBSTRING(e.email, CHARINDEX(''@'', e.email) + 1, 255)) AS Domain
    , w.Website
    , y.Company
    , i.JobTitle
    , l2.SourceHeadline AS LinkedInHeadline
    , l2.SourceIndustry AS Industry
    , l2.SourceLocationName AS LocationName
    , l2.SourceProfileUrl AS LinkedInProfileUrl
    , g2.SourceProfileUrl AS GooglePlusProfileUrl
    , c.String1
    , c.String2
    , c.String3
    , c.Number1
    , c.Number2
    , c.Number3
FROM
    (
        SELECT
            c.ID
            , l2.[Source] AS lSource
            , MIN(l2.SourceID) AS lSourceID
            , g2.[Source] AS gSource
            , MIN(g2.SourceID) AS gSourceID
        FROM
            Contacts c
            LEFT OUTER JOIN SourceContactID l1 ON l1.ContactID = c.ID AND l1.[Source] = ''LinkedIn''
            LEFT OUTER JOIN SourceContacts l2 ON l2.[Source] = l1.[Source] AND l2.SourceID = l1.SourceID
            LEFT OUTER JOIN SourceContactID g1 ON g1.ContactID = c.ID AND g1.[Source] = ''GoogleCSV''
            LEFT OUTER JOIN SourceContacts g2 ON g2.[Source] = g1.[Source] AND g2.SourceID = g1.SourceID
        GROUP BY
            c.ID
            , l2.[Source]
            , g2.[Source]
    ) t
    INNER JOIN Contacts c ON c.ID = t.ID

    LEFT OUTER JOIN ContactNames    n ON n.ID = c.ID
    LEFT OUTER JOIN ContactEmail    e ON e.ID = c.ID
    LEFT OUTER JOIN ContactMobile   m ON m.ID = c.ID
    LEFT OUTER JOIN ContactPhone    p ON p.ID = c.ID
    LEFT OUTER JOIN ContactCountry  r ON r.ID = c.ID
    LEFT OUTER JOIN ContactWebsite  w ON w.ID = c.ID
    LEFT OUTER JOIN ContactCompany  y ON y.ID = c.ID
    LEFT OUTER JOIN ContactJobTitle    i ON i.ID = c.ID

    LEFT OUTER JOIN SourceContacts l2 ON l2.[Source] = t.lSource AND l2.SourceID = t.lSourceID
    LEFT OUTER JOIN SourceContacts g2 ON g2.[Source] = t.gSource AND g2.SourceID = t.gSourceID
    
    LEFT OUTER JOIN (
        SELECT TOP 1000000
            c.ID
            , t.DoubleNameCount
        FROM
            (
                SELECT
                    c.FirstName
                    , c.LastName
                    , COUNT(*) AS DoubleNameCount
                FROM
                    ContactNames c
                WHERE
                    c.FirstName IS NOT NULL
                GROUP BY
                    c.FirstName
                    , c.LastName
                HAVING
                    COUNT(*) > 1
            ) t
            LEFT OUTER JOIN ContactNames c ON t.FirstName = c.FirstName AND t.LastName = c.LastName
        ORDER BY
            c.ID
    ) dn ON dn.ID = c.ID

WHERE
    r.Country = @CountryName','Contacts By Country','CODE','Contacts','Contacts','Contacts');
GO
INSERT INTO [QueryList] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_TYPE],[INSERT_PROCEDURE],[UPDATE_PROCEDURE],[DELETE_PROCEDURE]) VALUES ('-- Selects source contacts with the specified ContactID
SELECT
    s.Source
    , s.SourceID
    , s.MergeDate
    , s.IsJunk
    , d.ContactID
    , s.SourceFirstName
    , s.SourceLastName
    , s.SourceEmail
    , s.SourceSecondaryEmail
    , s.SourceMobile
    , s.SourcePhone
    , s.SourceCompany
    , s.SourceJobTitle
    , s.SourceHeadline
    , s.SourceIndustry
    , s.SourceLocationName
    , s.SourceCountryCode
    , s.SourceProfileUrl    
FROM
    SourceContacts s
    INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.ContactID = @ID
UNION ALL
-- Selects source contacts with en empty ContactID if ContactID is NULL
SELECT
    s.Source
    , s.SourceID
    , s.MergeDate
    , s.IsJunk
    , d.ContactID
    , s.SourceFirstName
    , s.SourceLastName
    , s.SourceEmail
    , s.SourceSecondaryEmail
    , s.SourceMobile
    , s.SourcePhone
    , s.SourceCompany
    , s.SourceJobTitle
    , s.SourceHeadline
    , s.SourceIndustry
    , s.SourceLocationName
    , s.SourceCountryCode
    , s.SourceProfileUrl    
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.ContactID IS NULL
    AND @ID IS NULL
UNION ALL
-- Selects source contacts with the LastName as contact''s LastName and an empty ContactID
SELECT
    s.Source
    , s.SourceID
    , s.MergeDate
    , s.IsJunk
    , d.ContactID
    , s.SourceFirstName
    , s.SourceLastName
    , s.SourceEmail
    , s.SourceSecondaryEmail
    , s.SourceMobile
    , s.SourcePhone
    , s.SourceCompany
    , s.SourceJobTitle
    , s.SourceHeadline
    , s.SourceIndustry
    , s.SourceLocationName
    , s.SourceCountryCode
    , s.SourceProfileUrl    
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    INNER JOIN ContactNames n ON n.LastName = s.SourceLastName
WHERE
    d.ContactID IS NULL
    AND n.ID = @ID','Source Contacts By ContactID','CODE','SourceContacts','SourceContacts','SourceContacts');
GO
-- print QueryLists have been inserted

INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('http','Google - API',NULL,'Actions','http://contacts.google.com','Open Google Contacts Page','HTTP',NULL,11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('http','LinkedIn - API',NULL,'Actions','http://www.linkedin.com/contacts/','Open LinkedIn Connections Page','HTTP',NULL,11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('http','LinkedIn - API',NULL,'ContextMenu','{SourceProfileUrl}','Open LinkedIn Profile','HTTP',NULL,12,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('http','Yahoo! - API',NULL,'Actions','http://contacts.yahoo.com/','Open Yahoo! Contacts Page','HTTP',NULL,11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('text','Google - CSV',NULL,'Actions','http://contacts.google.com','Open Google Contacts Export Page','HTTP',NULL,11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('text','Google - CSV',NULL,'Actions','{WorkbookPath}','Open Working Directory','CMD',NULL,12,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('text','Google - CSV',NULL,'Actions','notepad.exe {FileName}','Open Source File','CMD',NULL,13,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('text','LinkedIn - CSV',NULL,'Actions','http://www.linkedin.com/people/export-settings','Open LinkedIn Export Page','HTTP',NULL,11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('text','LinkedIn - CSV',NULL,'Actions','{WorkbookPath}','Open Working Directory','CMD',NULL,12,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('text','LinkedIn - CSV',NULL,'Actions','notepad.exe {FileName}','Open Source File','CMD',NULL,13,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('text','Outlook - CSV',NULL,'Actions','{WorkbookPath}','Open Working Directory','CMD',NULL,12,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('text','Outlook - CSV',NULL,'Actions','notepad.exe {FileName}','Open Source File','CMD',NULL,13,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('text','Yahoo! - HTM',NULL,'Actions','http://contacts.yahoo.com/','Open Yahoo! Contacts Export Page','HTTP',NULL,11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('text','Yahoo! - HTM',NULL,'Actions','{WorkbookPath}','Open Working Directory','CMD',NULL,12,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('text','Yahoo! - HTM',NULL,'Actions','{FileName}','Open Source File','CMD',NULL,13,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Contacts',NULL,'Actions','
-- Changing fields with non-printing characters only to NULL in SourceContacts

UPDATE SourceContacts SET SourceCompany = NULL   WHERE SourceCompany IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceCompany, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE SourceContacts SET SourceJobTitle = NULL  WHERE SourceJobTitle IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceJobTitle, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE SourceContacts SET SourceFirstName = NULL WHERE SourceFirstName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceFirstName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE SourceContacts SET SourceLastName = NULL  WHERE SourceLastName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceLastName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO

-- Changing fields with non-printing characters only to NULL in Contacts

UPDATE ContactCompany SET Company = NULL    WHERE Company IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(Company, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE ContactJobTitle SET JobTitle = NULL  WHERE JobTitle IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(JobTitle, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE ContactNames SET FirstName = NULL    WHERE FirstName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(FirstName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE ContactNames SET LastName = NULL     WHERE LastName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(LastName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO

-- Setting ContactID for new source contacts if SourceFirstName, SourceLastName, SourceJobTitle, and SourceCompany are the same (FirstName and LastName may be not unique)

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , v.ContactID
FROM
    SourceContacts s
    INNER JOIN SourceContacts t ON
        t.[Source] = s.[Source]
        AND t.SourceFirstName = s.SourceFirstName
        AND t.SourceLastName = s.SourceLastName
        AND t.SourceJobTitle = s.SourceJobTitle
        AND t.SourceCompany = s.SourceCompany
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN SourceContactID v ON v.[Source] = t.[Source] AND v.SourceID = t.SourceID
WHERE
    t.MergeDate < s.MergeDate
    AND v.ContactID IS NOT NULL    
    AND d.ContactID IS NULL;
GO

-- =====
-- Discovering existing contacts by unique FirstName and LastName in the same source (latest merged data are used)

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    t.[Source]
    , t.SourceID
    , d.ContactID
FROM
    (
        -- Selects unique FirstName, LastName in the last merged data in every Source
        SELECT
            s.[Source]
            , MAX(s.SourceID) AS SourceID
            , MAX(d.ContactID) AS ContactID
            , s.SourceFirstName
            , s.SourceLastName
        FROM
            SourceContacts s
            INNER JOIN (
                -- Selects the latest MergeDate for each FirstName, LastName in every Source
                SELECT
                    s.[Source]
                    , s.SourceFirstName
                    , s.SourceLastName
                    , MAX(s.MergeDate) AS LastMergeDate
                FROM
                    SourceContacts s
                GROUP BY
                    s.[Source]
                    , s.SourceFirstName
                    , s.SourceLastName
            ) t ON t.[Source] = s.[Source] AND t.SourceFirstName = s.SourceFirstName AND t.SourceLastName = s.SourceLastName
                AND t.LastMergeDate = s.MergeDate
            LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
        GROUP BY
            s.[Source]
            , s.SourceFirstName
            , s.SourceLastName
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON t.[Source] = s.[Source] AND t.SourceFirstName = s.SourceFirstName AND t.SourceLastName = s.SourceLastName
        AND t.SourceID <> s.SourceID    -- Source is the same and SourceID is different
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN SourceContactID v ON v.[Source] = t.[Source] AND v.SourceID = t.SourceID
WHERE
    d.ContactID IS NOT NULL
    AND t.ContactID IS NULL
    AND v.SourceID IS NULL;
GO

-- Discovering existing contacts by unique Emails in all sources
-- Existing duplicated emails in Contacts must be resolved manually

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceSecondaryEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO

-- Discovering existing contacts by unique mobile phones in all sources
-- Existing duplicated mobile phones in Contacts must be resolved manually
-- Phone numbers are normalized to digits

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    SourceContacts s
    INNER JOIN (
        -- Selects unique mobile phones with ContactID
        SELECT
            s.SourceMobile
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceMobile
                , s.ContactID
            FROM
                (
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , d.ContactID
                    FROM
                        SourceContacts s
                        LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceMobile IS NOT NULL
                    UNION
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.Mobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , s.ID AS ContactID
                    FROM
                        ContactMobile s
                    WHERE
                        s.Mobile IS NOT NULL
                ) s
            GROUP BY
                s.SourceMobile
                , s.ContactID
            ) s
        GROUP BY
            s.SourceMobile
        HAVING
            COUNT(*) = 1
    ) t ON t.SourceMobile = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO
-- =====

-- Adding new contacts identified by email (SourceID in Contacts)

INSERT INTO Contacts
    ( SourceID
    )
SELECT
    s.SourceEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN Contacts c ON c.SourceID = s.SourceEmail
WHERE
    s.IsJunk IS NULL
    AND s.SourceEmail IS NOT NULL
GROUP BY
    s.SourceEmail
HAVING
    MAX(d.ContactID) IS NULL
    AND MAX(c.SourceID) IS NULL;
GO

-- Adding new contacts identified by secondary email (SourceID in Contacts)

INSERT INTO Contacts
    ( SourceID
    )
SELECT
    s.SourceSecondaryEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN Contacts c ON c.SourceID = s.SourceSecondaryEmail
WHERE
    s.IsJunk IS NULL
    AND s.SourceEmail IS NULL
    AND s.SourceSecondaryEmail IS NOT NULL
GROUP BY
    s.SourceSecondaryEmail
HAVING
    MAX(d.ContactID) IS NULL
    AND MAX(c.SourceID) IS NULL;
GO

-- Adding new contacts identified by email (ID and Email in ContactEmail)

INSERT ContactEmail
    ( ID
    , Email
    )
SELECT
    c.ID
    , s.SourceEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    INNER JOIN Contacts c ON c.SourceID = s.SourceEmail
    LEFT OUTER JOIN ContactEmail e ON e.ID = c.ID
GROUP BY
    c.ID
    , s.SourceEmail
HAVING
    MAX(e.ID) IS NULL;
GO

-- Adding new contacts identified by secondary email (ID and Email in ContactEmail)

INSERT ContactEmail
    ( ID
    , Email
    )
SELECT
    c.ID
    , s.SourceSecondaryEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    INNER JOIN Contacts c ON c.SourceID = s.SourceSecondaryEmail
    LEFT OUTER JOIN ContactEmail e ON e.ID = c.ID
GROUP BY
    c.ID
    , s.SourceSecondaryEmail
HAVING
    MAX(e.ID) IS NULL;
GO

-- =====
-- Discovering existing contacts by unique Emails in all sources
-- Existing duplicated emails in Contacts must be resolved manually

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceSecondaryEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO
-- =====

-- Adding new contacts identified by mobile phones with empty emails (SourceID in Contacts)
-- Phone numbers are normalized to digits

INSERT INTO Contacts
    ( SourceID
    )
SELECT
    REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile2
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN Contacts c ON c.SourceID = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
WHERE
    s.IsJunk IS NULL
    AND s.SourceEmail IS NULL
    AND s.SourceSecondaryEmail IS NULL
    AND s.SourceMobile IS NOT NULL
GROUP BY
    REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
HAVING
    MAX(d.ContactID) IS NULL
    AND MAX(c.SourceID) IS NULL;
GO

-- Adding new contacts identified by mobile phones with empty emails (ID and Mobile in ContactMobile)

INSERT ContactMobile
    ( ID
    , Mobile
    )
SELECT
    c.ID
    , MIN(s.SourceMobile) AS Mobile
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    INNER JOIN Contacts c ON c.SourceID = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
    LEFT OUTER JOIN ContactMobile m ON m.ID = c.ID
GROUP BY
    c.ID
    , REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
HAVING
    MAX(m.ID) IS NULL;
GO

-- =====
-- Discovering existing contacts by unique mobile phones in all sources
-- Existing duplicated mobile phones in Contacts must be resolved manually
-- Phone numbers are normalized to digits

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    SourceContacts s
    INNER JOIN (
        -- Selects unique mobile phones with ContactID
        SELECT
            s.SourceMobile
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceMobile
                , s.ContactID
            FROM
                (
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , d.ContactID
                    FROM
                        SourceContacts s
                        LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceMobile IS NOT NULL
                    UNION
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.Mobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , s.ID AS ContactID
                    FROM
                        ContactMobile s
                    WHERE
                        s.Mobile IS NOT NULL
                ) s
            GROUP BY
                s.SourceMobile
                , s.ContactID
            ) s
        GROUP BY
            s.SourceMobile
        HAVING
            COUNT(*) = 1
    ) t ON t.SourceMobile = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO
-- =====

-- Updating LinkedIn API contacts
-- LinkedIn API data do not contain emails
-- Data are linked using first and last names if the names are unique in LinkedIn CSV data

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    SourceContacts s
    INNER JOIN (
        SELECT
            s.SourceFirstName
            , s.SourceLastName
            , MAX(d.ContactID) AS ContactID
        FROM
            SourceContacts s
            LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
        WHERE
            s.[Source] = ''LinkedInCSV''
        GROUP BY
            s.SourceFirstName
            , s.SourceLastName
        HAVING
            COUNT(*) = 1
    ) t ON t.SourceFirstName = s.SourceFirstName AND t.SourceLastName = s.SourceLastName
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    s.[Source] = ''LinkedIn''
    AND t.ContactID IS NOT NULL
    AND d.SourceID IS NULL;
GO

-- Inserting names for new contacts

INSERT ContactNames (ID, FirstName, LastName)
SELECT
    d.ContactID
    , MIN(s.SourceFirstName) AS FirstName
    , MIN(s.SourceLastName) AS LastName
FROM
    SourceContacts s
    INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN ContactNames c ON c.ID = d.ContactID
WHERE
    s.SourceFirstName IS NOT NULL
GROUP BY
    d.ContactID
HAVING
    MAX(c.ID) IS NULL
    AND d.ContactID IS NOT NULL;
GO

-- Inserting mobile numbers if not exist

INSERT ContactMobile (ID, Mobile)
SELECT
    d.ContactID
    , MIN(s.SourceMobile) AS Mobile
FROM
    SourceContacts s
    INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN ContactMobile c ON c.ID = d.ContactID
WHERE
    s.SourceMobile IS NOT NULL
GROUP BY
    d.ContactID
HAVING
    MAX(c.ID) IS NULL;
GO

-- Inserting new countries from SourceContacts

INSERT Countries
    (CountryCode, CountryName)
SELECT
    s.SourceCountryCode AS CountryCode
    , MIN(t.SourceLocationName) AS CountryName              -- Min LocationName for all with min length
FROM
    (
        SELECT
            s.SourceCountryCode
            , MIN(LEN(s.SourceLocationName)) AS [Length]    -- Min LocationName length
        FROM
            SourceContacts s
        WHERE
            s.SourceCountryCode IS NOT NULL
        GROUP BY
            s.SourceCountryCode                             -- All country codes
    ) s

    INNER JOIN (
        SELECT
            s.SourceCountryCode
            , s.SourceLocationName                          -- Default country name as LocationName
            , LEN(s.SourceLocationName) AS [Length]         -- with minimal length
        FROM
            SourceContacts s
        GROUP BY
            s.SourceCountryCode
            , s.SourceLocationName
    ) t ON t.SourceCountryCode = s.SourceCountryCode AND t.[Length] = s.[Length]

    LEFT OUTER JOIN Countries c ON c.CountryCode = s.SourceCountryCode
WHERE
    c.CountryCode IS NULL
GROUP BY
    s.SourceCountryCode;
GO

-- Inserting new domains into Websites from SourceContacts if domains have 3 or more contacts

INSERT Websites
    (Domain, Website)
SELECT
    c.Domain AS Domain
    , ''www.'' + c.Domain AS Website
FROM
    (
        SELECT
            LOWER(SUBSTRING(c.SourceEmail, CHARINDEX(''@'', c.SourceEmail) + 1, 255)) AS Domain
        FROM
            SourceContacts c
        WHERE
            c.SourceEmail IS NOT NULL
            AND CHARINDEX(''@'', c.SourceEmail) > 1
        GROUP BY
            LOWER(SUBSTRING(c.SourceEmail, CHARINDEX(''@'', c.SourceEmail) + 1, 255))
        HAVING
            COUNT(*) > 2
    ) c
    LEFT OUTER JOIN Websites w ON w.Domain = c.Domain
WHERE
    w.Domain IS NULL;
GO

-- Inserting  new domains into Websites from Contacts if domains have 3 or more contacts

INSERT Websites
    (Domain, Website)
SELECT
    c.Domain AS Domain
    , ''www.'' + c.Domain AS Website
FROM
    (
        SELECT
            LOWER(SUBSTRING(c.Email, CHARINDEX(''@'', c.Email) + 1, 255)) AS Domain
        FROM
            ContactEmail c
        WHERE
            c.Email IS NOT NULL
            AND CHARINDEX(''@'', c.Email) > 1
        GROUP BY
            LOWER(SUBSTRING(c.Email, CHARINDEX(''@'', c.Email) + 1, 255))
        HAVING
            COUNT(*) > 2
    ) c
    LEFT OUTER JOIN Websites w ON w.Domain = c.Domain
WHERE
    w.Domain IS NULL;
GO
','Update Contacts','CODE','_Reload',11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Source Contacts',NULL,'Actions','
-- Changing fields with non-printing characters only to NULL in SourceContacts

UPDATE SourceContacts SET SourceCompany = NULL   WHERE SourceCompany IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceCompany, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE SourceContacts SET SourceJobTitle = NULL  WHERE SourceJobTitle IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceJobTitle, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE SourceContacts SET SourceFirstName = NULL WHERE SourceFirstName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceFirstName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE SourceContacts SET SourceLastName = NULL  WHERE SourceLastName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceLastName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO

-- Changing fields with non-printing characters only to NULL in Contacts

UPDATE ContactCompany SET Company = NULL    WHERE Company IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(Company, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE ContactJobTitle SET JobTitle = NULL  WHERE JobTitle IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(JobTitle, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE ContactNames SET FirstName = NULL    WHERE FirstName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(FirstName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE ContactNames SET LastName = NULL     WHERE LastName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(LastName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO

-- Setting ContactID for new source contacts if SourceFirstName, SourceLastName, SourceJobTitle, and SourceCompany are the same (FirstName and LastName may be not unique)

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , v.ContactID
FROM
    SourceContacts s
    INNER JOIN SourceContacts t ON
        t.[Source] = s.[Source]
        AND t.SourceFirstName = s.SourceFirstName
        AND t.SourceLastName = s.SourceLastName
        AND t.SourceJobTitle = s.SourceJobTitle
        AND t.SourceCompany = s.SourceCompany
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN SourceContactID v ON v.[Source] = t.[Source] AND v.SourceID = t.SourceID
WHERE
    t.MergeDate < s.MergeDate
    AND v.ContactID IS NOT NULL    
    AND d.ContactID IS NULL;
GO

-- =====
-- Discovering existing contacts by unique FirstName and LastName in the same source (latest merged data are used)

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    t.[Source]
    , t.SourceID
    , d.ContactID
FROM
    (
        -- Selects unique FirstName, LastName in the last merged data in every Source
        SELECT
            s.[Source]
            , MAX(s.SourceID) AS SourceID
            , MAX(d.ContactID) AS ContactID
            , s.SourceFirstName
            , s.SourceLastName
        FROM
            SourceContacts s
            INNER JOIN (
                -- Selects the latest MergeDate for each FirstName, LastName in every Source
                SELECT
                    s.[Source]
                    , s.SourceFirstName
                    , s.SourceLastName
                    , MAX(s.MergeDate) AS LastMergeDate
                FROM
                    SourceContacts s
                GROUP BY
                    s.[Source]
                    , s.SourceFirstName
                    , s.SourceLastName
            ) t ON t.[Source] = s.[Source] AND t.SourceFirstName = s.SourceFirstName AND t.SourceLastName = s.SourceLastName
                AND t.LastMergeDate = s.MergeDate
            LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
        GROUP BY
            s.[Source]
            , s.SourceFirstName
            , s.SourceLastName
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON t.[Source] = s.[Source] AND t.SourceFirstName = s.SourceFirstName AND t.SourceLastName = s.SourceLastName
        AND t.SourceID <> s.SourceID    -- Source is the same and SourceID is different
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN SourceContactID v ON v.[Source] = t.[Source] AND v.SourceID = t.SourceID
WHERE
    d.ContactID IS NOT NULL
    AND t.ContactID IS NULL
    AND v.SourceID IS NULL;
GO

-- Discovering existing contacts by unique Emails in all sources
-- Existing duplicated emails in Contacts must be resolved manually

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceSecondaryEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO

-- Discovering existing contacts by unique mobile phones in all sources
-- Existing duplicated mobile phones in Contacts must be resolved manually
-- Phone numbers are normalized to digits

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    SourceContacts s
    INNER JOIN (
        -- Selects unique mobile phones with ContactID
        SELECT
            s.SourceMobile
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceMobile
                , s.ContactID
            FROM
                (
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , d.ContactID
                    FROM
                        SourceContacts s
                        LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceMobile IS NOT NULL
                    UNION
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.Mobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , s.ID AS ContactID
                    FROM
                        ContactMobile s
                    WHERE
                        s.Mobile IS NOT NULL
                ) s
            GROUP BY
                s.SourceMobile
                , s.ContactID
            ) s
        GROUP BY
            s.SourceMobile
        HAVING
            COUNT(*) = 1
    ) t ON t.SourceMobile = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO
-- =====

-- Adding new contacts identified by email (SourceID in Contacts)

INSERT INTO Contacts
    ( SourceID
    )
SELECT
    s.SourceEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN Contacts c ON c.SourceID = s.SourceEmail
WHERE
    s.IsJunk IS NULL
    AND s.SourceEmail IS NOT NULL
GROUP BY
    s.SourceEmail
HAVING
    MAX(d.ContactID) IS NULL
    AND MAX(c.SourceID) IS NULL;
GO

-- Adding new contacts identified by secondary email (SourceID in Contacts)

INSERT INTO Contacts
    ( SourceID
    )
SELECT
    s.SourceSecondaryEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN Contacts c ON c.SourceID = s.SourceSecondaryEmail
WHERE
    s.IsJunk IS NULL
    AND s.SourceEmail IS NULL
    AND s.SourceSecondaryEmail IS NOT NULL
GROUP BY
    s.SourceSecondaryEmail
HAVING
    MAX(d.ContactID) IS NULL
    AND MAX(c.SourceID) IS NULL;
GO

-- Adding new contacts identified by email (ID and Email in ContactEmail)

INSERT ContactEmail
    ( ID
    , Email
    )
SELECT
    c.ID
    , s.SourceEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    INNER JOIN Contacts c ON c.SourceID = s.SourceEmail
    LEFT OUTER JOIN ContactEmail e ON e.ID = c.ID
GROUP BY
    c.ID
    , s.SourceEmail
HAVING
    MAX(e.ID) IS NULL;
GO

-- Adding new contacts identified by secondary email (ID and Email in ContactEmail)

INSERT ContactEmail
    ( ID
    , Email
    )
SELECT
    c.ID
    , s.SourceSecondaryEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    INNER JOIN Contacts c ON c.SourceID = s.SourceSecondaryEmail
    LEFT OUTER JOIN ContactEmail e ON e.ID = c.ID
GROUP BY
    c.ID
    , s.SourceSecondaryEmail
HAVING
    MAX(e.ID) IS NULL;
GO

-- =====
-- Discovering existing contacts by unique Emails in all sources
-- Existing duplicated emails in Contacts must be resolved manually

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceSecondaryEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO
-- =====

-- Adding new contacts identified by mobile phones with empty emails (SourceID in Contacts)
-- Phone numbers are normalized to digits

INSERT INTO Contacts
    ( SourceID
    )
SELECT
    REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile2
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN Contacts c ON c.SourceID = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
WHERE
    s.IsJunk IS NULL
    AND s.SourceEmail IS NULL
    AND s.SourceSecondaryEmail IS NULL
    AND s.SourceMobile IS NOT NULL
GROUP BY
    REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
HAVING
    MAX(d.ContactID) IS NULL
    AND MAX(c.SourceID) IS NULL;
GO

-- Adding new contacts identified by mobile phones with empty emails (ID and Mobile in ContactMobile)

INSERT ContactMobile
    ( ID
    , Mobile
    )
SELECT
    c.ID
    , MIN(s.SourceMobile) AS Mobile
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    INNER JOIN Contacts c ON c.SourceID = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
    LEFT OUTER JOIN ContactMobile m ON m.ID = c.ID
GROUP BY
    c.ID
    , REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
HAVING
    MAX(m.ID) IS NULL;
GO

-- =====
-- Discovering existing contacts by unique mobile phones in all sources
-- Existing duplicated mobile phones in Contacts must be resolved manually
-- Phone numbers are normalized to digits

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    SourceContacts s
    INNER JOIN (
        -- Selects unique mobile phones with ContactID
        SELECT
            s.SourceMobile
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceMobile
                , s.ContactID
            FROM
                (
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , d.ContactID
                    FROM
                        SourceContacts s
                        LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceMobile IS NOT NULL
                    UNION
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.Mobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , s.ID AS ContactID
                    FROM
                        ContactMobile s
                    WHERE
                        s.Mobile IS NOT NULL
                ) s
            GROUP BY
                s.SourceMobile
                , s.ContactID
            ) s
        GROUP BY
            s.SourceMobile
        HAVING
            COUNT(*) = 1
    ) t ON t.SourceMobile = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO
-- =====

-- Updating LinkedIn API contacts
-- LinkedIn API data do not contain emails
-- Data are linked using first and last names if the names are unique in LinkedIn CSV data

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    SourceContacts s
    INNER JOIN (
        SELECT
            s.SourceFirstName
            , s.SourceLastName
            , MAX(d.ContactID) AS ContactID
        FROM
            SourceContacts s
            LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
        WHERE
            s.[Source] = ''LinkedInCSV''
        GROUP BY
            s.SourceFirstName
            , s.SourceLastName
        HAVING
            COUNT(*) = 1
    ) t ON t.SourceFirstName = s.SourceFirstName AND t.SourceLastName = s.SourceLastName
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    s.[Source] = ''LinkedIn''
    AND t.ContactID IS NOT NULL
    AND d.SourceID IS NULL;
GO

-- Inserting names for new contacts

INSERT ContactNames (ID, FirstName, LastName)
SELECT
    d.ContactID
    , MIN(s.SourceFirstName) AS FirstName
    , MIN(s.SourceLastName) AS LastName
FROM
    SourceContacts s
    INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN ContactNames c ON c.ID = d.ContactID
WHERE
    s.SourceFirstName IS NOT NULL
GROUP BY
    d.ContactID
HAVING
    MAX(c.ID) IS NULL
    AND d.ContactID IS NOT NULL;
GO

-- Inserting mobile numbers if not exist

INSERT ContactMobile (ID, Mobile)
SELECT
    d.ContactID
    , MIN(s.SourceMobile) AS Mobile
FROM
    SourceContacts s
    INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN ContactMobile c ON c.ID = d.ContactID
WHERE
    s.SourceMobile IS NOT NULL
GROUP BY
    d.ContactID
HAVING
    MAX(c.ID) IS NULL;
GO

-- Inserting new countries from SourceContacts

INSERT Countries
    (CountryCode, CountryName)
SELECT
    s.SourceCountryCode AS CountryCode
    , MIN(t.SourceLocationName) AS CountryName              -- Min LocationName for all with min length
FROM
    (
        SELECT
            s.SourceCountryCode
            , MIN(LEN(s.SourceLocationName)) AS [Length]    -- Min LocationName length
        FROM
            SourceContacts s
        WHERE
            s.SourceCountryCode IS NOT NULL
        GROUP BY
            s.SourceCountryCode                             -- All country codes
    ) s

    INNER JOIN (
        SELECT
            s.SourceCountryCode
            , s.SourceLocationName                          -- Default country name as LocationName
            , LEN(s.SourceLocationName) AS [Length]         -- with minimal length
        FROM
            SourceContacts s
        GROUP BY
            s.SourceCountryCode
            , s.SourceLocationName
    ) t ON t.SourceCountryCode = s.SourceCountryCode AND t.[Length] = s.[Length]

    LEFT OUTER JOIN Countries c ON c.CountryCode = s.SourceCountryCode
WHERE
    c.CountryCode IS NULL
GROUP BY
    s.SourceCountryCode;
GO

-- Inserting new domains into Websites from SourceContacts if domains have 3 or more contacts

INSERT Websites
    (Domain, Website)
SELECT
    c.Domain AS Domain
    , ''www.'' + c.Domain AS Website
FROM
    (
        SELECT
            LOWER(SUBSTRING(c.SourceEmail, CHARINDEX(''@'', c.SourceEmail) + 1, 255)) AS Domain
        FROM
            SourceContacts c
        WHERE
            c.SourceEmail IS NOT NULL
            AND CHARINDEX(''@'', c.SourceEmail) > 1
        GROUP BY
            LOWER(SUBSTRING(c.SourceEmail, CHARINDEX(''@'', c.SourceEmail) + 1, 255))
        HAVING
            COUNT(*) > 2
    ) c
    LEFT OUTER JOIN Websites w ON w.Domain = c.Domain
WHERE
    w.Domain IS NULL;
GO

-- Inserting  new domains into Websites from Contacts if domains have 3 or more contacts

INSERT Websites
    (Domain, Website)
SELECT
    c.Domain AS Domain
    , ''www.'' + c.Domain AS Website
FROM
    (
        SELECT
            LOWER(SUBSTRING(c.Email, CHARINDEX(''@'', c.Email) + 1, 255)) AS Domain
        FROM
            ContactEmail c
        WHERE
            c.Email IS NOT NULL
            AND CHARINDEX(''@'', c.Email) > 1
        GROUP BY
            LOWER(SUBSTRING(c.Email, CHARINDEX(''@'', c.Email) + 1, 255))
        HAVING
            COUNT(*) > 2
    ) c
    LEFT OUTER JOIN Websites w ON w.Domain = c.Domain
WHERE
    w.Domain IS NULL;
GO
','Update Contacts','CODE','_Reload',11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Contacts',NULL,'Actions','
-- Changing fields with non-printing characters only to NULL in SourceContacts

UPDATE SourceContacts SET SourceCompany = NULL   WHERE SourceCompany IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceCompany, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE SourceContacts SET SourceJobTitle = NULL  WHERE SourceJobTitle IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceJobTitle, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE SourceContacts SET SourceFirstName = NULL WHERE SourceFirstName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceFirstName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE SourceContacts SET SourceLastName = NULL  WHERE SourceLastName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceLastName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO

-- Changing fields with non-printing characters only to NULL in Contacts

UPDATE ContactCompany SET Company = NULL    WHERE Company IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(Company, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE ContactJobTitle SET JobTitle = NULL  WHERE JobTitle IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(JobTitle, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE ContactNames SET FirstName = NULL    WHERE FirstName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(FirstName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE ContactNames SET LastName = NULL     WHERE LastName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(LastName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO

-- Setting ContactID for new source contacts if SourceFirstName, SourceLastName, SourceJobTitle, and SourceCompany are the same (FirstName and LastName may be not unique)

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , v.ContactID
FROM
    SourceContacts s
    INNER JOIN SourceContacts t ON
        t.[Source] = s.[Source]
        AND t.SourceFirstName = s.SourceFirstName
        AND t.SourceLastName = s.SourceLastName
        AND t.SourceJobTitle = s.SourceJobTitle
        AND t.SourceCompany = s.SourceCompany
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN SourceContactID v ON v.[Source] = t.[Source] AND v.SourceID = t.SourceID
WHERE
    t.MergeDate < s.MergeDate
    AND v.ContactID IS NOT NULL    
    AND d.ContactID IS NULL;
GO

-- =====
-- Discovering existing contacts by unique FirstName and LastName in the same source (latest merged data are used)

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    t.[Source]
    , t.SourceID
    , d.ContactID
FROM
    (
        -- Selects unique FirstName, LastName in the last merged data in every Source
        SELECT
            s.[Source]
            , MAX(s.SourceID) AS SourceID
            , MAX(d.ContactID) AS ContactID
            , s.SourceFirstName
            , s.SourceLastName
        FROM
            SourceContacts s
            INNER JOIN (
                -- Selects the latest MergeDate for each FirstName, LastName in every Source
                SELECT
                    s.[Source]
                    , s.SourceFirstName
                    , s.SourceLastName
                    , MAX(s.MergeDate) AS LastMergeDate
                FROM
                    SourceContacts s
                GROUP BY
                    s.[Source]
                    , s.SourceFirstName
                    , s.SourceLastName
            ) t ON t.[Source] = s.[Source] AND t.SourceFirstName = s.SourceFirstName AND t.SourceLastName = s.SourceLastName
                AND t.LastMergeDate = s.MergeDate
            LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
        GROUP BY
            s.[Source]
            , s.SourceFirstName
            , s.SourceLastName
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON t.[Source] = s.[Source] AND t.SourceFirstName = s.SourceFirstName AND t.SourceLastName = s.SourceLastName
        AND t.SourceID <> s.SourceID    -- Source is the same and SourceID is different
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN SourceContactID v ON v.[Source] = t.[Source] AND v.SourceID = t.SourceID
WHERE
    d.ContactID IS NOT NULL
    AND t.ContactID IS NULL
    AND v.SourceID IS NULL;
GO

-- Discovering existing contacts by unique Emails in all sources
-- Existing duplicated emails in Contacts must be resolved manually

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceSecondaryEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO

-- Discovering existing contacts by unique mobile phones in all sources
-- Existing duplicated mobile phones in Contacts must be resolved manually
-- Phone numbers are normalized to digits

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    SourceContacts s
    INNER JOIN (
        -- Selects unique mobile phones with ContactID
        SELECT
            s.SourceMobile
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceMobile
                , s.ContactID
            FROM
                (
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , d.ContactID
                    FROM
                        SourceContacts s
                        LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceMobile IS NOT NULL
                    UNION
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.Mobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , s.ID AS ContactID
                    FROM
                        ContactMobile s
                    WHERE
                        s.Mobile IS NOT NULL
                ) s
            GROUP BY
                s.SourceMobile
                , s.ContactID
            ) s
        GROUP BY
            s.SourceMobile
        HAVING
            COUNT(*) = 1
    ) t ON t.SourceMobile = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO
-- =====

-- Adding new contacts identified by email (SourceID in Contacts)

INSERT INTO Contacts
    ( SourceID
    )
SELECT
    s.SourceEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN Contacts c ON c.SourceID = s.SourceEmail
WHERE
    s.IsJunk IS NULL
    AND s.SourceEmail IS NOT NULL
GROUP BY
    s.SourceEmail
HAVING
    MAX(d.ContactID) IS NULL
    AND MAX(c.SourceID) IS NULL;
GO

-- Adding new contacts identified by secondary email (SourceID in Contacts)

INSERT INTO Contacts
    ( SourceID
    )
SELECT
    s.SourceSecondaryEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN Contacts c ON c.SourceID = s.SourceSecondaryEmail
WHERE
    s.IsJunk IS NULL
    AND s.SourceEmail IS NULL
    AND s.SourceSecondaryEmail IS NOT NULL
GROUP BY
    s.SourceSecondaryEmail
HAVING
    MAX(d.ContactID) IS NULL
    AND MAX(c.SourceID) IS NULL;
GO

-- Adding new contacts identified by email (ID and Email in ContactEmail)

INSERT ContactEmail
    ( ID
    , Email
    )
SELECT
    c.ID
    , s.SourceEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    INNER JOIN Contacts c ON c.SourceID = s.SourceEmail
    LEFT OUTER JOIN ContactEmail e ON e.ID = c.ID
GROUP BY
    c.ID
    , s.SourceEmail
HAVING
    MAX(e.ID) IS NULL;
GO

-- Adding new contacts identified by secondary email (ID and Email in ContactEmail)

INSERT ContactEmail
    ( ID
    , Email
    )
SELECT
    c.ID
    , s.SourceSecondaryEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    INNER JOIN Contacts c ON c.SourceID = s.SourceSecondaryEmail
    LEFT OUTER JOIN ContactEmail e ON e.ID = c.ID
GROUP BY
    c.ID
    , s.SourceSecondaryEmail
HAVING
    MAX(e.ID) IS NULL;
GO

-- =====
-- Discovering existing contacts by unique Emails in all sources
-- Existing duplicated emails in Contacts must be resolved manually

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceSecondaryEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO
-- =====

-- Adding new contacts identified by mobile phones with empty emails (SourceID in Contacts)
-- Phone numbers are normalized to digits

INSERT INTO Contacts
    ( SourceID
    )
SELECT
    REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile2
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN Contacts c ON c.SourceID = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
WHERE
    s.IsJunk IS NULL
    AND s.SourceEmail IS NULL
    AND s.SourceSecondaryEmail IS NULL
    AND s.SourceMobile IS NOT NULL
GROUP BY
    REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
HAVING
    MAX(d.ContactID) IS NULL
    AND MAX(c.SourceID) IS NULL;
GO

-- Adding new contacts identified by mobile phones with empty emails (ID and Mobile in ContactMobile)

INSERT ContactMobile
    ( ID
    , Mobile
    )
SELECT
    c.ID
    , MIN(s.SourceMobile) AS Mobile
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    INNER JOIN Contacts c ON c.SourceID = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
    LEFT OUTER JOIN ContactMobile m ON m.ID = c.ID
GROUP BY
    c.ID
    , REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
HAVING
    MAX(m.ID) IS NULL;
GO

-- =====
-- Discovering existing contacts by unique mobile phones in all sources
-- Existing duplicated mobile phones in Contacts must be resolved manually
-- Phone numbers are normalized to digits

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    SourceContacts s
    INNER JOIN (
        -- Selects unique mobile phones with ContactID
        SELECT
            s.SourceMobile
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceMobile
                , s.ContactID
            FROM
                (
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , d.ContactID
                    FROM
                        SourceContacts s
                        LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceMobile IS NOT NULL
                    UNION
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.Mobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , s.ID AS ContactID
                    FROM
                        ContactMobile s
                    WHERE
                        s.Mobile IS NOT NULL
                ) s
            GROUP BY
                s.SourceMobile
                , s.ContactID
            ) s
        GROUP BY
            s.SourceMobile
        HAVING
            COUNT(*) = 1
    ) t ON t.SourceMobile = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO
-- =====

-- Updating LinkedIn API contacts
-- LinkedIn API data do not contain emails
-- Data are linked using first and last names if the names are unique in LinkedIn CSV data

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    SourceContacts s
    INNER JOIN (
        SELECT
            s.SourceFirstName
            , s.SourceLastName
            , MAX(d.ContactID) AS ContactID
        FROM
            SourceContacts s
            LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
        WHERE
            s.[Source] = ''LinkedInCSV''
        GROUP BY
            s.SourceFirstName
            , s.SourceLastName
        HAVING
            COUNT(*) = 1
    ) t ON t.SourceFirstName = s.SourceFirstName AND t.SourceLastName = s.SourceLastName
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    s.[Source] = ''LinkedIn''
    AND t.ContactID IS NOT NULL
    AND d.SourceID IS NULL;
GO

-- Inserting names for new contacts

INSERT ContactNames (ID, FirstName, LastName)
SELECT
    d.ContactID
    , MIN(s.SourceFirstName) AS FirstName
    , MIN(s.SourceLastName) AS LastName
FROM
    SourceContacts s
    INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN ContactNames c ON c.ID = d.ContactID
WHERE
    s.SourceFirstName IS NOT NULL
GROUP BY
    d.ContactID
HAVING
    MAX(c.ID) IS NULL
    AND d.ContactID IS NOT NULL;
GO

-- Inserting mobile numbers if not exist

INSERT ContactMobile (ID, Mobile)
SELECT
    d.ContactID
    , MIN(s.SourceMobile) AS Mobile
FROM
    SourceContacts s
    INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN ContactMobile c ON c.ID = d.ContactID
WHERE
    s.SourceMobile IS NOT NULL
GROUP BY
    d.ContactID
HAVING
    MAX(c.ID) IS NULL;
GO

-- Inserting new countries from SourceContacts

INSERT Countries
    (CountryCode, CountryName)
SELECT
    s.SourceCountryCode AS CountryCode
    , MIN(t.SourceLocationName) AS CountryName              -- Min LocationName for all with min length
FROM
    (
        SELECT
            s.SourceCountryCode
            , MIN(LEN(s.SourceLocationName)) AS [Length]    -- Min LocationName length
        FROM
            SourceContacts s
        WHERE
            s.SourceCountryCode IS NOT NULL
        GROUP BY
            s.SourceCountryCode                             -- All country codes
    ) s

    INNER JOIN (
        SELECT
            s.SourceCountryCode
            , s.SourceLocationName                          -- Default country name as LocationName
            , LEN(s.SourceLocationName) AS [Length]         -- with minimal length
        FROM
            SourceContacts s
        GROUP BY
            s.SourceCountryCode
            , s.SourceLocationName
    ) t ON t.SourceCountryCode = s.SourceCountryCode AND t.[Length] = s.[Length]

    LEFT OUTER JOIN Countries c ON c.CountryCode = s.SourceCountryCode
WHERE
    c.CountryCode IS NULL
GROUP BY
    s.SourceCountryCode;
GO

-- Inserting new domains into Websites from SourceContacts if domains have 3 or more contacts

INSERT Websites
    (Domain, Website)
SELECT
    c.Domain AS Domain
    , ''www.'' + c.Domain AS Website
FROM
    (
        SELECT
            LOWER(SUBSTRING(c.SourceEmail, CHARINDEX(''@'', c.SourceEmail) + 1, 255)) AS Domain
        FROM
            SourceContacts c
        WHERE
            c.SourceEmail IS NOT NULL
            AND CHARINDEX(''@'', c.SourceEmail) > 1
        GROUP BY
            LOWER(SUBSTRING(c.SourceEmail, CHARINDEX(''@'', c.SourceEmail) + 1, 255))
        HAVING
            COUNT(*) > 2
    ) c
    LEFT OUTER JOIN Websites w ON w.Domain = c.Domain
WHERE
    w.Domain IS NULL;
GO

-- Inserting  new domains into Websites from Contacts if domains have 3 or more contacts

INSERT Websites
    (Domain, Website)
SELECT
    c.Domain AS Domain
    , ''www.'' + c.Domain AS Website
FROM
    (
        SELECT
            LOWER(SUBSTRING(c.Email, CHARINDEX(''@'', c.Email) + 1, 255)) AS Domain
        FROM
            ContactEmail c
        WHERE
            c.Email IS NOT NULL
            AND CHARINDEX(''@'', c.Email) > 1
        GROUP BY
            LOWER(SUBSTRING(c.Email, CHARINDEX(''@'', c.Email) + 1, 255))
        HAVING
            COUNT(*) > 2
    ) c
    LEFT OUTER JOIN Websites w ON w.Domain = c.Domain
WHERE
    w.Domain IS NULL;
GO
','Update Contacts','CODE','_Reload',11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'SourceContacts',NULL,'Actions','
-- Changing fields with non-printing characters only to NULL in SourceContacts

UPDATE SourceContacts SET SourceCompany = NULL   WHERE SourceCompany IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceCompany, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE SourceContacts SET SourceJobTitle = NULL  WHERE SourceJobTitle IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceJobTitle, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE SourceContacts SET SourceFirstName = NULL WHERE SourceFirstName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceFirstName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE SourceContacts SET SourceLastName = NULL  WHERE SourceLastName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceLastName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO

-- Changing fields with non-printing characters only to NULL in Contacts

UPDATE ContactCompany SET Company = NULL    WHERE Company IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(Company, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE ContactJobTitle SET JobTitle = NULL  WHERE JobTitle IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(JobTitle, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE ContactNames SET FirstName = NULL    WHERE FirstName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(FirstName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE ContactNames SET LastName = NULL     WHERE LastName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(LastName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO

-- Setting ContactID for new source contacts if SourceFirstName, SourceLastName, SourceJobTitle, and SourceCompany are the same (FirstName and LastName may be not unique)

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , v.ContactID
FROM
    SourceContacts s
    INNER JOIN SourceContacts t ON
        t.[Source] = s.[Source]
        AND t.SourceFirstName = s.SourceFirstName
        AND t.SourceLastName = s.SourceLastName
        AND t.SourceJobTitle = s.SourceJobTitle
        AND t.SourceCompany = s.SourceCompany
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN SourceContactID v ON v.[Source] = t.[Source] AND v.SourceID = t.SourceID
WHERE
    t.MergeDate < s.MergeDate
    AND v.ContactID IS NOT NULL    
    AND d.ContactID IS NULL;
GO

-- =====
-- Discovering existing contacts by unique FirstName and LastName in the same source (latest merged data are used)

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    t.[Source]
    , t.SourceID
    , d.ContactID
FROM
    (
        -- Selects unique FirstName, LastName in the last merged data in every Source
        SELECT
            s.[Source]
            , MAX(s.SourceID) AS SourceID
            , MAX(d.ContactID) AS ContactID
            , s.SourceFirstName
            , s.SourceLastName
        FROM
            SourceContacts s
            INNER JOIN (
                -- Selects the latest MergeDate for each FirstName, LastName in every Source
                SELECT
                    s.[Source]
                    , s.SourceFirstName
                    , s.SourceLastName
                    , MAX(s.MergeDate) AS LastMergeDate
                FROM
                    SourceContacts s
                GROUP BY
                    s.[Source]
                    , s.SourceFirstName
                    , s.SourceLastName
            ) t ON t.[Source] = s.[Source] AND t.SourceFirstName = s.SourceFirstName AND t.SourceLastName = s.SourceLastName
                AND t.LastMergeDate = s.MergeDate
            LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
        GROUP BY
            s.[Source]
            , s.SourceFirstName
            , s.SourceLastName
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON t.[Source] = s.[Source] AND t.SourceFirstName = s.SourceFirstName AND t.SourceLastName = s.SourceLastName
        AND t.SourceID <> s.SourceID    -- Source is the same and SourceID is different
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN SourceContactID v ON v.[Source] = t.[Source] AND v.SourceID = t.SourceID
WHERE
    d.ContactID IS NOT NULL
    AND t.ContactID IS NULL
    AND v.SourceID IS NULL;
GO

-- Discovering existing contacts by unique Emails in all sources
-- Existing duplicated emails in Contacts must be resolved manually

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceSecondaryEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO

-- Discovering existing contacts by unique mobile phones in all sources
-- Existing duplicated mobile phones in Contacts must be resolved manually
-- Phone numbers are normalized to digits

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    SourceContacts s
    INNER JOIN (
        -- Selects unique mobile phones with ContactID
        SELECT
            s.SourceMobile
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceMobile
                , s.ContactID
            FROM
                (
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , d.ContactID
                    FROM
                        SourceContacts s
                        LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceMobile IS NOT NULL
                    UNION
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.Mobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , s.ID AS ContactID
                    FROM
                        ContactMobile s
                    WHERE
                        s.Mobile IS NOT NULL
                ) s
            GROUP BY
                s.SourceMobile
                , s.ContactID
            ) s
        GROUP BY
            s.SourceMobile
        HAVING
            COUNT(*) = 1
    ) t ON t.SourceMobile = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO
-- =====

-- Adding new contacts identified by email (SourceID in Contacts)

INSERT INTO Contacts
    ( SourceID
    )
SELECT
    s.SourceEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN Contacts c ON c.SourceID = s.SourceEmail
WHERE
    s.IsJunk IS NULL
    AND s.SourceEmail IS NOT NULL
GROUP BY
    s.SourceEmail
HAVING
    MAX(d.ContactID) IS NULL
    AND MAX(c.SourceID) IS NULL;
GO

-- Adding new contacts identified by secondary email (SourceID in Contacts)

INSERT INTO Contacts
    ( SourceID
    )
SELECT
    s.SourceSecondaryEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN Contacts c ON c.SourceID = s.SourceSecondaryEmail
WHERE
    s.IsJunk IS NULL
    AND s.SourceEmail IS NULL
    AND s.SourceSecondaryEmail IS NOT NULL
GROUP BY
    s.SourceSecondaryEmail
HAVING
    MAX(d.ContactID) IS NULL
    AND MAX(c.SourceID) IS NULL;
GO

-- Adding new contacts identified by email (ID and Email in ContactEmail)

INSERT ContactEmail
    ( ID
    , Email
    )
SELECT
    c.ID
    , s.SourceEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    INNER JOIN Contacts c ON c.SourceID = s.SourceEmail
    LEFT OUTER JOIN ContactEmail e ON e.ID = c.ID
GROUP BY
    c.ID
    , s.SourceEmail
HAVING
    MAX(e.ID) IS NULL;
GO

-- Adding new contacts identified by secondary email (ID and Email in ContactEmail)

INSERT ContactEmail
    ( ID
    , Email
    )
SELECT
    c.ID
    , s.SourceSecondaryEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    INNER JOIN Contacts c ON c.SourceID = s.SourceSecondaryEmail
    LEFT OUTER JOIN ContactEmail e ON e.ID = c.ID
GROUP BY
    c.ID
    , s.SourceSecondaryEmail
HAVING
    MAX(e.ID) IS NULL;
GO

-- =====
-- Discovering existing contacts by unique Emails in all sources
-- Existing duplicated emails in Contacts must be resolved manually

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceSecondaryEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO
-- =====

-- Adding new contacts identified by mobile phones with empty emails (SourceID in Contacts)
-- Phone numbers are normalized to digits

INSERT INTO Contacts
    ( SourceID
    )
SELECT
    REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile2
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN Contacts c ON c.SourceID = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
WHERE
    s.IsJunk IS NULL
    AND s.SourceEmail IS NULL
    AND s.SourceSecondaryEmail IS NULL
    AND s.SourceMobile IS NOT NULL
GROUP BY
    REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
HAVING
    MAX(d.ContactID) IS NULL
    AND MAX(c.SourceID) IS NULL;
GO

-- Adding new contacts identified by mobile phones with empty emails (ID and Mobile in ContactMobile)

INSERT ContactMobile
    ( ID
    , Mobile
    )
SELECT
    c.ID
    , MIN(s.SourceMobile) AS Mobile
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    INNER JOIN Contacts c ON c.SourceID = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
    LEFT OUTER JOIN ContactMobile m ON m.ID = c.ID
GROUP BY
    c.ID
    , REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
HAVING
    MAX(m.ID) IS NULL;
GO

-- =====
-- Discovering existing contacts by unique mobile phones in all sources
-- Existing duplicated mobile phones in Contacts must be resolved manually
-- Phone numbers are normalized to digits

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    SourceContacts s
    INNER JOIN (
        -- Selects unique mobile phones with ContactID
        SELECT
            s.SourceMobile
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceMobile
                , s.ContactID
            FROM
                (
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , d.ContactID
                    FROM
                        SourceContacts s
                        LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceMobile IS NOT NULL
                    UNION
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.Mobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , s.ID AS ContactID
                    FROM
                        ContactMobile s
                    WHERE
                        s.Mobile IS NOT NULL
                ) s
            GROUP BY
                s.SourceMobile
                , s.ContactID
            ) s
        GROUP BY
            s.SourceMobile
        HAVING
            COUNT(*) = 1
    ) t ON t.SourceMobile = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO
-- =====

-- Updating LinkedIn API contacts
-- LinkedIn API data do not contain emails
-- Data are linked using first and last names if the names are unique in LinkedIn CSV data

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    SourceContacts s
    INNER JOIN (
        SELECT
            s.SourceFirstName
            , s.SourceLastName
            , MAX(d.ContactID) AS ContactID
        FROM
            SourceContacts s
            LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
        WHERE
            s.[Source] = ''LinkedInCSV''
        GROUP BY
            s.SourceFirstName
            , s.SourceLastName
        HAVING
            COUNT(*) = 1
    ) t ON t.SourceFirstName = s.SourceFirstName AND t.SourceLastName = s.SourceLastName
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    s.[Source] = ''LinkedIn''
    AND t.ContactID IS NOT NULL
    AND d.SourceID IS NULL;
GO

-- Inserting names for new contacts

INSERT ContactNames (ID, FirstName, LastName)
SELECT
    d.ContactID
    , MIN(s.SourceFirstName) AS FirstName
    , MIN(s.SourceLastName) AS LastName
FROM
    SourceContacts s
    INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN ContactNames c ON c.ID = d.ContactID
WHERE
    s.SourceFirstName IS NOT NULL
GROUP BY
    d.ContactID
HAVING
    MAX(c.ID) IS NULL
    AND d.ContactID IS NOT NULL;
GO

-- Inserting mobile numbers if not exist

INSERT ContactMobile (ID, Mobile)
SELECT
    d.ContactID
    , MIN(s.SourceMobile) AS Mobile
FROM
    SourceContacts s
    INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN ContactMobile c ON c.ID = d.ContactID
WHERE
    s.SourceMobile IS NOT NULL
GROUP BY
    d.ContactID
HAVING
    MAX(c.ID) IS NULL;
GO

-- Inserting new countries from SourceContacts

INSERT Countries
    (CountryCode, CountryName)
SELECT
    s.SourceCountryCode AS CountryCode
    , MIN(t.SourceLocationName) AS CountryName              -- Min LocationName for all with min length
FROM
    (
        SELECT
            s.SourceCountryCode
            , MIN(LEN(s.SourceLocationName)) AS [Length]    -- Min LocationName length
        FROM
            SourceContacts s
        WHERE
            s.SourceCountryCode IS NOT NULL
        GROUP BY
            s.SourceCountryCode                             -- All country codes
    ) s

    INNER JOIN (
        SELECT
            s.SourceCountryCode
            , s.SourceLocationName                          -- Default country name as LocationName
            , LEN(s.SourceLocationName) AS [Length]         -- with minimal length
        FROM
            SourceContacts s
        GROUP BY
            s.SourceCountryCode
            , s.SourceLocationName
    ) t ON t.SourceCountryCode = s.SourceCountryCode AND t.[Length] = s.[Length]

    LEFT OUTER JOIN Countries c ON c.CountryCode = s.SourceCountryCode
WHERE
    c.CountryCode IS NULL
GROUP BY
    s.SourceCountryCode;
GO

-- Inserting new domains into Websites from SourceContacts if domains have 3 or more contacts

INSERT Websites
    (Domain, Website)
SELECT
    c.Domain AS Domain
    , ''www.'' + c.Domain AS Website
FROM
    (
        SELECT
            LOWER(SUBSTRING(c.SourceEmail, CHARINDEX(''@'', c.SourceEmail) + 1, 255)) AS Domain
        FROM
            SourceContacts c
        WHERE
            c.SourceEmail IS NOT NULL
            AND CHARINDEX(''@'', c.SourceEmail) > 1
        GROUP BY
            LOWER(SUBSTRING(c.SourceEmail, CHARINDEX(''@'', c.SourceEmail) + 1, 255))
        HAVING
            COUNT(*) > 2
    ) c
    LEFT OUTER JOIN Websites w ON w.Domain = c.Domain
WHERE
    w.Domain IS NULL;
GO

-- Inserting  new domains into Websites from Contacts if domains have 3 or more contacts

INSERT Websites
    (Domain, Website)
SELECT
    c.Domain AS Domain
    , ''www.'' + c.Domain AS Website
FROM
    (
        SELECT
            LOWER(SUBSTRING(c.Email, CHARINDEX(''@'', c.Email) + 1, 255)) AS Domain
        FROM
            ContactEmail c
        WHERE
            c.Email IS NOT NULL
            AND CHARINDEX(''@'', c.Email) > 1
        GROUP BY
            LOWER(SUBSTRING(c.Email, CHARINDEX(''@'', c.Email) + 1, 255))
        HAVING
            COUNT(*) > 2
    ) c
    LEFT OUTER JOIN Websites w ON w.Domain = c.Domain
WHERE
    w.Domain IS NULL;
GO
','Update Contacts','CODE','_Reload',11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Websites',NULL,'Actions','
-- Changing fields with non-printing characters only to NULL in SourceContacts

UPDATE SourceContacts SET SourceCompany = NULL   WHERE SourceCompany IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceCompany, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE SourceContacts SET SourceJobTitle = NULL  WHERE SourceJobTitle IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceJobTitle, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE SourceContacts SET SourceFirstName = NULL WHERE SourceFirstName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceFirstName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE SourceContacts SET SourceLastName = NULL  WHERE SourceLastName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceLastName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO

-- Changing fields with non-printing characters only to NULL in Contacts

UPDATE ContactCompany SET Company = NULL    WHERE Company IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(Company, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE ContactJobTitle SET JobTitle = NULL  WHERE JobTitle IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(JobTitle, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE ContactNames SET FirstName = NULL    WHERE FirstName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(FirstName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE ContactNames SET LastName = NULL     WHERE LastName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(LastName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO

-- Setting ContactID for new source contacts if SourceFirstName, SourceLastName, SourceJobTitle, and SourceCompany are the same (FirstName and LastName may be not unique)

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , v.ContactID
FROM
    SourceContacts s
    INNER JOIN SourceContacts t ON
        t.[Source] = s.[Source]
        AND t.SourceFirstName = s.SourceFirstName
        AND t.SourceLastName = s.SourceLastName
        AND t.SourceJobTitle = s.SourceJobTitle
        AND t.SourceCompany = s.SourceCompany
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN SourceContactID v ON v.[Source] = t.[Source] AND v.SourceID = t.SourceID
WHERE
    t.MergeDate < s.MergeDate
    AND v.ContactID IS NOT NULL    
    AND d.ContactID IS NULL;
GO

-- =====
-- Discovering existing contacts by unique FirstName and LastName in the same source (latest merged data are used)

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    t.[Source]
    , t.SourceID
    , d.ContactID
FROM
    (
        -- Selects unique FirstName, LastName in the last merged data in every Source
        SELECT
            s.[Source]
            , MAX(s.SourceID) AS SourceID
            , MAX(d.ContactID) AS ContactID
            , s.SourceFirstName
            , s.SourceLastName
        FROM
            SourceContacts s
            INNER JOIN (
                -- Selects the latest MergeDate for each FirstName, LastName in every Source
                SELECT
                    s.[Source]
                    , s.SourceFirstName
                    , s.SourceLastName
                    , MAX(s.MergeDate) AS LastMergeDate
                FROM
                    SourceContacts s
                GROUP BY
                    s.[Source]
                    , s.SourceFirstName
                    , s.SourceLastName
            ) t ON t.[Source] = s.[Source] AND t.SourceFirstName = s.SourceFirstName AND t.SourceLastName = s.SourceLastName
                AND t.LastMergeDate = s.MergeDate
            LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
        GROUP BY
            s.[Source]
            , s.SourceFirstName
            , s.SourceLastName
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON t.[Source] = s.[Source] AND t.SourceFirstName = s.SourceFirstName AND t.SourceLastName = s.SourceLastName
        AND t.SourceID <> s.SourceID    -- Source is the same and SourceID is different
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN SourceContactID v ON v.[Source] = t.[Source] AND v.SourceID = t.SourceID
WHERE
    d.ContactID IS NOT NULL
    AND t.ContactID IS NULL
    AND v.SourceID IS NULL;
GO

-- Discovering existing contacts by unique Emails in all sources
-- Existing duplicated emails in Contacts must be resolved manually

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceSecondaryEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO

-- Discovering existing contacts by unique mobile phones in all sources
-- Existing duplicated mobile phones in Contacts must be resolved manually
-- Phone numbers are normalized to digits

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    SourceContacts s
    INNER JOIN (
        -- Selects unique mobile phones with ContactID
        SELECT
            s.SourceMobile
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceMobile
                , s.ContactID
            FROM
                (
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , d.ContactID
                    FROM
                        SourceContacts s
                        LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceMobile IS NOT NULL
                    UNION
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.Mobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , s.ID AS ContactID
                    FROM
                        ContactMobile s
                    WHERE
                        s.Mobile IS NOT NULL
                ) s
            GROUP BY
                s.SourceMobile
                , s.ContactID
            ) s
        GROUP BY
            s.SourceMobile
        HAVING
            COUNT(*) = 1
    ) t ON t.SourceMobile = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO
-- =====

-- Adding new contacts identified by email (SourceID in Contacts)

INSERT INTO Contacts
    ( SourceID
    )
SELECT
    s.SourceEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN Contacts c ON c.SourceID = s.SourceEmail
WHERE
    s.IsJunk IS NULL
    AND s.SourceEmail IS NOT NULL
GROUP BY
    s.SourceEmail
HAVING
    MAX(d.ContactID) IS NULL
    AND MAX(c.SourceID) IS NULL;
GO

-- Adding new contacts identified by secondary email (SourceID in Contacts)

INSERT INTO Contacts
    ( SourceID
    )
SELECT
    s.SourceSecondaryEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN Contacts c ON c.SourceID = s.SourceSecondaryEmail
WHERE
    s.IsJunk IS NULL
    AND s.SourceEmail IS NULL
    AND s.SourceSecondaryEmail IS NOT NULL
GROUP BY
    s.SourceSecondaryEmail
HAVING
    MAX(d.ContactID) IS NULL
    AND MAX(c.SourceID) IS NULL;
GO

-- Adding new contacts identified by email (ID and Email in ContactEmail)

INSERT ContactEmail
    ( ID
    , Email
    )
SELECT
    c.ID
    , s.SourceEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    INNER JOIN Contacts c ON c.SourceID = s.SourceEmail
    LEFT OUTER JOIN ContactEmail e ON e.ID = c.ID
GROUP BY
    c.ID
    , s.SourceEmail
HAVING
    MAX(e.ID) IS NULL;
GO

-- Adding new contacts identified by secondary email (ID and Email in ContactEmail)

INSERT ContactEmail
    ( ID
    , Email
    )
SELECT
    c.ID
    , s.SourceSecondaryEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    INNER JOIN Contacts c ON c.SourceID = s.SourceSecondaryEmail
    LEFT OUTER JOIN ContactEmail e ON e.ID = c.ID
GROUP BY
    c.ID
    , s.SourceSecondaryEmail
HAVING
    MAX(e.ID) IS NULL;
GO

-- =====
-- Discovering existing contacts by unique Emails in all sources
-- Existing duplicated emails in Contacts must be resolved manually

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceSecondaryEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO
-- =====

-- Adding new contacts identified by mobile phones with empty emails (SourceID in Contacts)
-- Phone numbers are normalized to digits

INSERT INTO Contacts
    ( SourceID
    )
SELECT
    REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile2
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN Contacts c ON c.SourceID = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
WHERE
    s.IsJunk IS NULL
    AND s.SourceEmail IS NULL
    AND s.SourceSecondaryEmail IS NULL
    AND s.SourceMobile IS NOT NULL
GROUP BY
    REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
HAVING
    MAX(d.ContactID) IS NULL
    AND MAX(c.SourceID) IS NULL;
GO

-- Adding new contacts identified by mobile phones with empty emails (ID and Mobile in ContactMobile)

INSERT ContactMobile
    ( ID
    , Mobile
    )
SELECT
    c.ID
    , MIN(s.SourceMobile) AS Mobile
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    INNER JOIN Contacts c ON c.SourceID = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
    LEFT OUTER JOIN ContactMobile m ON m.ID = c.ID
GROUP BY
    c.ID
    , REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
HAVING
    MAX(m.ID) IS NULL;
GO

-- =====
-- Discovering existing contacts by unique mobile phones in all sources
-- Existing duplicated mobile phones in Contacts must be resolved manually
-- Phone numbers are normalized to digits

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    SourceContacts s
    INNER JOIN (
        -- Selects unique mobile phones with ContactID
        SELECT
            s.SourceMobile
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceMobile
                , s.ContactID
            FROM
                (
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , d.ContactID
                    FROM
                        SourceContacts s
                        LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceMobile IS NOT NULL
                    UNION
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.Mobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , s.ID AS ContactID
                    FROM
                        ContactMobile s
                    WHERE
                        s.Mobile IS NOT NULL
                ) s
            GROUP BY
                s.SourceMobile
                , s.ContactID
            ) s
        GROUP BY
            s.SourceMobile
        HAVING
            COUNT(*) = 1
    ) t ON t.SourceMobile = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO
-- =====

-- Updating LinkedIn API contacts
-- LinkedIn API data do not contain emails
-- Data are linked using first and last names if the names are unique in LinkedIn CSV data

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    SourceContacts s
    INNER JOIN (
        SELECT
            s.SourceFirstName
            , s.SourceLastName
            , MAX(d.ContactID) AS ContactID
        FROM
            SourceContacts s
            LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
        WHERE
            s.[Source] = ''LinkedInCSV''
        GROUP BY
            s.SourceFirstName
            , s.SourceLastName
        HAVING
            COUNT(*) = 1
    ) t ON t.SourceFirstName = s.SourceFirstName AND t.SourceLastName = s.SourceLastName
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    s.[Source] = ''LinkedIn''
    AND t.ContactID IS NOT NULL
    AND d.SourceID IS NULL;
GO

-- Inserting names for new contacts

INSERT ContactNames (ID, FirstName, LastName)
SELECT
    d.ContactID
    , MIN(s.SourceFirstName) AS FirstName
    , MIN(s.SourceLastName) AS LastName
FROM
    SourceContacts s
    INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN ContactNames c ON c.ID = d.ContactID
WHERE
    s.SourceFirstName IS NOT NULL
GROUP BY
    d.ContactID
HAVING
    MAX(c.ID) IS NULL
    AND d.ContactID IS NOT NULL;
GO

-- Inserting mobile numbers if not exist

INSERT ContactMobile (ID, Mobile)
SELECT
    d.ContactID
    , MIN(s.SourceMobile) AS Mobile
FROM
    SourceContacts s
    INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN ContactMobile c ON c.ID = d.ContactID
WHERE
    s.SourceMobile IS NOT NULL
GROUP BY
    d.ContactID
HAVING
    MAX(c.ID) IS NULL;
GO

-- Inserting new countries from SourceContacts

INSERT Countries
    (CountryCode, CountryName)
SELECT
    s.SourceCountryCode AS CountryCode
    , MIN(t.SourceLocationName) AS CountryName              -- Min LocationName for all with min length
FROM
    (
        SELECT
            s.SourceCountryCode
            , MIN(LEN(s.SourceLocationName)) AS [Length]    -- Min LocationName length
        FROM
            SourceContacts s
        WHERE
            s.SourceCountryCode IS NOT NULL
        GROUP BY
            s.SourceCountryCode                             -- All country codes
    ) s

    INNER JOIN (
        SELECT
            s.SourceCountryCode
            , s.SourceLocationName                          -- Default country name as LocationName
            , LEN(s.SourceLocationName) AS [Length]         -- with minimal length
        FROM
            SourceContacts s
        GROUP BY
            s.SourceCountryCode
            , s.SourceLocationName
    ) t ON t.SourceCountryCode = s.SourceCountryCode AND t.[Length] = s.[Length]

    LEFT OUTER JOIN Countries c ON c.CountryCode = s.SourceCountryCode
WHERE
    c.CountryCode IS NULL
GROUP BY
    s.SourceCountryCode;
GO

-- Inserting new domains into Websites from SourceContacts if domains have 3 or more contacts

INSERT Websites
    (Domain, Website)
SELECT
    c.Domain AS Domain
    , ''www.'' + c.Domain AS Website
FROM
    (
        SELECT
            LOWER(SUBSTRING(c.SourceEmail, CHARINDEX(''@'', c.SourceEmail) + 1, 255)) AS Domain
        FROM
            SourceContacts c
        WHERE
            c.SourceEmail IS NOT NULL
            AND CHARINDEX(''@'', c.SourceEmail) > 1
        GROUP BY
            LOWER(SUBSTRING(c.SourceEmail, CHARINDEX(''@'', c.SourceEmail) + 1, 255))
        HAVING
            COUNT(*) > 2
    ) c
    LEFT OUTER JOIN Websites w ON w.Domain = c.Domain
WHERE
    w.Domain IS NULL;
GO

-- Inserting  new domains into Websites from Contacts if domains have 3 or more contacts

INSERT Websites
    (Domain, Website)
SELECT
    c.Domain AS Domain
    , ''www.'' + c.Domain AS Website
FROM
    (
        SELECT
            LOWER(SUBSTRING(c.Email, CHARINDEX(''@'', c.Email) + 1, 255)) AS Domain
        FROM
            ContactEmail c
        WHERE
            c.Email IS NOT NULL
            AND CHARINDEX(''@'', c.Email) > 1
        GROUP BY
            LOWER(SUBSTRING(c.Email, CHARINDEX(''@'', c.Email) + 1, 255))
        HAVING
            COUNT(*) > 2
    ) c
    LEFT OUTER JOIN Websites w ON w.Domain = c.Domain
WHERE
    w.Domain IS NULL;
GO
','Update Contacts','CODE','_Reload',10,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Websites',NULL,'Actions',NULL,'MenuSeparator1','MENUSEPARATOR',NULL,20,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Websites',NULL,'Actions','UPDATE Websites
SET
    Checked = 1
WHERE
    Checked IS NULL','Update All as Checked','CODE','_Reload',21,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Websites',NULL,'ContextMenu','http://{Website}','Open Website {Website}','HTTP',NULL,11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Websites',NULL,'Actions','
-- Changing fields with non-printing characters only to NULL in SourceContacts

UPDATE SourceContacts SET SourceCompany = NULL   WHERE SourceCompany IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceCompany, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE SourceContacts SET SourceJobTitle = NULL  WHERE SourceJobTitle IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceJobTitle, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE SourceContacts SET SourceFirstName = NULL WHERE SourceFirstName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceFirstName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE SourceContacts SET SourceLastName = NULL  WHERE SourceLastName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceLastName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO

-- Changing fields with non-printing characters only to NULL in Contacts

UPDATE ContactCompany SET Company = NULL    WHERE Company IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(Company, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE ContactJobTitle SET JobTitle = NULL  WHERE JobTitle IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(JobTitle, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE ContactNames SET FirstName = NULL    WHERE FirstName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(FirstName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE ContactNames SET LastName = NULL     WHERE LastName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(LastName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO

-- Setting ContactID for new source contacts if SourceFirstName, SourceLastName, SourceJobTitle, and SourceCompany are the same (FirstName and LastName may be not unique)

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , v.ContactID
FROM
    SourceContacts s
    INNER JOIN SourceContacts t ON
        t.[Source] = s.[Source]
        AND t.SourceFirstName = s.SourceFirstName
        AND t.SourceLastName = s.SourceLastName
        AND t.SourceJobTitle = s.SourceJobTitle
        AND t.SourceCompany = s.SourceCompany
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN SourceContactID v ON v.[Source] = t.[Source] AND v.SourceID = t.SourceID
WHERE
    t.MergeDate < s.MergeDate
    AND v.ContactID IS NOT NULL    
    AND d.ContactID IS NULL;
GO

-- =====
-- Discovering existing contacts by unique FirstName and LastName in the same source (latest merged data are used)

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    t.[Source]
    , t.SourceID
    , d.ContactID
FROM
    (
        -- Selects unique FirstName, LastName in the last merged data in every Source
        SELECT
            s.[Source]
            , MAX(s.SourceID) AS SourceID
            , MAX(d.ContactID) AS ContactID
            , s.SourceFirstName
            , s.SourceLastName
        FROM
            SourceContacts s
            INNER JOIN (
                -- Selects the latest MergeDate for each FirstName, LastName in every Source
                SELECT
                    s.[Source]
                    , s.SourceFirstName
                    , s.SourceLastName
                    , MAX(s.MergeDate) AS LastMergeDate
                FROM
                    SourceContacts s
                GROUP BY
                    s.[Source]
                    , s.SourceFirstName
                    , s.SourceLastName
            ) t ON t.[Source] = s.[Source] AND t.SourceFirstName = s.SourceFirstName AND t.SourceLastName = s.SourceLastName
                AND t.LastMergeDate = s.MergeDate
            LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
        GROUP BY
            s.[Source]
            , s.SourceFirstName
            , s.SourceLastName
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON t.[Source] = s.[Source] AND t.SourceFirstName = s.SourceFirstName AND t.SourceLastName = s.SourceLastName
        AND t.SourceID <> s.SourceID    -- Source is the same and SourceID is different
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN SourceContactID v ON v.[Source] = t.[Source] AND v.SourceID = t.SourceID
WHERE
    d.ContactID IS NOT NULL
    AND t.ContactID IS NULL
    AND v.SourceID IS NULL;
GO

-- Discovering existing contacts by unique Emails in all sources
-- Existing duplicated emails in Contacts must be resolved manually

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceSecondaryEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO

-- Discovering existing contacts by unique mobile phones in all sources
-- Existing duplicated mobile phones in Contacts must be resolved manually
-- Phone numbers are normalized to digits

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    SourceContacts s
    INNER JOIN (
        -- Selects unique mobile phones with ContactID
        SELECT
            s.SourceMobile
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceMobile
                , s.ContactID
            FROM
                (
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , d.ContactID
                    FROM
                        SourceContacts s
                        LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceMobile IS NOT NULL
                    UNION
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.Mobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , s.ID AS ContactID
                    FROM
                        ContactMobile s
                    WHERE
                        s.Mobile IS NOT NULL
                ) s
            GROUP BY
                s.SourceMobile
                , s.ContactID
            ) s
        GROUP BY
            s.SourceMobile
        HAVING
            COUNT(*) = 1
    ) t ON t.SourceMobile = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO
-- =====

-- Adding new contacts identified by email (SourceID in Contacts)

INSERT INTO Contacts
    ( SourceID
    )
SELECT
    s.SourceEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN Contacts c ON c.SourceID = s.SourceEmail
WHERE
    s.IsJunk IS NULL
    AND s.SourceEmail IS NOT NULL
GROUP BY
    s.SourceEmail
HAVING
    MAX(d.ContactID) IS NULL
    AND MAX(c.SourceID) IS NULL;
GO

-- Adding new contacts identified by secondary email (SourceID in Contacts)

INSERT INTO Contacts
    ( SourceID
    )
SELECT
    s.SourceSecondaryEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN Contacts c ON c.SourceID = s.SourceSecondaryEmail
WHERE
    s.IsJunk IS NULL
    AND s.SourceEmail IS NULL
    AND s.SourceSecondaryEmail IS NOT NULL
GROUP BY
    s.SourceSecondaryEmail
HAVING
    MAX(d.ContactID) IS NULL
    AND MAX(c.SourceID) IS NULL;
GO

-- Adding new contacts identified by email (ID and Email in ContactEmail)

INSERT ContactEmail
    ( ID
    , Email
    )
SELECT
    c.ID
    , s.SourceEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    INNER JOIN Contacts c ON c.SourceID = s.SourceEmail
    LEFT OUTER JOIN ContactEmail e ON e.ID = c.ID
GROUP BY
    c.ID
    , s.SourceEmail
HAVING
    MAX(e.ID) IS NULL;
GO

-- Adding new contacts identified by secondary email (ID and Email in ContactEmail)

INSERT ContactEmail
    ( ID
    , Email
    )
SELECT
    c.ID
    , s.SourceSecondaryEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    INNER JOIN Contacts c ON c.SourceID = s.SourceSecondaryEmail
    LEFT OUTER JOIN ContactEmail e ON e.ID = c.ID
GROUP BY
    c.ID
    , s.SourceSecondaryEmail
HAVING
    MAX(e.ID) IS NULL;
GO

-- =====
-- Discovering existing contacts by unique Emails in all sources
-- Existing duplicated emails in Contacts must be resolved manually

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceSecondaryEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO
-- =====

-- Adding new contacts identified by mobile phones with empty emails (SourceID in Contacts)
-- Phone numbers are normalized to digits

INSERT INTO Contacts
    ( SourceID
    )
SELECT
    REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile2
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN Contacts c ON c.SourceID = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
WHERE
    s.IsJunk IS NULL
    AND s.SourceEmail IS NULL
    AND s.SourceSecondaryEmail IS NULL
    AND s.SourceMobile IS NOT NULL
GROUP BY
    REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
HAVING
    MAX(d.ContactID) IS NULL
    AND MAX(c.SourceID) IS NULL;
GO

-- Adding new contacts identified by mobile phones with empty emails (ID and Mobile in ContactMobile)

INSERT ContactMobile
    ( ID
    , Mobile
    )
SELECT
    c.ID
    , MIN(s.SourceMobile) AS Mobile
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    INNER JOIN Contacts c ON c.SourceID = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
    LEFT OUTER JOIN ContactMobile m ON m.ID = c.ID
GROUP BY
    c.ID
    , REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
HAVING
    MAX(m.ID) IS NULL;
GO

-- =====
-- Discovering existing contacts by unique mobile phones in all sources
-- Existing duplicated mobile phones in Contacts must be resolved manually
-- Phone numbers are normalized to digits

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    SourceContacts s
    INNER JOIN (
        -- Selects unique mobile phones with ContactID
        SELECT
            s.SourceMobile
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceMobile
                , s.ContactID
            FROM
                (
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , d.ContactID
                    FROM
                        SourceContacts s
                        LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceMobile IS NOT NULL
                    UNION
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.Mobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , s.ID AS ContactID
                    FROM
                        ContactMobile s
                    WHERE
                        s.Mobile IS NOT NULL
                ) s
            GROUP BY
                s.SourceMobile
                , s.ContactID
            ) s
        GROUP BY
            s.SourceMobile
        HAVING
            COUNT(*) = 1
    ) t ON t.SourceMobile = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO
-- =====

-- Updating LinkedIn API contacts
-- LinkedIn API data do not contain emails
-- Data are linked using first and last names if the names are unique in LinkedIn CSV data

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    SourceContacts s
    INNER JOIN (
        SELECT
            s.SourceFirstName
            , s.SourceLastName
            , MAX(d.ContactID) AS ContactID
        FROM
            SourceContacts s
            LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
        WHERE
            s.[Source] = ''LinkedInCSV''
        GROUP BY
            s.SourceFirstName
            , s.SourceLastName
        HAVING
            COUNT(*) = 1
    ) t ON t.SourceFirstName = s.SourceFirstName AND t.SourceLastName = s.SourceLastName
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    s.[Source] = ''LinkedIn''
    AND t.ContactID IS NOT NULL
    AND d.SourceID IS NULL;
GO

-- Inserting names for new contacts

INSERT ContactNames (ID, FirstName, LastName)
SELECT
    d.ContactID
    , MIN(s.SourceFirstName) AS FirstName
    , MIN(s.SourceLastName) AS LastName
FROM
    SourceContacts s
    INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN ContactNames c ON c.ID = d.ContactID
WHERE
    s.SourceFirstName IS NOT NULL
GROUP BY
    d.ContactID
HAVING
    MAX(c.ID) IS NULL
    AND d.ContactID IS NOT NULL;
GO

-- Inserting mobile numbers if not exist

INSERT ContactMobile (ID, Mobile)
SELECT
    d.ContactID
    , MIN(s.SourceMobile) AS Mobile
FROM
    SourceContacts s
    INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN ContactMobile c ON c.ID = d.ContactID
WHERE
    s.SourceMobile IS NOT NULL
GROUP BY
    d.ContactID
HAVING
    MAX(c.ID) IS NULL;
GO

-- Inserting new countries from SourceContacts

INSERT Countries
    (CountryCode, CountryName)
SELECT
    s.SourceCountryCode AS CountryCode
    , MIN(t.SourceLocationName) AS CountryName              -- Min LocationName for all with min length
FROM
    (
        SELECT
            s.SourceCountryCode
            , MIN(LEN(s.SourceLocationName)) AS [Length]    -- Min LocationName length
        FROM
            SourceContacts s
        WHERE
            s.SourceCountryCode IS NOT NULL
        GROUP BY
            s.SourceCountryCode                             -- All country codes
    ) s

    INNER JOIN (
        SELECT
            s.SourceCountryCode
            , s.SourceLocationName                          -- Default country name as LocationName
            , LEN(s.SourceLocationName) AS [Length]         -- with minimal length
        FROM
            SourceContacts s
        GROUP BY
            s.SourceCountryCode
            , s.SourceLocationName
    ) t ON t.SourceCountryCode = s.SourceCountryCode AND t.[Length] = s.[Length]

    LEFT OUTER JOIN Countries c ON c.CountryCode = s.SourceCountryCode
WHERE
    c.CountryCode IS NULL
GROUP BY
    s.SourceCountryCode;
GO

-- Inserting new domains into Websites from SourceContacts if domains have 3 or more contacts

INSERT Websites
    (Domain, Website)
SELECT
    c.Domain AS Domain
    , ''www.'' + c.Domain AS Website
FROM
    (
        SELECT
            LOWER(SUBSTRING(c.SourceEmail, CHARINDEX(''@'', c.SourceEmail) + 1, 255)) AS Domain
        FROM
            SourceContacts c
        WHERE
            c.SourceEmail IS NOT NULL
            AND CHARINDEX(''@'', c.SourceEmail) > 1
        GROUP BY
            LOWER(SUBSTRING(c.SourceEmail, CHARINDEX(''@'', c.SourceEmail) + 1, 255))
        HAVING
            COUNT(*) > 2
    ) c
    LEFT OUTER JOIN Websites w ON w.Domain = c.Domain
WHERE
    w.Domain IS NULL;
GO

-- Inserting  new domains into Websites from Contacts if domains have 3 or more contacts

INSERT Websites
    (Domain, Website)
SELECT
    c.Domain AS Domain
    , ''www.'' + c.Domain AS Website
FROM
    (
        SELECT
            LOWER(SUBSTRING(c.Email, CHARINDEX(''@'', c.Email) + 1, 255)) AS Domain
        FROM
            ContactEmail c
        WHERE
            c.Email IS NOT NULL
            AND CHARINDEX(''@'', c.Email) > 1
        GROUP BY
            LOWER(SUBSTRING(c.Email, CHARINDEX(''@'', c.Email) + 1, 255))
        HAVING
            COUNT(*) > 2
    ) c
    LEFT OUTER JOIN Websites w ON w.Domain = c.Domain
WHERE
    w.Domain IS NULL;
GO
','Update Contacts','CODE','_Reload',10,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Websites',NULL,'Actions',NULL,'MenuSeparator','MENUSEPARATOR',NULL,20,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Websites',NULL,'Actions','UPDATE Websites
SET
    Checked = 1
WHERE
    Checked IS NULL','Update All as Checked','CODE','_Reload',21,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Websites',NULL,'ContextMenu','http://{Website}','Open Website {Website}','HTTP',NULL,11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Countries',NULL,'Actions','
-- Changing fields with non-printing characters only to NULL in SourceContacts

UPDATE SourceContacts SET SourceCompany = NULL   WHERE SourceCompany IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceCompany, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE SourceContacts SET SourceJobTitle = NULL  WHERE SourceJobTitle IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceJobTitle, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE SourceContacts SET SourceFirstName = NULL WHERE SourceFirstName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceFirstName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE SourceContacts SET SourceLastName = NULL  WHERE SourceLastName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceLastName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO

-- Changing fields with non-printing characters only to NULL in Contacts

UPDATE ContactCompany SET Company = NULL    WHERE Company IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(Company, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE ContactJobTitle SET JobTitle = NULL  WHERE JobTitle IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(JobTitle, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE ContactNames SET FirstName = NULL    WHERE FirstName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(FirstName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE ContactNames SET LastName = NULL     WHERE LastName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(LastName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO

-- Setting ContactID for new source contacts if SourceFirstName, SourceLastName, SourceJobTitle, and SourceCompany are the same (FirstName and LastName may be not unique)

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , v.ContactID
FROM
    SourceContacts s
    INNER JOIN SourceContacts t ON
        t.[Source] = s.[Source]
        AND t.SourceFirstName = s.SourceFirstName
        AND t.SourceLastName = s.SourceLastName
        AND t.SourceJobTitle = s.SourceJobTitle
        AND t.SourceCompany = s.SourceCompany
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN SourceContactID v ON v.[Source] = t.[Source] AND v.SourceID = t.SourceID
WHERE
    t.MergeDate < s.MergeDate
    AND v.ContactID IS NOT NULL    
    AND d.ContactID IS NULL;
GO

-- =====
-- Discovering existing contacts by unique FirstName and LastName in the same source (latest merged data are used)

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    t.[Source]
    , t.SourceID
    , d.ContactID
FROM
    (
        -- Selects unique FirstName, LastName in the last merged data in every Source
        SELECT
            s.[Source]
            , MAX(s.SourceID) AS SourceID
            , MAX(d.ContactID) AS ContactID
            , s.SourceFirstName
            , s.SourceLastName
        FROM
            SourceContacts s
            INNER JOIN (
                -- Selects the latest MergeDate for each FirstName, LastName in every Source
                SELECT
                    s.[Source]
                    , s.SourceFirstName
                    , s.SourceLastName
                    , MAX(s.MergeDate) AS LastMergeDate
                FROM
                    SourceContacts s
                GROUP BY
                    s.[Source]
                    , s.SourceFirstName
                    , s.SourceLastName
            ) t ON t.[Source] = s.[Source] AND t.SourceFirstName = s.SourceFirstName AND t.SourceLastName = s.SourceLastName
                AND t.LastMergeDate = s.MergeDate
            LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
        GROUP BY
            s.[Source]
            , s.SourceFirstName
            , s.SourceLastName
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON t.[Source] = s.[Source] AND t.SourceFirstName = s.SourceFirstName AND t.SourceLastName = s.SourceLastName
        AND t.SourceID <> s.SourceID    -- Source is the same and SourceID is different
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN SourceContactID v ON v.[Source] = t.[Source] AND v.SourceID = t.SourceID
WHERE
    d.ContactID IS NOT NULL
    AND t.ContactID IS NULL
    AND v.SourceID IS NULL;
GO

-- Discovering existing contacts by unique Emails in all sources
-- Existing duplicated emails in Contacts must be resolved manually

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceSecondaryEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO

-- Discovering existing contacts by unique mobile phones in all sources
-- Existing duplicated mobile phones in Contacts must be resolved manually
-- Phone numbers are normalized to digits

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    SourceContacts s
    INNER JOIN (
        -- Selects unique mobile phones with ContactID
        SELECT
            s.SourceMobile
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceMobile
                , s.ContactID
            FROM
                (
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , d.ContactID
                    FROM
                        SourceContacts s
                        LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceMobile IS NOT NULL
                    UNION
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.Mobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , s.ID AS ContactID
                    FROM
                        ContactMobile s
                    WHERE
                        s.Mobile IS NOT NULL
                ) s
            GROUP BY
                s.SourceMobile
                , s.ContactID
            ) s
        GROUP BY
            s.SourceMobile
        HAVING
            COUNT(*) = 1
    ) t ON t.SourceMobile = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO
-- =====

-- Adding new contacts identified by email (SourceID in Contacts)

INSERT INTO Contacts
    ( SourceID
    )
SELECT
    s.SourceEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN Contacts c ON c.SourceID = s.SourceEmail
WHERE
    s.IsJunk IS NULL
    AND s.SourceEmail IS NOT NULL
GROUP BY
    s.SourceEmail
HAVING
    MAX(d.ContactID) IS NULL
    AND MAX(c.SourceID) IS NULL;
GO

-- Adding new contacts identified by secondary email (SourceID in Contacts)

INSERT INTO Contacts
    ( SourceID
    )
SELECT
    s.SourceSecondaryEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN Contacts c ON c.SourceID = s.SourceSecondaryEmail
WHERE
    s.IsJunk IS NULL
    AND s.SourceEmail IS NULL
    AND s.SourceSecondaryEmail IS NOT NULL
GROUP BY
    s.SourceSecondaryEmail
HAVING
    MAX(d.ContactID) IS NULL
    AND MAX(c.SourceID) IS NULL;
GO

-- Adding new contacts identified by email (ID and Email in ContactEmail)

INSERT ContactEmail
    ( ID
    , Email
    )
SELECT
    c.ID
    , s.SourceEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    INNER JOIN Contacts c ON c.SourceID = s.SourceEmail
    LEFT OUTER JOIN ContactEmail e ON e.ID = c.ID
GROUP BY
    c.ID
    , s.SourceEmail
HAVING
    MAX(e.ID) IS NULL;
GO

-- Adding new contacts identified by secondary email (ID and Email in ContactEmail)

INSERT ContactEmail
    ( ID
    , Email
    )
SELECT
    c.ID
    , s.SourceSecondaryEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    INNER JOIN Contacts c ON c.SourceID = s.SourceSecondaryEmail
    LEFT OUTER JOIN ContactEmail e ON e.ID = c.ID
GROUP BY
    c.ID
    , s.SourceSecondaryEmail
HAVING
    MAX(e.ID) IS NULL;
GO

-- =====
-- Discovering existing contacts by unique Emails in all sources
-- Existing duplicated emails in Contacts must be resolved manually

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceSecondaryEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO
-- =====

-- Adding new contacts identified by mobile phones with empty emails (SourceID in Contacts)
-- Phone numbers are normalized to digits

INSERT INTO Contacts
    ( SourceID
    )
SELECT
    REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile2
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN Contacts c ON c.SourceID = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
WHERE
    s.IsJunk IS NULL
    AND s.SourceEmail IS NULL
    AND s.SourceSecondaryEmail IS NULL
    AND s.SourceMobile IS NOT NULL
GROUP BY
    REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
HAVING
    MAX(d.ContactID) IS NULL
    AND MAX(c.SourceID) IS NULL;
GO

-- Adding new contacts identified by mobile phones with empty emails (ID and Mobile in ContactMobile)

INSERT ContactMobile
    ( ID
    , Mobile
    )
SELECT
    c.ID
    , MIN(s.SourceMobile) AS Mobile
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    INNER JOIN Contacts c ON c.SourceID = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
    LEFT OUTER JOIN ContactMobile m ON m.ID = c.ID
GROUP BY
    c.ID
    , REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
HAVING
    MAX(m.ID) IS NULL;
GO

-- =====
-- Discovering existing contacts by unique mobile phones in all sources
-- Existing duplicated mobile phones in Contacts must be resolved manually
-- Phone numbers are normalized to digits

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    SourceContacts s
    INNER JOIN (
        -- Selects unique mobile phones with ContactID
        SELECT
            s.SourceMobile
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceMobile
                , s.ContactID
            FROM
                (
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , d.ContactID
                    FROM
                        SourceContacts s
                        LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceMobile IS NOT NULL
                    UNION
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.Mobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , s.ID AS ContactID
                    FROM
                        ContactMobile s
                    WHERE
                        s.Mobile IS NOT NULL
                ) s
            GROUP BY
                s.SourceMobile
                , s.ContactID
            ) s
        GROUP BY
            s.SourceMobile
        HAVING
            COUNT(*) = 1
    ) t ON t.SourceMobile = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO
-- =====

-- Updating LinkedIn API contacts
-- LinkedIn API data do not contain emails
-- Data are linked using first and last names if the names are unique in LinkedIn CSV data

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    SourceContacts s
    INNER JOIN (
        SELECT
            s.SourceFirstName
            , s.SourceLastName
            , MAX(d.ContactID) AS ContactID
        FROM
            SourceContacts s
            LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
        WHERE
            s.[Source] = ''LinkedInCSV''
        GROUP BY
            s.SourceFirstName
            , s.SourceLastName
        HAVING
            COUNT(*) = 1
    ) t ON t.SourceFirstName = s.SourceFirstName AND t.SourceLastName = s.SourceLastName
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    s.[Source] = ''LinkedIn''
    AND t.ContactID IS NOT NULL
    AND d.SourceID IS NULL;
GO

-- Inserting names for new contacts

INSERT ContactNames (ID, FirstName, LastName)
SELECT
    d.ContactID
    , MIN(s.SourceFirstName) AS FirstName
    , MIN(s.SourceLastName) AS LastName
FROM
    SourceContacts s
    INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN ContactNames c ON c.ID = d.ContactID
WHERE
    s.SourceFirstName IS NOT NULL
GROUP BY
    d.ContactID
HAVING
    MAX(c.ID) IS NULL
    AND d.ContactID IS NOT NULL;
GO

-- Inserting mobile numbers if not exist

INSERT ContactMobile (ID, Mobile)
SELECT
    d.ContactID
    , MIN(s.SourceMobile) AS Mobile
FROM
    SourceContacts s
    INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN ContactMobile c ON c.ID = d.ContactID
WHERE
    s.SourceMobile IS NOT NULL
GROUP BY
    d.ContactID
HAVING
    MAX(c.ID) IS NULL;
GO

-- Inserting new countries from SourceContacts

INSERT Countries
    (CountryCode, CountryName)
SELECT
    s.SourceCountryCode AS CountryCode
    , MIN(t.SourceLocationName) AS CountryName              -- Min LocationName for all with min length
FROM
    (
        SELECT
            s.SourceCountryCode
            , MIN(LEN(s.SourceLocationName)) AS [Length]    -- Min LocationName length
        FROM
            SourceContacts s
        WHERE
            s.SourceCountryCode IS NOT NULL
        GROUP BY
            s.SourceCountryCode                             -- All country codes
    ) s

    INNER JOIN (
        SELECT
            s.SourceCountryCode
            , s.SourceLocationName                          -- Default country name as LocationName
            , LEN(s.SourceLocationName) AS [Length]         -- with minimal length
        FROM
            SourceContacts s
        GROUP BY
            s.SourceCountryCode
            , s.SourceLocationName
    ) t ON t.SourceCountryCode = s.SourceCountryCode AND t.[Length] = s.[Length]

    LEFT OUTER JOIN Countries c ON c.CountryCode = s.SourceCountryCode
WHERE
    c.CountryCode IS NULL
GROUP BY
    s.SourceCountryCode;
GO

-- Inserting new domains into Websites from SourceContacts if domains have 3 or more contacts

INSERT Websites
    (Domain, Website)
SELECT
    c.Domain AS Domain
    , ''www.'' + c.Domain AS Website
FROM
    (
        SELECT
            LOWER(SUBSTRING(c.SourceEmail, CHARINDEX(''@'', c.SourceEmail) + 1, 255)) AS Domain
        FROM
            SourceContacts c
        WHERE
            c.SourceEmail IS NOT NULL
            AND CHARINDEX(''@'', c.SourceEmail) > 1
        GROUP BY
            LOWER(SUBSTRING(c.SourceEmail, CHARINDEX(''@'', c.SourceEmail) + 1, 255))
        HAVING
            COUNT(*) > 2
    ) c
    LEFT OUTER JOIN Websites w ON w.Domain = c.Domain
WHERE
    w.Domain IS NULL;
GO

-- Inserting  new domains into Websites from Contacts if domains have 3 or more contacts

INSERT Websites
    (Domain, Website)
SELECT
    c.Domain AS Domain
    , ''www.'' + c.Domain AS Website
FROM
    (
        SELECT
            LOWER(SUBSTRING(c.Email, CHARINDEX(''@'', c.Email) + 1, 255)) AS Domain
        FROM
            ContactEmail c
        WHERE
            c.Email IS NOT NULL
            AND CHARINDEX(''@'', c.Email) > 1
        GROUP BY
            LOWER(SUBSTRING(c.Email, CHARINDEX(''@'', c.Email) + 1, 255))
        HAVING
            COUNT(*) > 2
    ) c
    LEFT OUTER JOIN Websites w ON w.Domain = c.Domain
WHERE
    w.Domain IS NULL;
GO
','Update Contacts','CODE','_Reload',11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Countries',NULL,'Actions',NULL,'MenuSeparator1','MENUSEPARATOR',NULL,20,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Countries',NULL,'Actions','UPDATE Countries
SET
    Checked = 1
WHERE
    Checked IS NULL','Update All as Checked','CODE','_Reload',21,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Countries',NULL,'Actions','
-- Changing fields with non-printing characters only to NULL in SourceContacts

UPDATE SourceContacts SET SourceCompany = NULL   WHERE SourceCompany IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceCompany, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE SourceContacts SET SourceJobTitle = NULL  WHERE SourceJobTitle IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceJobTitle, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE SourceContacts SET SourceFirstName = NULL WHERE SourceFirstName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceFirstName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE SourceContacts SET SourceLastName = NULL  WHERE SourceLastName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(SourceLastName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO

-- Changing fields with non-printing characters only to NULL in Contacts

UPDATE ContactCompany SET Company = NULL    WHERE Company IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(Company, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE ContactJobTitle SET JobTitle = NULL  WHERE JobTitle IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(JobTitle, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE ContactNames SET FirstName = NULL    WHERE FirstName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(FirstName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO
UPDATE ContactNames SET LastName = NULL     WHERE LastName IS NOT NULL AND RTRIM(REPLACE(REPLACE(REPLACE(REPLACE(LastName, ''?'', ''''), ''"'', ''''), '','', ''''), '' '', '''')) = '''';
GO

-- Setting ContactID for new source contacts if SourceFirstName, SourceLastName, SourceJobTitle, and SourceCompany are the same (FirstName and LastName may be not unique)

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , v.ContactID
FROM
    SourceContacts s
    INNER JOIN SourceContacts t ON
        t.[Source] = s.[Source]
        AND t.SourceFirstName = s.SourceFirstName
        AND t.SourceLastName = s.SourceLastName
        AND t.SourceJobTitle = s.SourceJobTitle
        AND t.SourceCompany = s.SourceCompany
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN SourceContactID v ON v.[Source] = t.[Source] AND v.SourceID = t.SourceID
WHERE
    t.MergeDate < s.MergeDate
    AND v.ContactID IS NOT NULL    
    AND d.ContactID IS NULL;
GO

-- =====
-- Discovering existing contacts by unique FirstName and LastName in the same source (latest merged data are used)

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    t.[Source]
    , t.SourceID
    , d.ContactID
FROM
    (
        -- Selects unique FirstName, LastName in the last merged data in every Source
        SELECT
            s.[Source]
            , MAX(s.SourceID) AS SourceID
            , MAX(d.ContactID) AS ContactID
            , s.SourceFirstName
            , s.SourceLastName
        FROM
            SourceContacts s
            INNER JOIN (
                -- Selects the latest MergeDate for each FirstName, LastName in every Source
                SELECT
                    s.[Source]
                    , s.SourceFirstName
                    , s.SourceLastName
                    , MAX(s.MergeDate) AS LastMergeDate
                FROM
                    SourceContacts s
                GROUP BY
                    s.[Source]
                    , s.SourceFirstName
                    , s.SourceLastName
            ) t ON t.[Source] = s.[Source] AND t.SourceFirstName = s.SourceFirstName AND t.SourceLastName = s.SourceLastName
                AND t.LastMergeDate = s.MergeDate
            LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
        GROUP BY
            s.[Source]
            , s.SourceFirstName
            , s.SourceLastName
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON t.[Source] = s.[Source] AND t.SourceFirstName = s.SourceFirstName AND t.SourceLastName = s.SourceLastName
        AND t.SourceID <> s.SourceID    -- Source is the same and SourceID is different
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN SourceContactID v ON v.[Source] = t.[Source] AND v.SourceID = t.SourceID
WHERE
    d.ContactID IS NOT NULL
    AND t.ContactID IS NULL
    AND v.SourceID IS NULL;
GO

-- Discovering existing contacts by unique Emails in all sources
-- Existing duplicated emails in Contacts must be resolved manually

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceSecondaryEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO

-- Discovering existing contacts by unique mobile phones in all sources
-- Existing duplicated mobile phones in Contacts must be resolved manually
-- Phone numbers are normalized to digits

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    SourceContacts s
    INNER JOIN (
        -- Selects unique mobile phones with ContactID
        SELECT
            s.SourceMobile
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceMobile
                , s.ContactID
            FROM
                (
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , d.ContactID
                    FROM
                        SourceContacts s
                        LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceMobile IS NOT NULL
                    UNION
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.Mobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , s.ID AS ContactID
                    FROM
                        ContactMobile s
                    WHERE
                        s.Mobile IS NOT NULL
                ) s
            GROUP BY
                s.SourceMobile
                , s.ContactID
            ) s
        GROUP BY
            s.SourceMobile
        HAVING
            COUNT(*) = 1
    ) t ON t.SourceMobile = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO
-- =====

-- Adding new contacts identified by email (SourceID in Contacts)

INSERT INTO Contacts
    ( SourceID
    )
SELECT
    s.SourceEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN Contacts c ON c.SourceID = s.SourceEmail
WHERE
    s.IsJunk IS NULL
    AND s.SourceEmail IS NOT NULL
GROUP BY
    s.SourceEmail
HAVING
    MAX(d.ContactID) IS NULL
    AND MAX(c.SourceID) IS NULL;
GO

-- Adding new contacts identified by secondary email (SourceID in Contacts)

INSERT INTO Contacts
    ( SourceID
    )
SELECT
    s.SourceSecondaryEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN Contacts c ON c.SourceID = s.SourceSecondaryEmail
WHERE
    s.IsJunk IS NULL
    AND s.SourceEmail IS NULL
    AND s.SourceSecondaryEmail IS NOT NULL
GROUP BY
    s.SourceSecondaryEmail
HAVING
    MAX(d.ContactID) IS NULL
    AND MAX(c.SourceID) IS NULL;
GO

-- Adding new contacts identified by email (ID and Email in ContactEmail)

INSERT ContactEmail
    ( ID
    , Email
    )
SELECT
    c.ID
    , s.SourceEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    INNER JOIN Contacts c ON c.SourceID = s.SourceEmail
    LEFT OUTER JOIN ContactEmail e ON e.ID = c.ID
GROUP BY
    c.ID
    , s.SourceEmail
HAVING
    MAX(e.ID) IS NULL;
GO

-- Adding new contacts identified by secondary email (ID and Email in ContactEmail)

INSERT ContactEmail
    ( ID
    , Email
    )
SELECT
    c.ID
    , s.SourceSecondaryEmail
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    INNER JOIN Contacts c ON c.SourceID = s.SourceSecondaryEmail
    LEFT OUTER JOIN ContactEmail e ON e.ID = c.ID
GROUP BY
    c.ID
    , s.SourceSecondaryEmail
HAVING
    MAX(e.ID) IS NULL;
GO

-- =====
-- Discovering existing contacts by unique Emails in all sources
-- Existing duplicated emails in Contacts must be resolved manually

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    (
        -- Selects unique Emails with ContactID
        SELECT
            s.SourceEmail
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceEmail
                , s.ContactID
            FROM
                (
                    -- Select Emails and SecondaryEmails with ContactID
                    SELECT
                        s.SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceEmail IS NOT NULL
                    UNION
                    SELECT
                        s.SourceSecondaryEmail AS SourceEmail
                        , d.ContactID
                    FROM
                        SourceContacts s
                        INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceSecondaryEmail IS NOT NULL
                    UNION
                    SELECT
                        s.Email AS SourceEmail
                        , s.ID AS ContactID
                    FROM
                        ContactEmail s
                    WHERE
                        s.Email IS NOT NULL
                ) s
            GROUP BY
                s.SourceEmail
                , s.ContactID
            ) s
        GROUP BY
            s.SourceEmail
        HAVING
            COUNT(*) = 1
    ) t
    INNER JOIN SourceContacts s ON s.SourceSecondaryEmail = t.SourceEmail
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO
-- =====

-- Adding new contacts identified by mobile phones with empty emails (SourceID in Contacts)
-- Phone numbers are normalized to digits

INSERT INTO Contacts
    ( SourceID
    )
SELECT
    REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile2
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN Contacts c ON c.SourceID = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
WHERE
    s.IsJunk IS NULL
    AND s.SourceEmail IS NULL
    AND s.SourceSecondaryEmail IS NULL
    AND s.SourceMobile IS NOT NULL
GROUP BY
    REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
HAVING
    MAX(d.ContactID) IS NULL
    AND MAX(c.SourceID) IS NULL;
GO

-- Adding new contacts identified by mobile phones with empty emails (ID and Mobile in ContactMobile)

INSERT ContactMobile
    ( ID
    , Mobile
    )
SELECT
    c.ID
    , MIN(s.SourceMobile) AS Mobile
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    INNER JOIN Contacts c ON c.SourceID = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
    LEFT OUTER JOIN ContactMobile m ON m.ID = c.ID
GROUP BY
    c.ID
    , REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
HAVING
    MAX(m.ID) IS NULL;
GO

-- =====
-- Discovering existing contacts by unique mobile phones in all sources
-- Existing duplicated mobile phones in Contacts must be resolved manually
-- Phone numbers are normalized to digits

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    SourceContacts s
    INNER JOIN (
        -- Selects unique mobile phones with ContactID
        SELECT
            s.SourceMobile
            , MAX(s.ContactID) AS ContactID
        FROM
            (
            SELECT
                s.SourceMobile
                , s.ContactID
            FROM
                (
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , d.ContactID
                    FROM
                        SourceContacts s
                        LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
                    WHERE
                        d.ContactID IS NOT NULL
                        AND s.SourceMobile IS NOT NULL
                    UNION
                    SELECT
                        REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.Mobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''') AS SourceMobile
                        , s.ID AS ContactID
                    FROM
                        ContactMobile s
                    WHERE
                        s.Mobile IS NOT NULL
                ) s
            GROUP BY
                s.SourceMobile
                , s.ContactID
            ) s
        GROUP BY
            s.SourceMobile
        HAVING
            COUNT(*) = 1
    ) t ON t.SourceMobile = REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(s.SourceMobile, ''-'', ''''), ''.'', ''''), ''('', ''''), '')'', ''''), '' '', ''''), ''+'', '''')
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.SourceID IS NULL;
GO
-- =====

-- Updating LinkedIn API contacts
-- LinkedIn API data do not contain emails
-- Data are linked using first and last names if the names are unique in LinkedIn CSV data

INSERT INTO SourceContactID
    ( [Source]
    , SourceID
    , ContactID
    )
SELECT
    s.[Source]
    , s.SourceID
    , t.ContactID
FROM
    SourceContacts s
    INNER JOIN (
        SELECT
            s.SourceFirstName
            , s.SourceLastName
            , MAX(d.ContactID) AS ContactID
        FROM
            SourceContacts s
            LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
        WHERE
            s.[Source] = ''LinkedInCSV''
        GROUP BY
            s.SourceFirstName
            , s.SourceLastName
        HAVING
            COUNT(*) = 1
    ) t ON t.SourceFirstName = s.SourceFirstName AND t.SourceLastName = s.SourceLastName
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    s.[Source] = ''LinkedIn''
    AND t.ContactID IS NOT NULL
    AND d.SourceID IS NULL;
GO

-- Inserting names for new contacts

INSERT ContactNames (ID, FirstName, LastName)
SELECT
    d.ContactID
    , MIN(s.SourceFirstName) AS FirstName
    , MIN(s.SourceLastName) AS LastName
FROM
    SourceContacts s
    INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN ContactNames c ON c.ID = d.ContactID
WHERE
    s.SourceFirstName IS NOT NULL
GROUP BY
    d.ContactID
HAVING
    MAX(c.ID) IS NULL
    AND d.ContactID IS NOT NULL;
GO

-- Inserting mobile numbers if not exist

INSERT ContactMobile (ID, Mobile)
SELECT
    d.ContactID
    , MIN(s.SourceMobile) AS Mobile
FROM
    SourceContacts s
    INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    LEFT OUTER JOIN ContactMobile c ON c.ID = d.ContactID
WHERE
    s.SourceMobile IS NOT NULL
GROUP BY
    d.ContactID
HAVING
    MAX(c.ID) IS NULL;
GO

-- Inserting new countries from SourceContacts

INSERT Countries
    (CountryCode, CountryName)
SELECT
    s.SourceCountryCode AS CountryCode
    , MIN(t.SourceLocationName) AS CountryName              -- Min LocationName for all with min length
FROM
    (
        SELECT
            s.SourceCountryCode
            , MIN(LEN(s.SourceLocationName)) AS [Length]    -- Min LocationName length
        FROM
            SourceContacts s
        WHERE
            s.SourceCountryCode IS NOT NULL
        GROUP BY
            s.SourceCountryCode                             -- All country codes
    ) s

    INNER JOIN (
        SELECT
            s.SourceCountryCode
            , s.SourceLocationName                          -- Default country name as LocationName
            , LEN(s.SourceLocationName) AS [Length]         -- with minimal length
        FROM
            SourceContacts s
        GROUP BY
            s.SourceCountryCode
            , s.SourceLocationName
    ) t ON t.SourceCountryCode = s.SourceCountryCode AND t.[Length] = s.[Length]

    LEFT OUTER JOIN Countries c ON c.CountryCode = s.SourceCountryCode
WHERE
    c.CountryCode IS NULL
GROUP BY
    s.SourceCountryCode;
GO

-- Inserting new domains into Websites from SourceContacts if domains have 3 or more contacts

INSERT Websites
    (Domain, Website)
SELECT
    c.Domain AS Domain
    , ''www.'' + c.Domain AS Website
FROM
    (
        SELECT
            LOWER(SUBSTRING(c.SourceEmail, CHARINDEX(''@'', c.SourceEmail) + 1, 255)) AS Domain
        FROM
            SourceContacts c
        WHERE
            c.SourceEmail IS NOT NULL
            AND CHARINDEX(''@'', c.SourceEmail) > 1
        GROUP BY
            LOWER(SUBSTRING(c.SourceEmail, CHARINDEX(''@'', c.SourceEmail) + 1, 255))
        HAVING
            COUNT(*) > 2
    ) c
    LEFT OUTER JOIN Websites w ON w.Domain = c.Domain
WHERE
    w.Domain IS NULL;
GO

-- Inserting  new domains into Websites from Contacts if domains have 3 or more contacts

INSERT Websites
    (Domain, Website)
SELECT
    c.Domain AS Domain
    , ''www.'' + c.Domain AS Website
FROM
    (
        SELECT
            LOWER(SUBSTRING(c.Email, CHARINDEX(''@'', c.Email) + 1, 255)) AS Domain
        FROM
            ContactEmail c
        WHERE
            c.Email IS NOT NULL
            AND CHARINDEX(''@'', c.Email) > 1
        GROUP BY
            LOWER(SUBSTRING(c.Email, CHARINDEX(''@'', c.Email) + 1, 255))
        HAVING
            COUNT(*) > 2
    ) c
    LEFT OUTER JOIN Websites w ON w.Domain = c.Domain
WHERE
    w.Domain IS NULL;
GO
','Update Contacts','CODE','_Reload',11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Countries',NULL,'Actions',NULL,'MenuSeparator','MENUSEPARATOR',NULL,20,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Countries',NULL,'Actions','UPDATE Countries
SET
    Checked = 1
WHERE
    Checked IS NULL','Update All as Checked','CODE','_Reload',21,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Contacts',NULL,'Actions',NULL,'MenuSeparator1','MENUSEPARATOR',NULL,20,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Contacts',NULL,'Actions','UPDATE Contacts
SET
    ContactStatus = 3
WHERE
    ContactStatus = 2','Update All as Checked','CODE','_Reload',22,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Contacts',NULL,'ContextMenu','http://{Website}','Open Website {Website}','HTTP',NULL,11,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Contacts',NULL,'ContextMenu','{LinkedInProfileUrl}','Open LinkedIn Profile','HTTP',NULL,12,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Contacts',NULL,'ContextMenu','{GooglePlusProfileUrl}','Open GooglePlus Profile','HTTP',NULL,13,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Contacts',NULL,'ContextMenu',NULL,'MenuSeparator1','MENUSEPARATOR',NULL,20,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Contacts',NULL,'ContextMenu','mailto:{Email}&subject=Thanks for the connection&body=Hello {FirstName},%0A','Create New E-mail - Thanks for the connection','CMD',NULL,21,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Contacts',NULL,'ContextMenu','https://www.google.com/search?as_q={Company}','Google Search - {Company}','HTTP',NULL,31,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Contacts',NULL,'ContextMenu','https://www.google.com/search?as_q={FirstName}+{LastName}','Google Search - {FirstName} {LastName}','HTTP',NULL,31,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Contacts',NULL,'SelectionChange','-- Selects source contacts with the specified ContactID
SELECT
    s.Source
    , s.SourceID
    , s.MergeDate
    , s.IsJunk
    , d.ContactID
    , s.SourceFirstName
    , s.SourceLastName
    , s.SourceEmail
    , s.SourceSecondaryEmail
    , s.SourceMobile
    , s.SourcePhone
    , s.SourceCompany
    , s.SourceJobTitle
    , s.SourceHeadline
    , s.SourceIndustry
    , s.SourceLocationName
    , s.SourceCountryCode
    , s.SourceProfileUrl    
FROM
    SourceContacts s
    INNER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.ContactID = @ID
UNION ALL
-- Selects source contacts with en empty ContactID if ContactID is NULL
SELECT
    s.Source
    , s.SourceID
    , s.MergeDate
    , s.IsJunk
    , d.ContactID
    , s.SourceFirstName
    , s.SourceLastName
    , s.SourceEmail
    , s.SourceSecondaryEmail
    , s.SourceMobile
    , s.SourcePhone
    , s.SourceCompany
    , s.SourceJobTitle
    , s.SourceHeadline
    , s.SourceIndustry
    , s.SourceLocationName
    , s.SourceCountryCode
    , s.SourceProfileUrl    
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
WHERE
    d.ContactID IS NULL
    AND @ID IS NULL
UNION ALL
-- Selects source contacts with the LastName as contact''s LastName and an empty ContactID
SELECT
    s.Source
    , s.SourceID
    , s.MergeDate
    , s.IsJunk
    , d.ContactID
    , s.SourceFirstName
    , s.SourceLastName
    , s.SourceEmail
    , s.SourceSecondaryEmail
    , s.SourceMobile
    , s.SourcePhone
    , s.SourceCompany
    , s.SourceJobTitle
    , s.SourceHeadline
    , s.SourceIndustry
    , s.SourceLocationName
    , s.SourceCountryCode
    , s.SourceProfileUrl    
FROM
    SourceContacts s
    LEFT OUTER JOIN SourceContactID d ON d.[Source] = s.[Source] AND d.SourceID = s.SourceID
    INNER JOIN ContactNames n ON n.LastName = s.SourceLastName
WHERE
    d.ContactID IS NULL
    AND n.ID = @ID','Source Contacts By ContactID','CODE','ContactDetails _TopWindow',NULL,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Websites',NULL,'SelectionChange','SELECT
    c.ID
    , NULL AS ContactStatus
    , CASE WHEN dn.ID IS NULL THEN NULL ELSE DoubleNameCount END AS IsDoubleName
    , c.ContactCategory
    , n.FirstName
    , n.LastName
    , e.Email
    , m.Mobile
    , p.Phone
    , r.Country
    , LOWER(SUBSTRING(e.email, CHARINDEX(''@'', e.email) + 1, 255)) AS Domain
    , w.Website
    , y.Company
    , i.JobTitle
    , l2.SourceHeadline AS LinkedInHeadline
    , l2.SourceIndustry AS Industry
    , l2.SourceLocationName AS LocationName
    , l2.SourceProfileUrl AS LinkedInProfileUrl
    , g2.SourceProfileUrl AS GooglePlusProfileUrl
    , c.String1
    , c.String2
    , c.String3
    , c.Number1
    , c.Number2
    , c.Number3
FROM
    (
        SELECT
            c.ID
            , l2.[Source] AS lSource
            , MIN(l2.SourceID) AS lSourceID
            , g2.[Source] AS gSource
            , MIN(g2.SourceID) AS gSourceID
        FROM
            Contacts c
            LEFT OUTER JOIN SourceContactID l1 ON l1.ContactID = c.ID AND l1.[Source] = ''LinkedIn''
            LEFT OUTER JOIN SourceContacts l2 ON l2.[Source] = l1.[Source] AND l2.SourceID = l1.SourceID
            LEFT OUTER JOIN SourceContactID g1 ON g1.ContactID = c.ID AND g1.[Source] = ''GoogleCSV''
            LEFT OUTER JOIN SourceContacts g2 ON g2.[Source] = g1.[Source] AND g2.SourceID = g1.SourceID
        GROUP BY
            c.ID
            , l2.[Source]
            , g2.[Source]
    ) t
    INNER JOIN Contacts c ON c.ID = t.ID

    LEFT OUTER JOIN ContactNames    n ON n.ID = c.ID
    LEFT OUTER JOIN ContactEmail    e ON e.ID = c.ID
    LEFT OUTER JOIN ContactMobile   m ON m.ID = c.ID
    LEFT OUTER JOIN ContactPhone    p ON p.ID = c.ID
    LEFT OUTER JOIN ContactCountry  r ON r.ID = c.ID
    LEFT OUTER JOIN ContactWebsite  w ON w.ID = c.ID
    LEFT OUTER JOIN ContactCompany  y ON y.ID = c.ID
    LEFT OUTER JOIN ContactJobTitle    i ON i.ID = c.ID

    LEFT OUTER JOIN SourceContacts l2 ON l2.[Source] = t.lSource AND l2.SourceID = t.lSourceID
    LEFT OUTER JOIN SourceContacts g2 ON g2.[Source] = t.gSource AND g2.SourceID = t.gSourceID
    
    LEFT OUTER JOIN (
        SELECT TOP 1000000
            c.ID
            , t.DoubleNameCount
        FROM
            (
                SELECT
                    c.FirstName
                    , c.LastName
                    , COUNT(*) AS DoubleNameCount
                FROM
                    ContactNames c
                WHERE
                    c.FirstName IS NOT NULL
                GROUP BY
                    c.FirstName
                    , c.LastName
                HAVING
                    COUNT(*) > 1
            ) t
            LEFT OUTER JOIN ContactNames c ON t.FirstName = c.FirstName AND t.LastName = c.LastName
        ORDER BY
            c.ID
    ) dn ON dn.ID = c.ID

    LEFT OUTER JOIN Websites ws ON ws.Domain = @Domain AND ws.Website = w.Website
WHERE
    LOWER(SUBSTRING(e.Email, CHARINDEX(''@'', e.Email) + 1, 255)) = @Domain','Contacts By Domain','CODE','WebsiteDetails _TopWindow',NULL,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Countries',NULL,'SelectionChange','SELECT
    c.ID
    , NULL AS ContactStatus
    , CASE WHEN dn.ID IS NULL THEN NULL ELSE DoubleNameCount END AS IsDoubleName
    , c.ContactCategory
    , n.FirstName
    , n.LastName
    , e.Email
    , m.Mobile
    , p.Phone
    , r.Country
    , LOWER(SUBSTRING(e.email, CHARINDEX(''@'', e.email) + 1, 255)) AS Domain
    , w.Website
    , y.Company
    , i.JobTitle
    , l2.SourceHeadline AS LinkedInHeadline
    , l2.SourceIndustry AS Industry
    , l2.SourceLocationName AS LocationName
    , l2.SourceProfileUrl AS LinkedInProfileUrl
    , g2.SourceProfileUrl AS GooglePlusProfileUrl
    , c.String1
    , c.String2
    , c.String3
    , c.Number1
    , c.Number2
    , c.Number3
FROM
    (
        SELECT
            c.ID
            , l2.[Source] AS lSource
            , MIN(l2.SourceID) AS lSourceID
            , g2.[Source] AS gSource
            , MIN(g2.SourceID) AS gSourceID
        FROM
            Contacts c
            LEFT OUTER JOIN SourceContactID l1 ON l1.ContactID = c.ID AND l1.[Source] = ''LinkedIn''
            LEFT OUTER JOIN SourceContacts l2 ON l2.[Source] = l1.[Source] AND l2.SourceID = l1.SourceID
            LEFT OUTER JOIN SourceContactID g1 ON g1.ContactID = c.ID AND g1.[Source] = ''GoogleCSV''
            LEFT OUTER JOIN SourceContacts g2 ON g2.[Source] = g1.[Source] AND g2.SourceID = g1.SourceID
        GROUP BY
            c.ID
            , l2.[Source]
            , g2.[Source]
    ) t
    INNER JOIN Contacts c ON c.ID = t.ID

    LEFT OUTER JOIN ContactNames    n ON n.ID = c.ID
    LEFT OUTER JOIN ContactEmail    e ON e.ID = c.ID
    LEFT OUTER JOIN ContactMobile   m ON m.ID = c.ID
    LEFT OUTER JOIN ContactPhone    p ON p.ID = c.ID
    LEFT OUTER JOIN ContactCountry  r ON r.ID = c.ID
    LEFT OUTER JOIN ContactWebsite  w ON w.ID = c.ID
    LEFT OUTER JOIN ContactCompany  y ON y.ID = c.ID
    LEFT OUTER JOIN ContactJobTitle    i ON i.ID = c.ID

    LEFT OUTER JOIN SourceContacts l2 ON l2.[Source] = t.lSource AND l2.SourceID = t.lSourceID
    LEFT OUTER JOIN SourceContacts g2 ON g2.[Source] = t.gSource AND g2.SourceID = t.gSourceID
    
    LEFT OUTER JOIN (
        SELECT TOP 1000000
            c.ID
            , t.DoubleNameCount
        FROM
            (
                SELECT
                    c.FirstName
                    , c.LastName
                    , COUNT(*) AS DoubleNameCount
                FROM
                    ContactNames c
                WHERE
                    c.FirstName IS NOT NULL
                GROUP BY
                    c.FirstName
                    , c.LastName
                HAVING
                    COUNT(*) > 1
            ) t
            LEFT OUTER JOIN ContactNames c ON t.FirstName = c.FirstName AND t.LastName = c.LastName
        ORDER BY
            c.ID
    ) dn ON dn.ID = c.ID

WHERE
    r.Country = @CountryName','Contacts By Country','CODE','CountryDetails _TopWindow',21,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Contacts',NULL,'Actions',NULL,'MenuSeparator','MENUSEPARATOR',NULL,50,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'SourceContacts',NULL,'Actions',NULL,'MenuSeparator','MENUSEPARATOR',NULL,50,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('http','Google - API',NULL,'Actions',NULL,'MenuSeparator','MENUSEPARATOR',NULL,50,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('http','LinkedIn - API',NULL,'Actions',NULL,'MenuSeparator','MENUSEPARATOR',NULL,50,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('http','Yahoo! - API',NULL,'Actions',NULL,'MenuSeparator','MENUSEPARATOR',NULL,50,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('text','Google - CSV',NULL,'Actions',NULL,'MenuSeparator','MENUSEPARATOR',NULL,50,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('text','LinkedIn - CSV',NULL,'Actions',NULL,'MenuSeparator','MENUSEPARATOR',NULL,50,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Countries',NULL,'Actions',NULL,'MenuSeparator2','MENUSEPARATOR',NULL,50,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('text','Outlook - CSV',NULL,'Actions',NULL,'MenuSeparator','MENUSEPARATOR',NULL,50,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('text','Yahoo! - HTM',NULL,'Actions',NULL,'MenuSeparator','MENUSEPARATOR',NULL,50,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Source Contacts',NULL,'Actions',NULL,'MenuSeparator','MENUSEPARATOR',NULL,50,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Contacts',NULL,'Actions','http://www.savetodb.com/social-contact-sqlce-database.htm/{DataLanguage}/','Online Help, Questions, and Suggestions','HTTP',NULL,51,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Countries',NULL,'Actions','http://www.savetodb.com/social-contact-sqlce-database.htm/{DataLanguage}/','Online Help, Questions, and Suggestions','HTTP',NULL,51,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'SourceContacts',NULL,'Actions','http://www.savetodb.com/social-contact-sqlce-database.htm/{DataLanguage}/','Online Help, Questions, and Suggestions','HTTP',NULL,51,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'Websites',NULL,'Actions','http://www.savetodb.com/social-contact-sqlce-database.htm/{DataLanguage}/','Online Help, Questions, and Suggestions','HTTP',NULL,51,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('http','Google - API',NULL,'Actions','http://www.savetodb.com/social-contact-sqlce-database.htm/{DataLanguage}/','Online Help, Questions, and Suggestions','HTTP',NULL,51,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('http','LinkedIn - API',NULL,'Actions','http://www.savetodb.com/social-contact-sqlce-database.htm/{DataLanguage}/','Online Help, Questions, and Suggestions','HTTP',NULL,51,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('http','Yahoo! - API',NULL,'Actions','http://www.savetodb.com/social-contact-sqlce-database.htm/{DataLanguage}/','Online Help, Questions, and Suggestions','HTTP',NULL,51,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('text','Google - CSV',NULL,'Actions','http://www.savetodb.com/social-contact-sqlce-database.htm/{DataLanguage}/','Online Help, Questions, and Suggestions','HTTP',NULL,51,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('text','LinkedIn - CSV',NULL,'Actions','http://www.savetodb.com/social-contact-sqlce-database.htm/{DataLanguage}/','Online Help, Questions, and Suggestions','HTTP',NULL,51,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('text','Outlook - CSV',NULL,'Actions','http://www.savetodb.com/social-contact-sqlce-database.htm/{DataLanguage}/','Online Help, Questions, and Suggestions','HTTP',NULL,51,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES ('text','Yahoo! - HTM',NULL,'Actions','http://www.savetodb.com/social-contact-sqlce-database.htm/{DataLanguage}/','Online Help, Questions, and Suggestions','HTTP',NULL,51,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Contacts',NULL,'Actions','http://www.savetodb.com/social-contact-sqlce-database.htm/{DataLanguage}/','Online Help, Questions, and Suggestions','HTTP',NULL,51,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Countries',NULL,'Actions','http://www.savetodb.com/social-contact-sqlce-database.htm/{DataLanguage}/','Online Help, Questions, and Suggestions','HTTP',NULL,51,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Source Contacts',NULL,'Actions','http://www.savetodb.com/social-contact-sqlce-database.htm/{DataLanguage}/','Online Help, Questions, and Suggestions','HTTP',NULL,51,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Websites',NULL,'Actions','http://www.savetodb.com/social-contact-sqlce-database.htm/{DataLanguage}/','Online Help, Questions, and Suggestions','HTTP',NULL,51,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Contacts',NULL,'Actions',NULL,'MenuSeparator2','MENUSEPARATOR',NULL,30,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Contacts',NULL,'Actions','SELECT
    NULL AS [JobTitle]
    , CASE WHEN n.ID IS NOT NULL THEN n.FirstName ELSE t.FirstName END AS [First Name]
    , NULL AS [Middle Name]
    , CASE WHEN n.ID IS NOT NULL THEN n.LastName ELSE t.LastName END AS [Last Name]
    , NULL AS [Suffix]
    , CASE WHEN y.ID IS NOT NULL THEN y.Company ELSE t.Company END AS [Company]
    , NULL AS [Department]
    , CASE WHEN i.ID IS NOT NULL THEN i.JobTitle ELSE t.JobTitle END AS [Job Title]
    , NULL AS [Business Street]
    , NULL AS [Business Street 2]
    , NULL AS [Business Street 3]
    , NULL AS [Business City]
    , NULL AS [Business State]
    , NULL AS [Business Postal Code]
    , COALESCE(r.Country, rs.CountryName) AS [Business Country/Region]
    , NULL AS [Home Street]
    , NULL AS [Home Street 2]
    , NULL AS [Home Street 3]
    , NULL AS [Home City]
    , NULL AS [Home State]
    , NULL AS [Home Postal Code]
    , NULL AS [Home Country/Region]
    , NULL AS [Other Street]
    , NULL AS [Other Street 2]
    , NULL AS [Other Street 3]
    , NULL AS [Other City]
    , NULL AS [Other State]
    , NULL AS [Other Postal Code]
    , NULL AS [Other Country/Region]
    , NULL AS [Assistant''''s Phone]
    , NULL AS [Business Fax]
    , CASE WHEN p.ID IS NOT NULL THEN p.Phone ELSE t.Phone END AS [Business Phone]
    , NULL AS [Business Phone 2]
    , NULL AS [Callback]
    , NULL AS [Car Phone]
    , NULL AS [Company Main Phone]
    , NULL AS [Home Fax]
    , NULL AS [Home Phone]
    , NULL AS [Home Phone 2]
    , NULL AS [ISDN]
    , CASE WHEN m.ID IS NOT NULL THEN m.Mobile ELSE t.Mobile END AS [Mobile Phone]
    , NULL AS [Other Fax]
    , NULL AS [Other Phone]
    , NULL AS [Pager]
    , NULL AS [Primary Phone]
    , NULL AS [Radio Phone]
    , NULL AS [TTY/TDD Phone]
    , NULL AS [Telex]
    , NULL AS [Account]
    , NULL AS [Anniversary]
    , NULL AS [Assistant''''s Name]
    , NULL AS [Billing Information]
    , NULL AS [Birthday]
    , NULL AS [Business Address PO Box]
    , NULL AS [Categories]
    , NULL AS [Children]
    , NULL AS [Directory Server]
    , CASE WHEN e.ID IS NOT NULL THEN e.Email ELSE t.Email END AS [E-mail Address]
    , NULL AS [E-mail Type]
    , NULL AS [E-mail Display Name]
    , NULL AS [E-mail 2 Address]
    , NULL AS [E-mail 2 Type]
    , NULL AS [E-mail 2 Display Name]
    , NULL AS [E-mail 3 Address]
    , NULL AS [E-mail 3 Type]
    , NULL AS [E-mail 3 Display Name]
    , NULL AS [Gender]
    , NULL AS [Government ID Number]
    , NULL AS [Hobby]
    , NULL AS [Home Address PO Box]
    , NULL AS [Initials]
    , NULL AS [Internet Free Busy]
    , NULL AS [Keywords]
    , NULL AS [Language]
    , NULL AS [Location]
    , NULL AS [Manager''''s Name]
    , NULL AS [Mileage]
    , NULL AS [Notes]
    , NULL AS [Office Location]
    , NULL AS [Organizational ID Number]
    , NULL AS [Other Address PO Box]
    , NULL AS [Priority]
    , NULL AS [Private]
    , NULL AS [Profession]
    , NULL AS [Referred By]
    , NULL AS [Sensitivity]
    , NULL AS [Spouse]
    , c.ContactCategory AS [User 1]
    , NULL AS [User 2]
    , NULL AS [User 3]
    , NULL AS [User 4]
    , CASE WHEN w.ID IS NOT NULL THEN w.Website WHEN ws.Domain IS NOT NULL THEN ws.Website WHEN e.Email IS NULL THEN NULL ELSE ''www.'' + LOWER(SUBSTRING(e.email, CHARINDEX(''@'', e.email) + 1, 255)) END AS [Web Page]
FROM
    (
        SELECT
            c.ID
            , l2.[Source] AS lSource
            , MIN(l2.SourceID) AS lSourceID
            , g2.[Source] AS gSource
            , MIN(g2.SourceID) AS gSourceID
            , MIN(s.SourceFirstName) AS FirstName
            , MIN(s.SourceLastName) AS LastName
            , MIN(s.SourceEmail) AS Email
            , MIN(s.SourceMobile) AS Mobile
            , MIN(s.SourcePhone) AS Phone
            , MIN(s.SourceCompany) AS Company
            , MIN(s.SourceJobTitle) AS JobTitle
            , MIN(s.SourceCountryCode) AS CountryCode
        FROM
            Contacts c
            LEFT OUTER JOIN SourceContactID l1 ON l1.ContactID = c.ID AND l1.[Source] = ''LinkedIn''
            LEFT OUTER JOIN SourceContacts l2 ON l2.[Source] = l1.[Source] AND l2.SourceID = l1.SourceID
            LEFT OUTER JOIN SourceContactID g1 ON g1.ContactID = c.ID AND g1.[Source] = ''GoogleCSV''
            LEFT OUTER JOIN SourceContacts g2 ON g2.[Source] = g1.[Source] AND g2.SourceID = g1.SourceID
            LEFT OUTER JOIN SourceContactID d ON d.ContactID = c.ID
            LEFT OUTER JOIN SourceContacts s ON s.[Source] = d.[Source] AND s.SourceID = d.SourceID
        GROUP BY
            c.ID
            , l2.[Source]
            , g2.[Source]
    ) t
    INNER JOIN Contacts c ON c.ID = t.ID

    LEFT OUTER JOIN ContactNames    n ON n.ID = c.ID
    LEFT OUTER JOIN ContactEmail    e ON e.ID = c.ID
    LEFT OUTER JOIN ContactMobile   m ON m.ID = c.ID
    LEFT OUTER JOIN ContactPhone    p ON p.ID = c.ID
    LEFT OUTER JOIN ContactCountry  r ON r.ID = c.ID
    LEFT OUTER JOIN ContactWebsite  w ON w.ID = c.ID
    LEFT OUTER JOIN ContactCompany  y ON y.ID = c.ID
    LEFT OUTER JOIN ContactJobTitle i ON i.ID = c.ID

    LEFT OUTER JOIN Websites ws ON ws.Domain = LOWER(SUBSTRING(e.email, CHARINDEX(''@'', e.email) + 1, 255))
    LEFT OUTER JOIN Countries rs ON rs.CountryCode = t.CountryCode

    LEFT OUTER JOIN SourceContacts l2 ON l2.[Source] = t.lSource AND l2.SourceID = t.lSourceID
    LEFT OUTER JOIN SourceContacts g2 ON g2.[Source] = t.gSource AND g2.SourceID = t.gSourceID','Export to Outlook CSV File','CODE','_SaveAs contacts.csv;CodePage=1252;Format=CSV;Separator=,',31,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Contacts',NULL,'Actions',NULL,'MenuSeparator3','MENUSEPARATOR',NULL,50,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Websites',NULL,'Actions',NULL,'MenuSeparator2','MENUSEPARATOR',NULL,50,NULL);
GO
INSERT INTO [EventHandlers] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[EVENT_NAME],[HANDLER_SCHEMA],[HANDLER_NAME],[HANDLER_TYPE],[TARGET_WORKSHEET],[MENU_ORDER],[EDIT_PARAMETERS]) VALUES (NULL,'View Contacts',NULL,'ContextMenu',NULL,'MenuSeparator2','MENUSEPARATOR',NULL,30,NULL);
GO
-- print EventHandlers have been inserted

INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'ContactCompany','en',NULL,'Contact Company',NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'ContactCountry','en',NULL,'Contact Country',NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'ContactEmail','en',NULL,'Contact Email',NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'ContactJobTitle','en',NULL,'Contact JobTitle',NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'ContactMobile','en',NULL,'Contact Mobile Phone',NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'ContactNames','en',NULL,'Contact Names',NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'ContactPhone','en',NULL,'Contact Phone',NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Contacts','en',NULL,'Contacts',NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'ContactWebsite','en',NULL,'Contact Website',NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Countries','en',NULL,'Countries',NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'SourceContactID','en',NULL,'Source Contact ID',NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'SourceContacts','en',NULL,'Source Contacts',NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Websites','en',NULL,'Websites',NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Google - CSV','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'LinkedIn - CSV','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Outlook - CSV','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Yahoo! - HTM','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'LinkedIn - API','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Yahoo! - API','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Google - API','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'View Contacts','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'View Source Contacts','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'View Websites','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'View Countries','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Contacts By Domain','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Contacts By Country','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Source Contacts By ContactID','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Create New E-mail - Thanks for the connection','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Export to Outlook CSV File','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Google Search - {Company}','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Google Search - {FirstName} {LastName}','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Online Help, Questions, and Suggestions','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Open Google Contacts Export Page','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Open Google Contacts Page','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Open GooglePlus Profile','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Open LinkedIn Connections Page','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Open LinkedIn Export Page','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Open LinkedIn Profile','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Open Source File','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Open Website {Website}','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Open Working Directory','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Open Yahoo! Contacts Export Page','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Open Yahoo! Contacts Page','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Update All as Checked','en',NULL,NULL,NULL);
GO
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC],[TRANSLATED_COMMENT]) VALUES (NULL,'Update Contacts','en',NULL,NULL,NULL);
GO
-- print ObjectTranslation have been inserted

INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'Checked','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'Comment','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'Company','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'ContactCategory','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'ContactID','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'Country','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'CountryCode','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'CountryName','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'Domain','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'Email','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'FirstName','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'IsJunk','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'JobTitle','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'LastName','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'MergeDate','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'Mobile','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'Phone','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'Source','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'SourceCompany','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'SourceCountryCode','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'SourceEmail','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'SourceFirstName','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'SourceHeadline','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'SourceID','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'SourceIndustry','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'SourceJobTitle','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'SourceLastName','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'SourceLocationName','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'SourceMobile','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'SourcePhone','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'SourceProfileUrl','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'SourceSecondaryEmail','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'Website','en',NULL,NULL);
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'Number1','en',NULL,'You may change the column name in the ColumnTranslation.TRANSLATED_NAME field');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'Number2','en',NULL,'You may change the column name in the ColumnTranslation.TRANSLATED_NAME field');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'Number3','en',NULL,'You may change the column name in the ColumnTranslation.TRANSLATED_NAME field');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'String1','en',NULL,'You may change the column name in the ColumnTranslation.TRANSLATED_NAME field');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'String2','en',NULL,'You may change the column name in the ColumnTranslation.TRANSLATED_NAME field');
GO
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA],[TABLE_NAME],[COLUMN_NAME],[LANGUAGE_NAME],[TRANSLATED_NAME],[TRANSLATED_DESC]) VALUES (NULL,NULL,'String3','en',NULL,'You may change the column name in the ColumnTranslation.TRANSLATED_NAME field');
GO
-- print ColumnTranslation have been inserted

INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,'LinkedIn - CSV','<?xml version="1.0" encoding="Unicode"?>
<table name=".LinkedIn - CSV">
<columnFormats>
<column name="" property="ListObjectName" value="LinkedInCSV_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium2" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="True" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="Title" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Title" property="Address" value="$C$4" type="String" />
<column name="First Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="First Name" property="Address" value="$D$4" type="String" />
<column name="Middle Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Middle Name" property="Address" value="$E$4" type="String" />
<column name="Last Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Last Name" property="Address" value="$F$4" type="String" />
<column name="Suffix" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Suffix" property="Address" value="$G$4" type="String" />
<column name="E-mail Address" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail Address" property="Address" value="$H$4" type="String" />
<column name="E-mail 2 Address" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 2 Address" property="Address" value="$I$4" type="String" />
<column name="E-mail 3 Address" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 3 Address" property="Address" value="$J$4" type="String" />
<column name="Business Street" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Street" property="Address" value="$K$4" type="String" />
<column name="Business Street 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Street 2" property="Address" value="$L$4" type="String" />
<column name="Business Street 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Street 3" property="Address" value="$M$4" type="String" />
<column name="Business City" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business City" property="Address" value="$N$4" type="String" />
<column name="Business State" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business State" property="Address" value="$O$4" type="String" />
<column name="Business Postal Code" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Postal Code" property="Address" value="$P$4" type="String" />
<column name="Business Country" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Country" property="Address" value="$Q$4" type="String" />
<column name="Home Street" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Street" property="Address" value="$R$4" type="String" />
<column name="Home Street 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Street 2" property="Address" value="$S$4" type="String" />
<column name="Home Street 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Street 3" property="Address" value="$T$4" type="String" />
<column name="Home City" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home City" property="Address" value="$U$4" type="String" />
<column name="Home State" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home State" property="Address" value="$V$4" type="String" />
<column name="Home Postal Code" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Postal Code" property="Address" value="$W$4" type="String" />
<column name="Home Country" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Country" property="Address" value="$X$4" type="String" />
<column name="Other Street" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Street" property="Address" value="$Y$4" type="String" />
<column name="Other Street 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Street 2" property="Address" value="$Z$4" type="String" />
<column name="Other Street 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Street 3" property="Address" value="$AA$4" type="String" />
<column name="Other City" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other City" property="Address" value="$AB$4" type="String" />
<column name="Other State" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other State" property="Address" value="$AC$4" type="String" />
<column name="Other Postal Code" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Postal Code" property="Address" value="$AD$4" type="String" />
<column name="Other Country" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Country" property="Address" value="$AE$4" type="String" />
<column name="Company" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Company" property="Address" value="$AF$4" type="String" />
<column name="Department" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Department" property="Address" value="$AG$4" type="String" />
<column name="Job Title" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Job Title" property="Address" value="$AH$4" type="String" />
<column name="Assistant''s Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Assistant''s Phone" property="Address" value="$AI$4" type="String" />
<column name="Business Fax" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Fax" property="Address" value="$AJ$4" type="String" />
<column name="Business Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Phone" property="Address" value="$AK$4" type="String" />
<column name="Business Phone 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Phone 2" property="Address" value="$AL$4" type="String" />
<column name="Callback" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Callback" property="Address" value="$AM$4" type="String" />
<column name="Car Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Car Phone" property="Address" value="$AN$4" type="String" />
<column name="Company Main Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Company Main Phone" property="Address" value="$AO$4" type="String" />
<column name="Home Fax" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Fax" property="Address" value="$AP$4" type="String" />
<column name="Home Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Phone" property="Address" value="$AQ$4" type="String" />
<column name="Home Phone 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Phone 2" property="Address" value="$AR$4" type="String" />
<column name="ISDN" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="ISDN" property="Address" value="$AS$4" type="String" />
<column name="Mobile Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Mobile Phone" property="Address" value="$AT$4" type="String" />
<column name="Other Fax" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Fax" property="Address" value="$AU$4" type="String" />
<column name="Other Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Phone" property="Address" value="$AV$4" type="String" />
<column name="Pager" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Pager" property="Address" value="$AW$4" type="String" />
<column name="Primary Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Primary Phone" property="Address" value="$AX$4" type="String" />
<column name="Radio Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Radio Phone" property="Address" value="$AY$4" type="String" />
<column name="TTY/TDD Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="TTY/TDD Phone" property="Address" value="$AZ$4" type="String" />
<column name="Telex" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Telex" property="Address" value="$BA$4" type="String" />
<column name="Assistant''s Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Assistant''s Name" property="Address" value="$BB$4" type="String" />
<column name="Birthday" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Birthday" property="Address" value="$BC$4" type="String" />
<column name="Manager''s Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Manager''s Name" property="Address" value="$BD$4" type="String" />
<column name="Notes" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Notes" property="Address" value="$BE$4" type="String" />
<column name="Other Address PO Box" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Address PO Box" property="Address" value="$BF$4" type="String" />
<column name="Spouse" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Spouse" property="Address" value="$BG$4" type="String" />
<column name="Web Page" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Web Page" property="Address" value="$BH$4" type="String" />
<column name="Personal Web Page" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Personal Web Page" property="Address" value="$BI$4" type="String" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Source" property="Address" value="$BJ$4" type="String" />
<column name="Source" property="FormulaR1C1" value="=&#34;LinkedInCSV&#34;" type="String" />
<column name="Source" property="ColumnWidth" value="11.29" type="Double" />
<column name="SourceID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceID" property="Address" value="$BK$4" type="String" />
<column name="SourceID" property="FormulaR1C1" value="=[@[E-mail Address]]" type="String" />
<column name="SourceID" property="ColumnWidth" value="36.57" type="Double" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="Address" value="$BL$4" type="String" />
<column name="SourceFirstName" property="FormulaR1C1" value="=SUBSTITUTE(SUBSTITUTE([@[First Name]],&#34;?&#34;,&#34;&#34;),&#34;&#65533&#34;,&#34;&#34;)" type="String" />
<column name="SourceFirstName" property="ColumnWidth" value="17.86" type="Double" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="Address" value="$BM$4" type="String" />
<column name="SourceLastName" property="FormulaR1C1" value="=SUBSTITUTE(SUBSTITUTE([@[Last Name]],&#34;?&#34;,&#34;&#34;),&#34;&#65533;&#34;,&#34;&#34;)" type="String" />
<column name="SourceLastName" property="ColumnWidth" value="17.43" type="Double" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceEmail" property="Address" value="$BN$4" type="String" />
<column name="SourceEmail" property="FormulaR1C1" value="=[@[E-mail Address]]" type="String" />
<column name="SourceEmail" property="ColumnWidth" value="32.14" type="Double" />
<column name="SourceCompany" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceCompany" property="Address" value="$BO$4" type="String" />
<column name="SourceCompany" property="FormulaR1C1" value="=TRIM(IF(LEN([@Company])&#62;0,SUBSTITUTE(SUBSTITUTE([@Company],&#34;?&#34;,&#34;&#34;),&#34;&#65533;&#34;,&#34;&#34;),&#34;&#34;))" type="String" />
<column name="SourceCompany" property="ColumnWidth" value="41.57" type="Double" />
<column name="SourceJobTitle" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceJobTitle" property="Address" value="$BP$4" type="String" />
<column name="SourceJobTitle" property="FormulaR1C1" value="=IF(LEN([@[Job Title]])&#62;0,SUBSTITUTE(SUBSTITUTE([@[Job Title]],&#34;?&#34;,&#34;&#34;),&#34;&#65533;&#34;,&#34;&#34;),&#34;&#34;)" type="String" />
<column name="SourceJobTitle" property="ColumnWidth" value="45.29" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="2" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
<column name="" property="PageSetup.LeftMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.RightMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.TopMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.BottomMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.HeaderMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.FooterMargin" value="22.6771653543307" type="Double" />
</columnFormats>
<views>
<view name="All">
<column name="" property="ListObjectName" value="LinkedInCSV_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Title" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="First Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Middle Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Last Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Suffix" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail Address" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 2 Address" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 3 Address" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Street" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Street 2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Street 3" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business City" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business State" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Postal Code" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Country" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Street" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Street 2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Street 3" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home City" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home State" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Postal Code" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Country" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Street" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Street 2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Street 3" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other City" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other State" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Postal Code" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Country" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Company" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Department" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Job Title" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Assistant''s Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Fax" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Phone 2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Callback" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Car Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Company Main Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Fax" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Phone 2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ISDN" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Mobile Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Fax" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Pager" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Primary Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Radio Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TTY/TDD Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Telex" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Assistant''s Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Birthday" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Manager''s Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Notes" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Address PO Box" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Spouse" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Web Page" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Personal Web Page" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
<view name="Source Fields">
<column name="" property="ListObjectName" value="LinkedInCSV_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Title" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="First Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Middle Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Last Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Suffix" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail Address" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 2 Address" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 3 Address" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Street" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Street 2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Street 3" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business City" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business State" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Postal Code" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Country" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Street" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Street 2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Street 3" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home City" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home State" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Postal Code" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Country" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Street" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Street 2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Street 3" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other City" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other State" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Postal Code" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Country" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Company" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Department" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Job Title" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Assistant''s Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Fax" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Phone 2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Callback" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Car Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Company Main Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Fax" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Phone 2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ISDN" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Mobile Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Fax" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Pager" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Primary Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Radio Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TTY/TDD Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Telex" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Assistant''s Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Birthday" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Manager''s Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Notes" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Address PO Box" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Spouse" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Web Page" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Personal Web Page" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceCompany" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceJobTitle" property="EntireColumn.Hidden" value="True" type="Boolean" />
</view>
<view name="Source Main Fields">
<column name="" property="ListObjectName" value="LinkedInCSV_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Title" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="First Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Middle Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Last Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Suffix" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail Address" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 2 Address" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 3 Address" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Street" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Street 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Street 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business City" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business State" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Postal Code" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Country" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Street" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Street 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Street 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home City" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home State" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Postal Code" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Country" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Street" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Street 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Street 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other City" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other State" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Postal Code" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Country" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Company" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Department" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Job Title" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Assistant''s Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Fax" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Phone 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Callback" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Car Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Company Main Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Fax" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Phone 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="ISDN" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Mobile Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Fax" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Pager" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Primary Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Radio Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="TTY/TDD Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Telex" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Assistant''s Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Birthday" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Manager''s Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Notes" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Address PO Box" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Spouse" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Web Page" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Personal Web Page" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceCompany" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceJobTitle" property="EntireColumn.Hidden" value="True" type="Boolean" />
</view>
<view name="Main Fields">
<column name="" property="ListObjectName" value="LinkedInCSV_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Title" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="First Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Middle Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Last Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Suffix" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail Address" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 2 Address" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 3 Address" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Street" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Street 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Street 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business City" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business State" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Postal Code" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Country" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Street" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Street 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Street 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home City" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home State" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Postal Code" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Country" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Street" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Street 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Street 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other City" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other State" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Postal Code" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Country" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Company" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Department" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Job Title" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Assistant''s Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Fax" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Phone 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Callback" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Car Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Company Main Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Fax" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Phone 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="ISDN" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Mobile Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Fax" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Pager" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Primary Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Radio Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="TTY/TDD Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Telex" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Assistant''s Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Birthday" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Manager''s Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Notes" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Address PO Box" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Spouse" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Web Page" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Personal Web Page" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceCompany" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceTitle" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
<view name="Export Fields">
<column name="" property="ListObjectName" value="LinkedInCSV_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Title" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="First Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Middle Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Last Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Suffix" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail Address" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 2 Address" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 3 Address" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Street" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Street 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Street 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business City" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business State" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Postal Code" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Country" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Street" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Street 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Street 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home City" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home State" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Postal Code" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Country" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Street" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Street 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Street 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other City" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other State" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Postal Code" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Country" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Company" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Department" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Job Title" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Assistant''s Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Fax" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Phone 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Callback" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Car Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Company Main Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Fax" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Phone 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="ISDN" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Mobile Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Fax" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Pager" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Primary Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Radio Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="TTY/TDD Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Telex" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Assistant''s Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Birthday" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Manager''s Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Notes" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Address PO Box" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Spouse" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Web Page" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Personal Web Page" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceCompany" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceTitle" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
</views>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,'LinkedIn - API','<?xml version="1.0" encoding="Unicode"?>
<table name=".LinkedIn - API">
<columnFormats>
<column name="" property="ListObjectName" value="LinkedIn_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium2" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="True" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="id" property="Address" value="$C$4" type="String" />
<column name="first-name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="first-name" property="Address" value="$D$4" type="String" />
<column name="last-name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="last-name" property="Address" value="$E$4" type="String" />
<column name="headline" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="headline" property="Address" value="$F$4" type="String" />
<column name="picture-url" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="picture-url" property="Address" value="$G$4" type="String" />
<column name="api-standard-profile-request.url" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="api-standard-profile-request.url" property="Address" value="$H$4" type="String" />
<column name="api-standard-profile-request.headers.total" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="api-standard-profile-request.headers.total" property="Address" value="$I$4" type="String" />
<column name="api-standard-profile-request.headers.http-header.name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="api-standard-profile-request.headers.http-header.name" property="Address" value="$J$4" type="String" />
<column name="api-standard-profile-request.headers.http-header.value" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="api-standard-profile-request.headers.http-header.value" property="Address" value="$K$4" type="String" />
<column name="site-standard-profile-request.url" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="site-standard-profile-request.url" property="Address" value="$L$4" type="String" />
<column name="location.name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="location.name" property="Address" value="$M$4" type="String" />
<column name="location.country.code" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="location.country.code" property="Address" value="$N$4" type="String" />
<column name="industry" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="industry" property="Address" value="$O$4" type="String" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Source" property="Address" value="$P$4" type="String" />
<column name="Source" property="FormulaR1C1" value="=IF([@id]=&#34;private&#34;,&#34;&#34;,&#34;LinkedIn&#34;)" type="String" />
<column name="Source" property="ColumnWidth" value="8.86" type="Double" />
<column name="SourceID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceID" property="Address" value="$Q$4" type="String" />
<column name="SourceID" property="FormulaR1C1" value="=IF([@id]=&#34;private&#34;,&#34;&#34;,[@id])" type="String" />
<column name="SourceID" property="ColumnWidth" value="14.14" type="Double" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="Address" value="$R$4" type="String" />
<column name="SourceFirstName" property="FormulaR1C1" value="=IF([@SourceID]=&#34;&#34;,&#34;&#34;,SUBSTITUTE(SUBSTITUTE(SUBSTITUTE([@[first-name]],&#34;?&#34;,&#34;&#34;),&#34;&#65533;&#34;,&#34;&#34;),&#34;&#9733;&#34;,&#34;&#34;))" type="String" />
<column name="SourceFirstName" property="ColumnWidth" value="20.43" type="Double" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="Address" value="$S$4" type="String" />
<column name="SourceLastName" property="FormulaR1C1" value="=IF([@SourceID]=&#34;&#34;,&#34;&#34;,SUBSTITUTE(SUBSTITUTE(SUBSTITUTE([@[last-name]],&#34;?&#34;,&#34;&#34;),&#34;&#65533;&#34;,&#34;&#34;),&#34;&#9733;&#34;,&#34;&#34;))" type="String" />
<column name="SourceLastName" property="ColumnWidth" value="43.86" type="Double" />
<column name="SourceHeadline" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceHeadline" property="Address" value="$T$4" type="String" />
<column name="SourceHeadline" property="FormulaR1C1" value="=[@headline]&#38;&#34;&#34;" type="String" />
<column name="SourceHeadline" property="ColumnWidth" value="54.57" type="Double" />
<column name="SourceLocationName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLocationName" property="Address" value="$U$4" type="String" />
<column name="SourceLocationName" property="FormulaR1C1" value="=[@[location.name]]&#38;&#34;&#34;" type="String" />
<column name="SourceLocationName" property="ColumnWidth" value="44.71" type="Double" />
<column name="SourceCountryCode" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceCountryCode" property="Address" value="$V$4" type="String" />
<column name="SourceCountryCode" property="FormulaR1C1" value="=[@[location.country.code]]&#38;&#34;&#34;" type="String" />
<column name="SourceCountryCode" property="ColumnWidth" value="20.43" type="Double" />
<column name="SourceIndustry" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceIndustry" property="Address" value="$W$4" type="String" />
<column name="SourceIndustry" property="FormulaR1C1" value="=[@industry]&#38;&#34;&#34;" type="String" />
<column name="SourceIndustry" property="ColumnWidth" value="34.43" type="Double" />
<column name="SourceProfileUrl" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceProfileUrl" property="Address" value="$X$4" type="String" />
<column name="SourceProfileUrl" property="FormulaR1C1" value="=[@[site-standard-profile-request.url]]&#38;&#34;&#34;" type="String" />
<column name="SourceProfileUrl" property="ColumnWidth" value="71.14" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="2" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
<column name="" property="PageSetup.LeftMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.RightMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.TopMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.BottomMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.HeaderMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.FooterMargin" value="22.6771653543307" type="Double" />
</columnFormats>
<views>
<view name="All">
<column name="" property="ListObjectName" value="LinkedIn_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="first-name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="last-name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="headline" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="picture-url" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="api-standard-profile-request.url" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="api-standard-profile-request.headers.total" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="api-standard-profile-request.headers.http-header.name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="api-standard-profile-request.headers.http-header.value" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="site-standard-profile-request.url" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="location.name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="location.country.code" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="industry" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
<view name="Source Fields">
<column name="" property="ListObjectName" value="LinkedIn_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="first-name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="last-name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="headline" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="picture-url" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="api-standard-profile-request.url" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="api-standard-profile-request.headers.total" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="api-standard-profile-request.headers.http-header.name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="api-standard-profile-request.headers.http-header.value" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="site-standard-profile-request.url" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="location.name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="location.country.code" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="industry" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceHeadline" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceLocationName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceCountryCode" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceIndustry" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceProfileUrl" property="EntireColumn.Hidden" value="True" type="Boolean" />
</view>
<view name="Source Main Fields">
<column name="" property="ListObjectName" value="LinkedIn_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="first-name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="last-name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="headline" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="picture-url" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="api-standard-profile-request.url" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="api-standard-profile-request.headers.total" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="api-standard-profile-request.headers.http-header.name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="api-standard-profile-request.headers.http-header.value" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="site-standard-profile-request.url" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="location.name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="location.country.code" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="industry" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceHeadline" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceLocationName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceCountryCode" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceIndustry" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceProfileUrl" property="EntireColumn.Hidden" value="True" type="Boolean" />
</view>
<view name="Main Fields">
<column name="" property="ListObjectName" value="LinkedIn_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="first-name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="last-name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="headline" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="picture-url" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="api-standard-profile-request.url" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="api-standard-profile-request.headers.total" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="api-standard-profile-request.headers.http-header.name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="api-standard-profile-request.headers.http-header.value" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="site-standard-profile-request.url" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="location.name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="location.country.code" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="industry" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceHeadline" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLocationName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceCountryCode" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceIndustry" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceProfileUrl" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
<view name="Export Fields">
<column name="" property="ListObjectName" value="LinkedIn_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="first-name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="last-name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="headline" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="picture-url" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="api-standard-profile-request.url" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="api-standard-profile-request.headers.total" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="api-standard-profile-request.headers.http-header.name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="api-standard-profile-request.headers.http-header.value" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="site-standard-profile-request.url" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="location.name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="location.country.code" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="industry" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceHeadline" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLocationName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceCountryCode" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceIndustry" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceProfileUrl" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
</views>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,'Yahoo! - HTM','<?xml version="1.0" encoding="Unicode"?>
<table name=".Yahoo! - HTM">
<columnFormats>
<column name="" property="ListObjectName" value="YahooHTM_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium2" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="True" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="name" property="Address" value="$C$4" type="String" />
<column name="email" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="email" property="Address" value="$D$4" type="String" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Source" property="Address" value="$E$4" type="String" />
<column name="Source" property="FormulaR1C1" value="=&#34;YahooHTM&#34;" type="String" />
<column name="Source" property="ColumnWidth" value="9.71" type="Double" />
<column name="SourceID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceID" property="Address" value="$F$4" type="String" />
<column name="SourceID" property="FormulaR1C1" value="=[@email]" type="String" />
<column name="SourceID" property="ColumnWidth" value="21.86" type="Double" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="Address" value="$G$4" type="String" />
<column name="SourceFirstName" property="FormulaR1C1" value="=TRIM(LEFT([@name],LEN([@name])-LEN([@SourceLastName])))" type="String" />
<column name="SourceFirstName" property="ColumnWidth" value="17.86" type="Double" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="Address" value="$H$4" type="String" />
<column name="SourceLastName" property="FormulaR1C1" value="=IFERROR(RIGHT([@name],LEN([@name])-FIND(&#34;|&#34;,SUBSTITUTE([@name],&#34; &#34;,&#34;|&#34;,LEN([@name])-LEN(SUBSTITUTE([@name],&#34; &#34;,&#34;&#34;))))),&#34;&#34;)" type="String" />
<column name="SourceLastName" property="ColumnWidth" value="17.43" type="Double" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceEmail" property="Address" value="$I$4" type="String" />
<column name="SourceEmail" property="FormulaR1C1" value="=[@SourceID]" type="String" />
<column name="SourceEmail" property="ColumnWidth" value="29" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="2" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
<column name="" property="PageSetup.LeftMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.RightMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.TopMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.BottomMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.HeaderMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.FooterMargin" value="22.6771653543307" type="Double" />
</columnFormats>
<views>
<view name="All">
<column name="" property="ListObjectName" value="YahooHTM_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="email" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
<view name="Source Fields">
<column name="" property="ListObjectName" value="YahooHTM_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="email" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="True" type="Boolean" />
</view>
<view name="Source Main Fields">
<column name="" property="ListObjectName" value="YahooHTM_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="email" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="True" type="Boolean" />
</view>
<view name="Main Fields">
<column name="" property="ListObjectName" value="YahooHTM_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="email" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
<view name="Export Fields">
<column name="" property="ListObjectName" value="YahooHTM_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="email" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
</views>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,'Yahoo! - API','<?xml version="1.0" encoding="Unicode"?>
<table name=".Yahoo! - API">
<columnFormats>
<column name="" property="ListObjectName" value="Yahoo_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium2" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="True" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="yahoo:uri" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="yahoo:uri" property="Address" value="$C$4" type="String" />
<column name="yahoo:created" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="yahoo:created" property="Address" value="$D$4" type="String" />
<column name="yahoo:created" property="NumberFormat" value="m/d/yyyy h:mm" type="String" />
<column name="yahoo:updated" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="yahoo:updated" property="Address" value="$E$4" type="String" />
<column name="yahoo:updated" property="NumberFormat" value="m/d/yyyy h:mm" type="String" />
<column name="isConnection" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="isConnection" property="Address" value="$F$4" type="String" />
<column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="id" property="Address" value="$G$4" type="String" />
<column name="fields.yahoo:uri" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.yahoo:uri" property="Address" value="$H$4" type="String" />
<column name="fields.yahoo:created" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.yahoo:created" property="Address" value="$I$4" type="String" />
<column name="fields.yahoo:created" property="NumberFormat" value="m/d/yyyy h:mm" type="String" />
<column name="fields.yahoo:updated" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.yahoo:updated" property="Address" value="$J$4" type="String" />
<column name="fields.yahoo:updated" property="NumberFormat" value="m/d/yyyy h:mm" type="String" />
<column name="fields.id" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.id" property="Address" value="$K$4" type="String" />
<column name="fields.value" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.value" property="Address" value="$L$4" type="String" />
<column name="fields.editedBy" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.editedBy" property="Address" value="$M$4" type="String" />
<column name="fields.value.givenName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.value.givenName" property="Address" value="$N$4" type="String" />
<column name="fields.value.familyName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.value.familyName" property="Address" value="$O$4" type="String" />
<column name="categories.yahoo:uri" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="categories.yahoo:uri" property="Address" value="$P$4" type="String" />
<column name="categories.yahoo:created" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="categories.yahoo:created" property="Address" value="$Q$4" type="String" />
<column name="categories.yahoo:created" property="NumberFormat" value="m/d/yyyy h:mm" type="String" />
<column name="categories.yahoo:updated" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="categories.yahoo:updated" property="Address" value="$R$4" type="String" />
<column name="categories.yahoo:updated" property="NumberFormat" value="m/d/yyyy h:mm" type="String" />
<column name="categories.id" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="categories.id" property="Address" value="$S$4" type="String" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Source" property="Address" value="$T$4" type="String" />
<column name="Source" property="FormulaR1C1" value="=&#34;Yahoo&#34;" type="String" />
<column name="Source" property="ColumnWidth" value="8.57" type="Double" />
<column name="SourceID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceID" property="Address" value="$U$4" type="String" />
<column name="SourceID" property="FormulaR1C1" value="=RIGHT([@[yahoo:uri]],LEN([@[yahoo:uri]])-FIND(&#34;|&#34;,SUBSTITUTE([@[yahoo:uri]],&#34;/&#34;,&#34;|&#34;,LEN([@[yahoo:uri]])-LEN(SUBSTITUTE([@[yahoo:uri]],&#34;/&#34;,&#34;&#34;)))))" type="String" />
<column name="SourceID" property="ColumnWidth" value="10.43" type="Double" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="Address" value="$V$4" type="String" />
<column name="SourceFirstName" property="FormulaR1C1" value="=IF(LEN([@[fields.value.givenName]])&#62;0,[@[fields.value.givenName]],&#34;&#34;)" type="String" />
<column name="SourceFirstName" property="ColumnWidth" value="17.86" type="Double" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="Address" value="$W$4" type="String" />
<column name="SourceLastName" property="FormulaR1C1" value="=IF(LEN([@[fields.value.familyName]])&#62;0,[@[fields.value.familyName]],&#34;&#34;)" type="String" />
<column name="SourceLastName" property="ColumnWidth" value="17.43" type="Double" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceEmail" property="Address" value="$X$4" type="String" />
<column name="SourceEmail" property="FormulaR1C1" value="=[@[fields.value]]" type="String" />
<column name="SourceEmail" property="ColumnWidth" value="25.29" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="2" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
<column name="" property="PageSetup.LeftMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.RightMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.TopMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.BottomMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.HeaderMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.FooterMargin" value="22.6771653543307" type="Double" />
</columnFormats>
<views>
<view name="All">
<column name="" property="ListObjectName" value="Yahoo_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="yahoo:uri" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="yahoo:created" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="yahoo:updated" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="isConnection" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="fields.yahoo:uri" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="fields.yahoo:created" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="fields.yahoo:updated" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="fields.id" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="fields.value" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="fields.editedBy" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="fields.value.givenName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="fields.value.familyName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="categories.yahoo:uri" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="categories.yahoo:created" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="categories.yahoo:updated" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="categories.id" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
<view name="Source Fields">
<column name="" property="ListObjectName" value="Yahoo_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="yahoo:uri" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="yahoo:created" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="yahoo:updated" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="isConnection" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="fields.yahoo:uri" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="fields.yahoo:created" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="fields.yahoo:updated" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="fields.id" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="fields.value" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="fields.editedBy" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="fields.value.givenName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="fields.value.familyName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="categories.yahoo:uri" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="categories.yahoo:created" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="categories.yahoo:updated" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="categories.id" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="True" type="Boolean" />
</view>
<view name="Source Main Fields">
<column name="" property="ListObjectName" value="Yahoo_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="yahoo:uri" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="yahoo:created" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="yahoo:updated" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="isConnection" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.yahoo:uri" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.yahoo:created" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.yahoo:updated" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.id" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.value" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="fields.editedBy" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.value.givenName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="fields.value.familyName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="categories.yahoo:uri" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="categories.yahoo:created" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="categories.yahoo:updated" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="categories.id" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="True" type="Boolean" />
</view>
<view name="Main Fields">
<column name="" property="ListObjectName" value="Yahoo_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="yahoo:uri" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="yahoo:created" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="yahoo:updated" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="isConnection" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.yahoo:uri" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.yahoo:created" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.yahoo:updated" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.id" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.value" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="fields.editedBy" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.value.givenName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="fields.value.familyName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="categories.yahoo:uri" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="categories.yahoo:created" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="categories.yahoo:updated" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="categories.id" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
<view name="Export Fields">
<column name="" property="ListObjectName" value="Yahoo_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="yahoo:uri" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="yahoo:created" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="yahoo:updated" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="isConnection" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="id" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.yahoo:uri" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.yahoo:created" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.yahoo:updated" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.id" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.value" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.editedBy" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.value.givenName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="fields.value.familyName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="categories.yahoo:uri" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="categories.yahoo:created" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="categories.yahoo:updated" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="categories.id" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
</views>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,'Google - CSV','<?xml version="1.0" encoding="Unicode"?>
<table name=".Google - CSV">
<columnFormats>
<column name="" property="ListObjectName" value="GoogleCSV_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium2" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="True" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Name" property="Address" value="$C$4" type="String" />
<column name="Given Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Given Name" property="Address" value="$D$4" type="String" />
<column name="Additional Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Additional Name" property="Address" value="$E$4" type="String" />
<column name="Family Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Family Name" property="Address" value="$F$4" type="String" />
<column name="Yomi Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Yomi Name" property="Address" value="$G$4" type="String" />
<column name="Given Name Yomi" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Given Name Yomi" property="Address" value="$H$4" type="String" />
<column name="Additional Name Yomi" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Additional Name Yomi" property="Address" value="$I$4" type="String" />
<column name="Family Name Yomi" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Family Name Yomi" property="Address" value="$J$4" type="String" />
<column name="Name Prefix" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Name Prefix" property="Address" value="$K$4" type="String" />
<column name="Name Suffix" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Name Suffix" property="Address" value="$L$4" type="String" />
<column name="Initials" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Initials" property="Address" value="$M$4" type="String" />
<column name="Nickname" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Nickname" property="Address" value="$N$4" type="String" />
<column name="Short Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Short Name" property="Address" value="$O$4" type="String" />
<column name="Maiden Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Maiden Name" property="Address" value="$P$4" type="String" />
<column name="Birthday" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Birthday" property="Address" value="$Q$4" type="String" />
<column name="Gender" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Gender" property="Address" value="$R$4" type="String" />
<column name="Location" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Location" property="Address" value="$S$4" type="String" />
<column name="Billing Information" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Billing Information" property="Address" value="$T$4" type="String" />
<column name="Directory Server" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Directory Server" property="Address" value="$U$4" type="String" />
<column name="Mileage" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Mileage" property="Address" value="$V$4" type="String" />
<column name="Occupation" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Occupation" property="Address" value="$W$4" type="String" />
<column name="Hobby" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Hobby" property="Address" value="$X$4" type="String" />
<column name="Sensitivity" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Sensitivity" property="Address" value="$Y$4" type="String" />
<column name="Priority" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Priority" property="Address" value="$Z$4" type="String" />
<column name="Subject" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Subject" property="Address" value="$AA$4" type="String" />
<column name="Notes" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Notes" property="Address" value="$AB$4" type="String" />
<column name="Group Membership" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Group Membership" property="Address" value="$AC$4" type="String" />
<column name="E-mail 1 - Type" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 1 - Type" property="Address" value="$AD$4" type="String" />
<column name="E-mail 1 - Value" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 1 - Value" property="Address" value="$AE$4" type="String" />
<column name="E-mail 2 - Type" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 2 - Type" property="Address" value="$AF$4" type="String" />
<column name="E-mail 2 - Value" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 2 - Value" property="Address" value="$AG$4" type="String" />
<column name="Website 1 - Type" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Website 1 - Type" property="Address" value="$AH$4" type="String" />
<column name="Website 1 - Value" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Website 1 - Value" property="Address" value="$AI$4" type="String" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Source" property="Address" value="$AJ$4" type="String" />
<column name="Source" property="FormulaR1C1" value="=&#34;GoogleCSV&#34;" type="String" />
<column name="Source" property="ColumnWidth" value="10" type="Double" />
<column name="SourceID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceID" property="Address" value="$AK$4" type="String" />
<column name="SourceID" property="FormulaR1C1" value="=IF(ISERROR(FIND(&#34; ::: &#34;,[@[E-mail 1 - Value]])),[@[E-mail 1 - Value]]&#38;&#34;&#34;,LEFT([@[E-mail 1 - Value]],FIND(&#34; ::: &#34;,[@[E-mail 1 - Value]])))" type="String" />
<column name="SourceID" property="ColumnWidth" value="21.86" type="Double" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="Address" value="$AL$4" type="String" />
<column name="SourceFirstName" property="FormulaR1C1" value="=[@[Given Name]]&#38;IF([@[Additional Name]]=&#34;&#34;,&#34;&#34;,&#34; &#34;&#38;[@[Additional Name]])" type="String" />
<column name="SourceFirstName" property="ColumnWidth" value="17.86" type="Double" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="Address" value="$AM$4" type="String" />
<column name="SourceLastName" property="FormulaR1C1" value="=[@[Family Name]]&#38;&#34;&#34;" type="String" />
<column name="SourceLastName" property="ColumnWidth" value="17.43" type="Double" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceEmail" property="Address" value="$AN$4" type="String" />
<column name="SourceEmail" property="FormulaR1C1" value="=IF(ISERROR(FIND(&#34; ::: &#34;,[@[E-mail 1 - Value]])),[@[E-mail 1 - Value]]&#38;&#34;&#34;,LEFT([@[E-mail 1 - Value]],FIND(&#34; ::: &#34;,[@[E-mail 1 - Value]])))" type="String" />
<column name="SourceEmail" property="ColumnWidth" value="19.29" type="Double" />
<column name="SourceSecondaryEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceSecondaryEmail" property="Address" value="$AO$4" type="String" />
<column name="SourceSecondaryEmail" property="FormulaR1C1" value="=IF(OR([@[E-mail 2 - Value]]=&#34;&#34;,UPPER([@[E-mail 2 - Value]])=UPPER([@SourceEmail])),&#34;&#34;,[@[E-mail 2 - Value]])" type="String" />
<column name="SourceSecondaryEmail" property="ColumnWidth" value="23" type="Double" />
<column name="SourceProfileUrl" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceProfileUrl" property="Address" value="$AP$4" type="String" />
<column name="SourceProfileUrl" property="FormulaR1C1" value="=[@[Website 1 - Value]]&#38;&#34;&#34;" type="String" />
<column name="SourceProfileUrl" property="ColumnWidth" value="27.57" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
<column name="" property="PageSetup.LeftMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.RightMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.TopMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.BottomMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.HeaderMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.FooterMargin" value="22.6771653543307" type="Double" />
</columnFormats>
<views>
<view name="All">
<column name="" property="ListObjectName" value="GoogleCSV_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Given Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Additional Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Family Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Yomi Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Given Name Yomi" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Additional Name Yomi" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Family Name Yomi" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Name Prefix" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Name Suffix" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Initials" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Nickname" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Short Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Maiden Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Birthday" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Gender" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Location" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Billing Information" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Directory Server" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Mileage" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Occupation" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Hobby" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Sensitivity" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Priority" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Subject" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Notes" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Group Membership" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 1 - Type" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 1 - Value" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 2 - Type" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 2 - Value" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Website 1 - Type" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Website 1 - Value" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
<view name="Source Fields">
<column name="" property="ListObjectName" value="GoogleCSV_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Given Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Additional Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Family Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Yomi Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Given Name Yomi" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Additional Name Yomi" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Family Name Yomi" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Name Prefix" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Name Suffix" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Initials" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Nickname" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Short Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Maiden Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Birthday" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Gender" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Location" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Billing Information" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Directory Server" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Mileage" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Occupation" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Hobby" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Sensitivity" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Priority" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Subject" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Notes" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Group Membership" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 1 - Type" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 1 - Value" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 2 - Type" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 2 - Value" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Website 1 - Type" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Website 1 - Value" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceSecondaryEmail" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceProfileUrl" property="EntireColumn.Hidden" value="True" type="Boolean" />
</view>
<view name="Source Main Fields">
<column name="" property="ListObjectName" value="GoogleCSV_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Given Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Additional Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Family Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Yomi Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Given Name Yomi" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Additional Name Yomi" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Family Name Yomi" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Name Prefix" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Name Suffix" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Initials" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Nickname" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Short Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Maiden Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Birthday" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Gender" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Location" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Billing Information" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Directory Server" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Mileage" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Occupation" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Hobby" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Sensitivity" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Priority" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Subject" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Notes" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Group Membership" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 1 - Type" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 1 - Value" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 2 - Type" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 2 - Value" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Website 1 - Type" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Website 1 - Value" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceSecondaryEmail" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceProfileUrl" property="EntireColumn.Hidden" value="True" type="Boolean" />
</view>
<view name="Main Fields">
<column name="" property="ListObjectName" value="GoogleCSV_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Given Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Additional Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Family Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Yomi Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Given Name Yomi" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Additional Name Yomi" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Family Name Yomi" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Name Prefix" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Name Suffix" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Initials" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Nickname" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Short Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Maiden Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Birthday" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Gender" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Location" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Billing Information" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Directory Server" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Mileage" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Occupation" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Hobby" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Sensitivity" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Priority" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Subject" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Notes" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Group Membership" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 1 - Type" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 1 - Value" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 2 - Type" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 2 - Value" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Website 1 - Type" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Website 1 - Value" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceSecondaryEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceProfileUrl" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
<view name="Export Fields">
<column name="" property="ListObjectName" value="GoogleCSV_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Given Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Additional Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Family Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Yomi Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Given Name Yomi" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Additional Name Yomi" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Family Name Yomi" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Name Prefix" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Name Suffix" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Initials" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Nickname" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Short Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Maiden Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Birthday" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Gender" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Location" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Billing Information" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Directory Server" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Mileage" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Occupation" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Hobby" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Sensitivity" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Priority" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Subject" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Notes" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Group Membership" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 1 - Type" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 1 - Value" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 2 - Type" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 2 - Value" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Website 1 - Type" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Website 1 - Value" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceSecondaryEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceProfileUrl" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
</views>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,'Google - API','<?xml version="1.0" encoding="Unicode"?>
<table name=".Google - API">
<columnFormats>
<column name="" property="ListObjectName" value="Google_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium2" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="True" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="id.$t" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="id.$t" property="Address" value="$C$4" type="String" />
<column name="id.$t" property="VerticalAlignment" value="-4160" type="Double" />
<column name="updated.$t" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="updated.$t" property="Address" value="$D$4" type="String" />
<column name="updated.$t" property="NumberFormat" value="m/d/yyyy h:mm" type="String" />
<column name="updated.$t" property="VerticalAlignment" value="-4160" type="Double" />
<column name="title.$t" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="title.$t" property="Address" value="$E$4" type="String" />
<column name="title.$t" property="VerticalAlignment" value="-4160" type="Double" />
<column name="link.href" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="link.href" property="Address" value="$F$4" type="String" />
<column name="link.href" property="VerticalAlignment" value="-4160" type="Double" />
<column name="gd$organization.primary" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="gd$organization.primary" property="Address" value="$G$4" type="String" />
<column name="gd$organization.primary" property="VerticalAlignment" value="-4160" type="Double" />
<column name="gd$organization.gd$orgName.$t" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="gd$organization.gd$orgName.$t" property="Address" value="$H$4" type="String" />
<column name="gd$organization.gd$orgName.$t" property="VerticalAlignment" value="-4160" type="Double" />
<column name="gd$email.address" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="gd$email.address" property="Address" value="$I$4" type="String" />
<column name="gd$email.address" property="VerticalAlignment" value="-4160" type="Double" />
<column name="gd$email.primary" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="gd$email.primary" property="Address" value="$J$4" type="String" />
<column name="gd$email.primary" property="VerticalAlignment" value="-4160" type="Double" />
<column name="gd$phoneNumber.uri" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="gd$phoneNumber.uri" property="Address" value="$K$4" type="String" />
<column name="gd$phoneNumber.uri" property="VerticalAlignment" value="-4160" type="Double" />
<column name="gd$phoneNumber.$t" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="gd$phoneNumber.$t" property="Address" value="$L$4" type="String" />
<column name="gd$phoneNumber.$t" property="VerticalAlignment" value="-4160" type="Double" />
<column name="content.$t" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="content.$t" property="Address" value="$M$4" type="String" />
<column name="content.$t" property="VerticalAlignment" value="-4160" type="Double" />
<column name="gd$organization.gd$orgTitle.$t" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="gd$organization.gd$orgTitle.$t" property="Address" value="$N$4" type="String" />
<column name="gd$organization.gd$orgTitle.$t" property="VerticalAlignment" value="-4160" type="Double" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Source" property="Address" value="$O$4" type="String" />
<column name="Source" property="FormulaR1C1" value="=&#34;Google&#34;" type="String" />
<column name="Source" property="ColumnWidth" value="8.57" type="Double" />
<column name="Source" property="VerticalAlignment" value="-4160" type="Double" />
<column name="SourceID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceID" property="Address" value="$P$4" type="String" />
<column name="SourceID" property="FormulaR1C1" value="=RIGHT([@[id.$t]],LEN([@[id.$t]])-FIND(&#34;|&#34;,SUBSTITUTE([@[id.$t]],&#34;/&#34;,&#34;|&#34;,LEN([@[id.$t]])-LEN(SUBSTITUTE([@[id.$t]],&#34;/&#34;,&#34;&#34;)))))" type="String" />
<column name="SourceID" property="ColumnWidth" value="17.14" type="Double" />
<column name="SourceID" property="VerticalAlignment" value="-4160" type="Double" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="Address" value="$Q$4" type="String" />
<column name="SourceFirstName" property="FormulaR1C1" value="=TRIM(SUBSTITUTE(LEFT([@[title.$t]],LEN([@[title.$t]])-LEN([@SourceLastName])),&#34;?&#34;,&#34;&#34;))" type="String" />
<column name="SourceFirstName" property="ColumnWidth" value="25.29" type="Double" />
<column name="SourceFirstName" property="VerticalAlignment" value="-4160" type="Double" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="Address" value="$R$4" type="String" />
<column name="SourceLastName" property="FormulaR1C1" value="=IFERROR(SUBSTITUTE(RIGHT([@[title.$t]],LEN([@[title.$t]])-FIND(&#34;|&#34;,SUBSTITUTE([@[title.$t]],&#34; &#34;,&#34;|&#34;,LEN([@[title.$t]])-LEN(SUBSTITUTE([@[title.$t]],&#34; &#34;,&#34;&#34;))))),&#34;?&#34;,&#34;&#34;),&#34;&#34;)" type="String" />
<column name="SourceLastName" property="ColumnWidth" value="17.43" type="Double" />
<column name="SourceLastName" property="VerticalAlignment" value="-4160" type="Double" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceEmail" property="Address" value="$S$4" type="String" />
<column name="SourceEmail" property="FormulaR1C1" value="=[@[gd$email.address]]&#38;&#34;&#34;" type="String" />
<column name="SourceEmail" property="ColumnWidth" value="31.71" type="Double" />
<column name="SourceEmail" property="VerticalAlignment" value="-4160" type="Double" />
<column name="SourceMobile" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceMobile" property="Address" value="$T$4" type="String" />
<column name="SourceMobile" property="FormulaR1C1" value="=[@[gd$phoneNumber.$t]]&#38;&#34;&#34;" type="String" />
<column name="SourceMobile" property="ColumnWidth" value="17.29" type="Double" />
<column name="SourceMobile" property="VerticalAlignment" value="-4160" type="Double" />
<column name="SourceCompany" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceCompany" property="Address" value="$U$4" type="String" />
<column name="SourceCompany" property="FormulaR1C1" value="=[@[gd$organization.gd$orgName.$t]]&#38;&#34;&#34;" type="String" />
<column name="SourceCompany" property="ColumnWidth" value="17.86" type="Double" />
<column name="SourceCompany" property="VerticalAlignment" value="-4160" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="2" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
<column name="" property="PageSetup.LeftMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.RightMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.TopMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.BottomMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.HeaderMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.FooterMargin" value="22.6771653543307" type="Double" />
</columnFormats>
<views>
<view name="All">
<column name="" property="ListObjectName" value="Google_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="id.$t" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="updated.$t" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="title.$t" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="link.href" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="gd$organization.primary" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="gd$organization.gd$orgName.$t" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="gd$email.address" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="gd$email.primary" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="gd$phoneNumber.uri" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="gd$phoneNumber.$t" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="content.$t" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="gd$organization.gd$orgTitle.$t" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
<view name="Source Fields">
<column name="" property="ListObjectName" value="Google_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="id.$t" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="updated.$t" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="title.$t" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="link.href" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="gd$organization.primary" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="gd$organization.gd$orgName.$t" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="gd$email.address" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="gd$email.primary" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="gd$phoneNumber.uri" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="gd$phoneNumber.$t" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="content.$t" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="gd$organization.gd$orgTitle.$t" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceMobile" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceCompany" property="EntireColumn.Hidden" value="True" type="Boolean" />
</view>
<view name="Source Main Fields">
<column name="" property="ListObjectName" value="Google_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="id.$t" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="updated.$t" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="title.$t" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="link.href" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="gd$organization.primary" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="gd$organization.gd$orgName.$t" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="gd$email.address" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="gd$email.primary" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="gd$phoneNumber.uri" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="gd$phoneNumber.$t" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="content.$t" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="gd$organization.gd$orgTitle.$t" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceMobile" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceCompany" property="EntireColumn.Hidden" value="True" type="Boolean" />
</view>
<view name="Main Fields">
<column name="" property="ListObjectName" value="Google_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="id.$t" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="updated.$t" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="title.$t" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="link.href" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="gd$organization.primary" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="gd$organization.gd$orgName.$t" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="gd$email.address" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="gd$email.primary" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="gd$phoneNumber.uri" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="gd$phoneNumber.$t" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="content.$t" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="gd$organization.gd$orgTitle.$t" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceMobile" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceCompany" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
<view name="Export Fields">
<column name="" property="ListObjectName" value="Google_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="id.$t" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="updated.$t" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="title.$t" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="link.href" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="gd$organization.primary" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="gd$organization.gd$orgName.$t" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="gd$email.address" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="gd$email.primary" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="gd$phoneNumber.uri" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="gd$phoneNumber.$t" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="content.$t" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="gd$organization.gd$orgTitle.$t" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceMobile" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceCompany" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
</views>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,'Outlook - CSV','<?xml version="1.0" encoding="Unicode"?>
<table name=".Outlook - CSV">
<columnFormats>
<column name="" property="ListObjectName" value="OutlookCSV_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium2" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="True" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="Title" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Title" property="Address" value="$C$4" type="String" />
<column name="First Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="First Name" property="Address" value="$D$4" type="String" />
<column name="Middle Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Middle Name" property="Address" value="$E$4" type="String" />
<column name="Last Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Last Name" property="Address" value="$F$4" type="String" />
<column name="Suffix" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Suffix" property="Address" value="$G$4" type="String" />
<column name="Company" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Company" property="Address" value="$H$4" type="String" />
<column name="Department" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Department" property="Address" value="$I$4" type="String" />
<column name="Job Title" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Job Title" property="Address" value="$J$4" type="String" />
<column name="Business Street" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Street" property="Address" value="$K$4" type="String" />
<column name="Business Street 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Street 2" property="Address" value="$L$4" type="String" />
<column name="Business Street 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Street 3" property="Address" value="$M$4" type="String" />
<column name="Business City" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business City" property="Address" value="$N$4" type="String" />
<column name="Business State" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business State" property="Address" value="$O$4" type="String" />
<column name="Business Postal Code" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Postal Code" property="Address" value="$P$4" type="String" />
<column name="Business Country/Region" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Country/Region" property="Address" value="$Q$4" type="String" />
<column name="Home Street" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Street" property="Address" value="$R$4" type="String" />
<column name="Home Street 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Street 2" property="Address" value="$S$4" type="String" />
<column name="Home Street 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Street 3" property="Address" value="$T$4" type="String" />
<column name="Home City" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home City" property="Address" value="$U$4" type="String" />
<column name="Home State" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home State" property="Address" value="$V$4" type="String" />
<column name="Home Postal Code" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Postal Code" property="Address" value="$W$4" type="String" />
<column name="Home Country/Region" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Country/Region" property="Address" value="$X$4" type="String" />
<column name="Other Street" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Street" property="Address" value="$Y$4" type="String" />
<column name="Other Street 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Street 2" property="Address" value="$Z$4" type="String" />
<column name="Other Street 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Street 3" property="Address" value="$AA$4" type="String" />
<column name="Other City" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other City" property="Address" value="$AB$4" type="String" />
<column name="Other State" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other State" property="Address" value="$AC$4" type="String" />
<column name="Other Postal Code" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Postal Code" property="Address" value="$AD$4" type="String" />
<column name="Other Country/Region" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Country/Region" property="Address" value="$AE$4" type="String" />
<column name="Assistant''s Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Assistant''s Phone" property="Address" value="$AF$4" type="String" />
<column name="Business Fax" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Fax" property="Address" value="$AG$4" type="String" />
<column name="Business Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Phone" property="Address" value="$AH$4" type="String" />
<column name="Business Phone 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Phone 2" property="Address" value="$AI$4" type="String" />
<column name="Callback" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Callback" property="Address" value="$AJ$4" type="String" />
<column name="Car Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Car Phone" property="Address" value="$AK$4" type="String" />
<column name="Company Main Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Company Main Phone" property="Address" value="$AL$4" type="String" />
<column name="Home Fax" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Fax" property="Address" value="$AM$4" type="String" />
<column name="Home Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Phone" property="Address" value="$AN$4" type="String" />
<column name="Home Phone 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Phone 2" property="Address" value="$AO$4" type="String" />
<column name="ISDN" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="ISDN" property="Address" value="$AP$4" type="String" />
<column name="Mobile Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Mobile Phone" property="Address" value="$AQ$4" type="String" />
<column name="Other Fax" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Fax" property="Address" value="$AR$4" type="String" />
<column name="Other Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Phone" property="Address" value="$AS$4" type="String" />
<column name="Pager" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Pager" property="Address" value="$AT$4" type="String" />
<column name="Primary Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Primary Phone" property="Address" value="$AU$4" type="String" />
<column name="Radio Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Radio Phone" property="Address" value="$AV$4" type="String" />
<column name="TTY/TDD Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="TTY/TDD Phone" property="Address" value="$AW$4" type="String" />
<column name="Telex" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Telex" property="Address" value="$AX$4" type="String" />
<column name="Account" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Account" property="Address" value="$AY$4" type="String" />
<column name="Anniversary" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Anniversary" property="Address" value="$AZ$4" type="String" />
<column name="Assistant''s Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Assistant''s Name" property="Address" value="$BA$4" type="String" />
<column name="Billing Information" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Billing Information" property="Address" value="$BB$4" type="String" />
<column name="Birthday" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Birthday" property="Address" value="$BC$4" type="String" />
<column name="Business Address PO Box" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Address PO Box" property="Address" value="$BD$4" type="String" />
<column name="Categories" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Categories" property="Address" value="$BE$4" type="String" />
<column name="Children" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Children" property="Address" value="$BF$4" type="String" />
<column name="Directory Server" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Directory Server" property="Address" value="$BG$4" type="String" />
<column name="E-mail Address" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail Address" property="Address" value="$BH$4" type="String" />
<column name="E-mail Type" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail Type" property="Address" value="$BI$4" type="String" />
<column name="E-mail Display Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail Display Name" property="Address" value="$BJ$4" type="String" />
<column name="E-mail 2 Address" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 2 Address" property="Address" value="$BK$4" type="String" />
<column name="E-mail 2 Type" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 2 Type" property="Address" value="$BL$4" type="String" />
<column name="E-mail 2 Display Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 2 Display Name" property="Address" value="$BM$4" type="String" />
<column name="E-mail 3 Address" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 3 Address" property="Address" value="$BN$4" type="String" />
<column name="E-mail 3 Type" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 3 Type" property="Address" value="$BO$4" type="String" />
<column name="E-mail 3 Display Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 3 Display Name" property="Address" value="$BP$4" type="String" />
<column name="Gender" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Gender" property="Address" value="$BQ$4" type="String" />
<column name="Government ID Number" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Government ID Number" property="Address" value="$BR$4" type="String" />
<column name="Hobby" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Hobby" property="Address" value="$BS$4" type="String" />
<column name="Home Address PO Box" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Address PO Box" property="Address" value="$BT$4" type="String" />
<column name="Initials" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Initials" property="Address" value="$BU$4" type="String" />
<column name="Internet Free Busy" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Internet Free Busy" property="Address" value="$BV$4" type="String" />
<column name="Keywords" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Keywords" property="Address" value="$BW$4" type="String" />
<column name="Language" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Language" property="Address" value="$BX$4" type="String" />
<column name="Location" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Location" property="Address" value="$BY$4" type="String" />
<column name="Manager''s Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Manager''s Name" property="Address" value="$BZ$4" type="String" />
<column name="Mileage" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Mileage" property="Address" value="$CA$4" type="String" />
<column name="Notes" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Notes" property="Address" value="$CB$4" type="String" />
<column name="Office Location" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Office Location" property="Address" value="$CC$4" type="String" />
<column name="Organizational ID Number" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Organizational ID Number" property="Address" value="$CD$4" type="String" />
<column name="Other Address PO Box" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Address PO Box" property="Address" value="$CE$4" type="String" />
<column name="Priority" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Priority" property="Address" value="$CF$4" type="String" />
<column name="Private" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Private" property="Address" value="$CG$4" type="String" />
<column name="Profession" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Profession" property="Address" value="$CH$4" type="String" />
<column name="Referred By" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Referred By" property="Address" value="$CI$4" type="String" />
<column name="Sensitivity" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Sensitivity" property="Address" value="$CJ$4" type="String" />
<column name="Spouse" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Spouse" property="Address" value="$CK$4" type="String" />
<column name="User 1" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="User 1" property="Address" value="$CL$4" type="String" />
<column name="User 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="User 2" property="Address" value="$CM$4" type="String" />
<column name="User 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="User 3" property="Address" value="$CN$4" type="String" />
<column name="User 4" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="User 4" property="Address" value="$CO$4" type="String" />
<column name="Web Page" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Web Page" property="Address" value="$CP$4" type="String" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Source" property="Address" value="$CQ$4" type="String" />
<column name="Source" property="FormulaR1C1" value="=&#34;OutlookCSV&#34;" type="String" />
<column name="Source" property="ColumnWidth" value="10.86" type="Double" />
<column name="SourceID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceID" property="Address" value="$CR$4" type="String" />
<column name="SourceID" property="FormulaR1C1" value="=IF([@[E-mail Address]]&#62;&#34;&#34;,[@[E-mail Address]],SUBSTITUTE(SUBSTITUTE(SUBSTITUTE(SUBSTITUTE(SUBSTITUTE([@SourcePhone],&#34;+&#34;,&#34;&#34;),&#34;(&#34;,&#34;&#34;),&#34;)&#34;,&#34;&#34;),&#34; &#34;,&#34;&#34;),&#34;-&#34;,&#34;&#34;))" type="String" />
<column name="SourceID" property="ColumnWidth" value="21.86" type="Double" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="Address" value="$CS$4" type="String" />
<column name="SourceFirstName" property="FormulaR1C1" value="=[@[First Name]]&#38;IF(LEN([@[Middle Name]])&#62;0,&#34; &#34;&#38;[@[Middle Name]],&#34;&#34;)" type="String" />
<column name="SourceFirstName" property="ColumnWidth" value="17.86" type="Double" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="Address" value="$CT$4" type="String" />
<column name="SourceLastName" property="FormulaR1C1" value="=[@[Last Name]]&#38;&#34;&#34;" type="String" />
<column name="SourceLastName" property="ColumnWidth" value="17.43" type="Double" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceEmail" property="Address" value="$CU$4" type="String" />
<column name="SourceEmail" property="FormulaR1C1" value="=[@[E-mail Address]]&#38;&#34;&#34;" type="String" />
<column name="SourceEmail" property="ColumnWidth" value="21.86" type="Double" />
<column name="SourceSecondaryEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceSecondaryEmail" property="Address" value="$CV$4" type="String" />
<column name="SourceSecondaryEmail" property="FormulaR1C1" value="=[@[E-mail 2 Address]]&#38;&#34;&#34;" type="String" />
<column name="SourceSecondaryEmail" property="ColumnWidth" value="23" type="Double" />
<column name="SourceMobile" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceMobile" property="Address" value="$CW$4" type="String" />
<column name="SourceMobile" property="FormulaR1C1" value="=[@[Mobile Phone]]&#38;&#34;&#34;" type="String" />
<column name="SourceMobile" property="ColumnWidth" value="15.14" type="Double" />
<column name="SourcePhone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourcePhone" property="Address" value="$CX$4" type="String" />
<column name="SourcePhone" property="FormulaR1C1" value="=IF([@[Business Phone]]&#62;&#34;&#34;,[@[Business Phone]],IF([@[Primary Phone]]&#62;&#34;&#34;,[@[Primary Phone]],IF([@[Home Phone]]&#62;&#34;&#34;,[@[Home Phone]],IF([@[Mobile Phone]]&#62;&#34;&#34;,[@[Mobile Phone]],&#34;&#34;))))" type="String" />
<column name="SourcePhone" property="ColumnWidth" value="16.14" type="Double" />
<column name="SourceCompany" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceCompany" property="Address" value="$CY$4" type="String" />
<column name="SourceCompany" property="FormulaR1C1" value="=[@Company]&#38;&#34;&#34;" type="String" />
<column name="SourceCompany" property="ColumnWidth" value="17" type="Double" />
<column name="SourceJobTitle" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceJobTitle" property="Address" value="$CZ$4" type="String" />
<column name="SourceJobTitle" property="FormulaR1C1" value="=[@[Job Title]]&#38;&#34;&#34;" type="String" />
<column name="SourceJobTitle" property="ColumnWidth" value="15.71" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="2" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
<column name="" property="PageSetup.LeftMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.RightMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.TopMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.BottomMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.HeaderMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.FooterMargin" value="22.6771653543307" type="Double" />
</columnFormats>
<views>
<view name="All">
<column name="" property="ListObjectName" value="OutlookCSV_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Title" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="First Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Middle Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Last Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Suffix" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Company" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Department" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Job Title" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Street" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Street 2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Street 3" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business City" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business State" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Postal Code" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Country/Region" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Street" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Street 2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Street 3" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home City" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home State" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Postal Code" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Country/Region" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Street" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Street 2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Street 3" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other City" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other State" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Postal Code" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Country/Region" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Assistant''s Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Fax" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Phone 2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Callback" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Car Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Company Main Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Fax" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Phone 2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ISDN" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Mobile Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Fax" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Pager" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Primary Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Radio Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TTY/TDD Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Telex" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Account" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Anniversary" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Assistant''s Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Billing Information" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Birthday" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Address PO Box" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Categories" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Children" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Directory Server" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail Address" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail Type" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail Display Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 2 Address" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 2 Type" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 2 Display Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 3 Address" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 3 Type" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 3 Display Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Gender" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Government ID Number" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Hobby" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Address PO Box" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Initials" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Internet Free Busy" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Keywords" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Language" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Location" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Manager''s Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Mileage" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Notes" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Office Location" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Organizational ID Number" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Address PO Box" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Priority" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Private" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Profession" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Referred By" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Sensitivity" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Spouse" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="User 1" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="User 2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="User 3" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="User 4" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Web Page" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
<view name="Source Fields">
<column name="" property="ListObjectName" value="OutlookCSV_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Title" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="First Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Middle Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Last Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Suffix" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Company" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Department" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Job Title" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Street" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Street 2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Street 3" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business City" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business State" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Postal Code" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Country/Region" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Street" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Street 2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Street 3" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home City" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home State" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Postal Code" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Country/Region" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Street" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Street 2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Street 3" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other City" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other State" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Postal Code" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Country/Region" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Assistant''s Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Fax" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Phone 2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Callback" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Car Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Company Main Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Fax" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Phone 2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ISDN" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Mobile Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Fax" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Pager" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Primary Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Radio Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TTY/TDD Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Telex" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Account" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Anniversary" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Assistant''s Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Billing Information" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Birthday" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Address PO Box" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Categories" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Children" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Directory Server" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail Address" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail Type" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail Display Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 2 Address" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 2 Type" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 2 Display Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 3 Address" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 3 Type" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail 3 Display Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Gender" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Government ID Number" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Hobby" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Home Address PO Box" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Initials" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Internet Free Busy" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Keywords" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Language" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Location" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Manager''s Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Mileage" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Notes" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Office Location" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Organizational ID Number" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Address PO Box" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Priority" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Private" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Profession" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Referred By" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Sensitivity" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Spouse" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="User 1" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="User 2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="User 3" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="User 4" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Web Page" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceSecondaryEmail" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceMobile" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourcePhone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceCompany" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceJobTitle" property="EntireColumn.Hidden" value="True" type="Boolean" />
</view>
<view name="Source Main Fields">
<column name="" property="ListObjectName" value="OutlookCSV_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Title" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="First Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Middle Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Last Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Suffix" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Company" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Department" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Job Title" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Street" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Street 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Street 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business City" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business State" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Postal Code" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Country/Region" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Street" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Street 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Street 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home City" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home State" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Postal Code" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Country/Region" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Street" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Street 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Street 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other City" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other State" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Postal Code" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Country/Region" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Assistant''s Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Fax" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Phone 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Callback" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Car Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Company Main Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Fax" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Phone 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="ISDN" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Mobile Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Fax" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Pager" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Primary Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Radio Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="TTY/TDD Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Telex" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Account" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Anniversary" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Assistant''s Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Billing Information" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Birthday" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Address PO Box" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Categories" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Children" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Directory Server" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail Address" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail Type" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail Display Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 2 Address" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 2 Type" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 2 Display Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 3 Address" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 3 Type" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 3 Display Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Gender" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Government ID Number" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Hobby" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Address PO Box" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Initials" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Internet Free Busy" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Keywords" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Language" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Location" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Manager''s Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Mileage" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Notes" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Office Location" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Organizational ID Number" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Address PO Box" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Priority" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Private" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Profession" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Referred By" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Sensitivity" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Spouse" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="User 1" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="User 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="User 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="User 4" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Web Page" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceSecondaryEmail" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceMobile" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourcePhone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceCompany" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceJobTitle" property="EntireColumn.Hidden" value="True" type="Boolean" />
</view>
<view name="Main Fields">
<column name="" property="ListObjectName" value="OutlookCSV_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Title" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="First Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Middle Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Last Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Suffix" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Company" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Department" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Job Title" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Street" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Street 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Street 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business City" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business State" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Postal Code" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Country/Region" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Street" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Street 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Street 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home City" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home State" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Postal Code" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Country/Region" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Street" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Street 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Street 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other City" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other State" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Postal Code" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Country/Region" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Assistant''s Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Fax" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Business Phone 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Callback" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Car Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Company Main Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Fax" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Phone 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="ISDN" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Mobile Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Other Fax" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Pager" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Primary Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Radio Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="TTY/TDD Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Telex" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Account" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Anniversary" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Assistant''s Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Billing Information" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Birthday" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Address PO Box" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Categories" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Children" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Directory Server" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail Address" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="E-mail Type" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail Display Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 2 Address" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 2 Type" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 2 Display Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 3 Address" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 3 Type" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 3 Display Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Gender" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Government ID Number" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Hobby" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Address PO Box" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Initials" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Internet Free Busy" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Keywords" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Language" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Location" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Manager''s Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Mileage" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Notes" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Office Location" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Organizational ID Number" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Address PO Box" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Priority" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Private" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Profession" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Referred By" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Sensitivity" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Spouse" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="User 1" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="User 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="User 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="User 4" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Web Page" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceSecondaryEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceMobile" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourcePhone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceCompany" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceTitle" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
<view name="Export Fields">
<column name="" property="ListObjectName" value="OutlookCSV_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Title" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="First Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Middle Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Last Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Suffix" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Company" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Department" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Job Title" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Street" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Street 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Street 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business City" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business State" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Postal Code" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Country/Region" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Street" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Street 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Street 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home City" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home State" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Postal Code" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Country/Region" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Street" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Street 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Street 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other City" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other State" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Postal Code" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Country/Region" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Assistant''s Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Fax" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Phone 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Callback" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Car Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Company Main Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Fax" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Phone 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="ISDN" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Mobile Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Fax" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Pager" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Primary Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Radio Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="TTY/TDD Phone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Telex" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Account" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Anniversary" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Assistant''s Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Billing Information" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Birthday" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Business Address PO Box" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Categories" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Children" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Directory Server" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail Address" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail Type" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail Display Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 2 Address" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 2 Type" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 2 Display Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 3 Address" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 3 Type" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="E-mail 3 Display Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Gender" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Government ID Number" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Hobby" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Home Address PO Box" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Initials" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Internet Free Busy" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Keywords" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Language" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Location" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Manager''s Name" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Mileage" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Notes" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Office Location" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Organizational ID Number" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Other Address PO Box" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Priority" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Private" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Profession" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Referred By" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Sensitivity" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Spouse" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="User 1" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="User 2" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="User 3" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="User 4" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Web Page" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceSecondaryEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceMobile" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourcePhone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceCompany" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceJobTitle" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
</views>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,'Countries','<table name="Countries"><columnFormats><column name="" property="ListObjectName" value="Countries_Table1" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium2" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="True" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="CountryCode" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="CountryCode" property="Address" value="$C$4" type="String" /><column name="CountryCode" property="ColumnWidth" value="14.14" type="Double" /><column name="CountryCode" property="Validation.Type" value="6" type="Double" /><column name="CountryCode" property="Validation.AlertStyle" value="1" type="Double" /><column name="CountryCode" property="Validation.Operator" value="8" type="Double" /><column name="CountryCode" property="Validation.Formula1" value="2" type="String" /><column name="CountryCode" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="CountryCode" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="CountryCode" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="CountryCode" property="Validation.ErrorMessage" value="The column requires values of the char(2) datatype." type="String" /><column name="CountryCode" property="Validation.ShowInput" value="True" type="Boolean" /><column name="CountryCode" property="Validation.ShowError" value="True" type="Boolean" /><column name="CountryName" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="CountryName" property="Address" value="$D$4" type="String" /><column name="CountryName" property="ColumnWidth" value="19.29" type="Double" /><column name="CountryName" property="Validation.Type" value="6" type="Double" /><column name="CountryName" property="Validation.AlertStyle" value="1" type="Double" /><column name="CountryName" property="Validation.Operator" value="8" type="Double" /><column name="CountryName" property="Validation.Formula1" value="255" type="String" /><column name="CountryName" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="CountryName" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="CountryName" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="CountryName" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="CountryName" property="Validation.ShowInput" value="True" type="Boolean" /><column name="CountryName" property="Validation.ShowError" value="True" type="Boolean" /><column name="Checked" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="Checked" property="Address" value="$E$4" type="String" /><column name="Checked" property="ColumnWidth" value="10.14" type="Double" /><column name="Checked" property="Validation.Type" value="1" type="Double" /><column name="Checked" property="Validation.AlertStyle" value="1" type="Double" /><column name="Checked" property="Validation.Operator" value="1" type="Double" /><column name="Checked" property="Validation.Formula1" value="0" type="String" /><column name="Checked" property="Validation.Formula2" value="255" type="String" /><column name="Checked" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="Checked" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="Checked" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="Checked" property="Validation.ErrorMessage" value="The column requires values of the tinyint datatype." type="String" /><column name="Checked" property="Validation.ShowInput" value="True" type="Boolean" /><column name="Checked" property="Validation.ShowError" value="True" type="Boolean" /><column name="CountryCode" property="FormatConditions(1).AppliesTo.Address" value="$C$4:$C$90" type="String" /><column name="CountryCode" property="FormatConditions(1).Type" value="2" type="Double" /><column name="CountryCode" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="CountryCode" property="FormatConditions(1).Formula1" value="=ISBLANK(C4)" type="String" /><column name="CountryCode" property="FormatConditions(1).NumberFormat" value="General" type="String" /><column name="CountryCode" property="FormatConditions(1).Interior.Color" value="65535" type="Double" /><column name="CountryCode" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" /><column name="SortFields(1)" property="KeyfieldName" value="CountryName" type="String" /><column name="SortFields(1)" property="SortOn" value="0" type="Double" /><column name="SortFields(1)" property="Order" value="1" type="Double" /><column name="SortFields(1)" property="DataOption" value="0" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /><column name="" property="PageSetup.PaperSize" value="1" type="Double" /><column name="" property="PageSetup.LeftMargin" value="22.6771653543307" type="Double" /><column name="" property="PageSetup.RightMargin" value="22.6771653543307" type="Double" /><column name="" property="PageSetup.TopMargin" value="25.511811023622" type="Double" /><column name="" property="PageSetup.BottomMargin" value="25.511811023622" type="Double" /><column name="" property="PageSetup.HeaderMargin" value="22.6771653543307" type="Double" /><column name="" property="PageSetup.FooterMargin" value="22.6771653543307" type="Double" /></columnFormats><views><view name="By CountryCode"><column name="" property="ListObjectName" value="Countries_Table1" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="CountryCode" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="CountryName" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="Checked" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SortFields(1)" property="KeyfieldName" value="CountryCode" type="String" /><column name="SortFields(1)" property="SortOn" value="0" type="Double" /><column name="SortFields(1)" property="Order" value="1" type="Double" /><column name="SortFields(1)" property="DataOption" value="2" type="Double" /></view><view name="By CountryName"><column name="" property="ListObjectName" value="Countries_Table1" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="CountryCode" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="CountryName" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="Checked" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SortFields(1)" property="KeyfieldName" value="CountryName" type="String" /><column name="SortFields(1)" property="SortOn" value="0" type="Double" /><column name="SortFields(1)" property="Order" value="1" type="Double" /><column name="SortFields(1)" property="DataOption" value="2" type="Double" /></view></views></table>');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,'View Countries','<?xml version="1.0" encoding="Unicode"?>
<table name=".View Countries">
<columnFormats>
<column name="" property="ListObjectName" value="Countries_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="CountryCode" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="CountryCode" property="Address" value="$C$4" type="String" />
<column name="CountryCode" property="ColumnWidth" value="14.14" type="Double" />
<column name="CountryCode" property="Validation.Type" value="6" type="Double" />
<column name="CountryCode" property="Validation.AlertStyle" value="1" type="Double" />
<column name="CountryCode" property="Validation.Operator" value="8" type="Double" />
<column name="CountryCode" property="Validation.Formula1" value="2" type="String" />
<column name="CountryCode" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="CountryCode" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="CountryCode" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="CountryCode" property="Validation.ShowError" value="True" type="Boolean" />
<column name="CountryName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="CountryName" property="Address" value="$D$4" type="String" />
<column name="CountryName" property="ColumnWidth" value="19.29" type="Double" />
<column name="CountryName" property="Validation.Type" value="6" type="Double" />
<column name="CountryName" property="Validation.AlertStyle" value="1" type="Double" />
<column name="CountryName" property="Validation.Operator" value="8" type="Double" />
<column name="CountryName" property="Validation.Formula1" value="255" type="String" />
<column name="CountryName" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="CountryName" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="CountryName" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="CountryName" property="Validation.ShowError" value="True" type="Boolean" />
<column name="Checked" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Checked" property="Address" value="$E$4" type="String" />
<column name="Checked" property="ColumnWidth" value="10.14" type="Double" />
<column name="Checked" property="HorizontalAlignment" value="-4108" type="Double" />
<column name="Checked" property="Font.Size" value="10" type="Double" />
<column name="Checked" property="Validation.Type" value="1" type="Double" />
<column name="Checked" property="Validation.AlertStyle" value="1" type="Double" />
<column name="Checked" property="Validation.Operator" value="1" type="Double" />
<column name="Checked" property="Validation.Formula1" value="0" type="String" />
<column name="Checked" property="Validation.Formula2" value="255" type="String" />
<column name="Checked" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="Checked" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="Checked" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="Checked" property="Validation.ShowError" value="True" type="Boolean" />
<column name="ContactCount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ContactCount" property="Address" value="$F$4" type="String" />
<column name="ContactCount" property="ColumnWidth" value="14.71" type="Double" />
<column name="ContactCount" property="Validation.Type" value="1" type="Double" />
<column name="ContactCount" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ContactCount" property="Validation.Operator" value="1" type="Double" />
<column name="ContactCount" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ContactCount" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ContactCount" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ContactCount" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ContactCount" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ContactCount" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HasErrors" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HasErrors" property="Address" value="$G$4" type="String" />
<column name="HasErrors" property="ColumnWidth" value="10.86" type="Double" />
<column name="HasErrors" property="HorizontalAlignment" value="-4108" type="Double" />
<column name="HasErrors" property="Font.Size" value="10" type="Double" />
<column name="HasErrors" property="Validation.Type" value="1" type="Double" />
<column name="HasErrors" property="Validation.AlertStyle" value="1" type="Double" />
<column name="HasErrors" property="Validation.Operator" value="1" type="Double" />
<column name="HasErrors" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="HasErrors" property="Validation.Formula2" value="2147483647" type="String" />
<column name="HasErrors" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="HasErrors" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="HasErrors" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="HasErrors" property="Validation.ShowError" value="True" type="Boolean" />
<column name="CountryCode" property="FormatConditions(1).AppliesTo.Address" value="$C$3:$C$91" type="String" />
<column name="CountryCode" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="CountryCode" property="FormatConditions(1).Priority" value="4" type="Double" />
<column name="CountryCode" property="FormatConditions(1).Formula1" value="=ISBLANK(C3)" type="String" />
<column name="CountryCode" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="CountryCode" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="Checked" property="FormatConditions(1).AppliesTo.Address" value="$E$3:$E$91" type="String" />
<column name="Checked" property="FormatConditions(1).Type" value="6" type="Double" />
<column name="Checked" property="FormatConditions(1).Priority" value="3" type="Double" />
<column name="Checked" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" />
<column name="Checked" property="FormatConditions(1).IconSet.ID" value="8" type="Double" />
<column name="Checked" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" />
<column name="Checked" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" />
<column name="Checked" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" />
<column name="Checked" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" />
<column name="Checked" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" />
<column name="Checked" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" />
<column name="ContactCount" property="FormatConditions(1).AppliesTo.Address" value="$F$3:$F$91" type="String" />
<column name="ContactCount" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="ContactCount" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="ContactCount" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="ContactCount" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="1" type="Double" />
<column name="ContactCount" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="7039480" type="Double" />
<column name="ContactCount" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="5" type="Double" />
<column name="ContactCount" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="50" type="Double" />
<column name="ContactCount" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8711167" type="Double" />
<column name="ContactCount" property="FormatConditions(1).ColorScaleCriteria(3).Type" value="2" type="Double" />
<column name="ContactCount" property="FormatConditions(1).ColorScaleCriteria(3).Value" value="813" type="Double" />
<column name="ContactCount" property="FormatConditions(1).ColorScaleCriteria(3).FormatColor.Color" value="8109667" type="Double" />
<column name="HasErrors" property="FormatConditions(1).AppliesTo.Address" value="$G$3:$G$91" type="String" />
<column name="HasErrors" property="FormatConditions(1).Type" value="6" type="Double" />
<column name="HasErrors" property="FormatConditions(1).Priority" value="2" type="Double" />
<column name="HasErrors" property="FormatConditions(1).ReverseOrder" value="True" type="Boolean" />
<column name="HasErrors" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" />
<column name="HasErrors" property="FormatConditions(1).IconSet.ID" value="8" type="Double" />
<column name="HasErrors" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" />
<column name="HasErrors" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" />
<column name="HasErrors" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" />
<column name="HasErrors" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" />
<column name="HasErrors" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" />
<column name="HasErrors" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" />
<column name="SortFields(1)" property="KeyfieldName" value="CountryName" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="0" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
<column name="" property="PageSetup.LeftMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.RightMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.TopMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.BottomMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.HeaderMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.FooterMargin" value="22.6771653543307" type="Double" />
</columnFormats>
<views>
<view name="By Country Code">
<column name="" property="ListObjectName" value="Countries_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="CountryCode" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="CountryName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Checked" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ContactCount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HasErrors" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SortFields(1)" property="KeyfieldName" value="CountryCode" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="2" type="Double" />
</view>
<view name="By Country Name">
<column name="" property="ListObjectName" value="Countries_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="CountryCode" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="CountryName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Checked" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ContactCount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HasErrors" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SortFields(1)" property="KeyfieldName" value="CountryName" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="2" type="Double" />
</view>
<view name="By Contact Count">
<column name="" property="ListObjectName" value="Countries_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="CountryCode" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="CountryName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Checked" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ContactCount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HasErrors" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SortFields(1)" property="KeyfieldName" value="ContactCount" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="2" type="Double" />
<column name="SortFields(1)" property="DataOption" value="2" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="CountryName" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="1" type="Double" />
<column name="SortFields(2)" property="DataOption" value="2" type="Double" />
</view>
<view name="New Countries">
<column name="" property="ListObjectName" value="Countries_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="CountryCode" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="CountryName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Checked" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ContactCount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HasErrors" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Checked" property="AutoFilter.Criteria1" value="=" type="String" />
<column name="SortFields(1)" property="KeyfieldName" value="CountryName" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="2" type="Double" />
</view>
<view name="With Errors">
<column name="" property="ListObjectName" value="Countries_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="CountryCode" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="CountryName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Checked" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ContactCount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HasErrors" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HasErrors" property="AutoFilter.Criteria1" value="&#60;&#62;" type="String" />
<column name="SortFields(1)" property="KeyfieldName" value="CountryName" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="2" type="Double" />
</view>
</views>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,'Websites','<table name="Websites"><columnFormats><column name="" property="ListObjectName" value="Countries_Table113" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ID" property="Address" value="$C$4" type="String" /><column name="ID" property="ColumnWidth" value="4.43" type="Double" /><column name="ID" property="Validation.Type" value="1" type="Double" /><column name="ID" property="Validation.AlertStyle" value="1" type="Double" /><column name="ID" property="Validation.Operator" value="1" type="Double" /><column name="ID" property="Validation.Formula1" value="-32768" type="String" /><column name="ID" property="Validation.Formula2" value="32767" type="String" /><column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="ID" property="Validation.ShowInput" value="True" type="Boolean" /><column name="ID" property="Validation.ShowError" value="True" type="Boolean" /><column name="Domain" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="Domain" property="Address" value="$D$4" type="String" /><column name="Domain" property="ColumnWidth" value="21.86" type="Double" /><column name="Domain" property="Validation.Type" value="6" type="Double" /><column name="Domain" property="Validation.AlertStyle" value="1" type="Double" /><column name="Domain" property="Validation.Operator" value="8" type="Double" /><column name="Domain" property="Validation.Formula1" value="255" type="String" /><column name="Domain" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="Domain" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="Domain" property="Validation.ShowInput" value="True" type="Boolean" /><column name="Domain" property="Validation.ShowError" value="True" type="Boolean" /><column name="Website" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="Website" property="Address" value="$E$4" type="String" /><column name="Website" property="ColumnWidth" value="12.86" type="Double" /><column name="Website" property="Validation.Type" value="6" type="Double" /><column name="Website" property="Validation.AlertStyle" value="1" type="Double" /><column name="Website" property="Validation.Operator" value="8" type="Double" /><column name="Website" property="Validation.Formula1" value="255" type="String" /><column name="Website" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="Website" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="Website" property="Validation.ShowInput" value="True" type="Boolean" /><column name="Website" property="Validation.ShowError" value="True" type="Boolean" /><column name="Comment" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="Comment" property="Address" value="$F$4" type="String" /><column name="Comment" property="ColumnWidth" value="16.86" type="Double" /><column name="Checked" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="Checked" property="Address" value="$G$4" type="String" /><column name="Checked" property="ColumnWidth" value="10.14" type="Double" /><column name="Checked" property="HorizontalAlignment" value="-4108" type="Double" /><column name="Checked" property="Font.Size" value="10" type="Double" /><column name="Checked" property="Validation.Type" value="1" type="Double" /><column name="Checked" property="Validation.AlertStyle" value="1" type="Double" /><column name="Checked" property="Validation.Operator" value="1" type="Double" /><column name="Checked" property="Validation.Formula1" value="0" type="String" /><column name="Checked" property="Validation.Formula2" value="255" type="String" /><column name="Checked" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="Checked" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="Checked" property="Validation.ShowInput" value="True" type="Boolean" /><column name="Checked" property="Validation.ShowError" value="True" type="Boolean" /><column name="Checked" property="FormatConditions(1).AppliesTo.Address" value="$G$4:$G$71" type="String" /><column name="Checked" property="FormatConditions(1).Type" value="6" type="Double" /><column name="Checked" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="Checked" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" /><column name="Checked" property="FormatConditions(1).IconSet.ID" value="8" type="Double" /><column name="Checked" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" /><column name="Checked" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" /><column name="Checked" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" /><column name="Checked" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" /><column name="Checked" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" /><column name="Checked" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" /><column name="SortFields(1)" property="KeyfieldName" value="Domain" type="String" /><column name="SortFields(1)" property="SortOn" value="0" type="Double" /><column name="SortFields(1)" property="Order" value="1" type="Double" /><column name="SortFields(1)" property="DataOption" value="2" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /><column name="" property="PageSetup.PaperSize" value="1" type="Double" /><column name="" property="PageSetup.LeftMargin" value="22.6771653543307" type="Double" /><column name="" property="PageSetup.RightMargin" value="22.6771653543307" type="Double" /><column name="" property="PageSetup.TopMargin" value="25.511811023622" type="Double" /><column name="" property="PageSetup.BottomMargin" value="25.511811023622" type="Double" /><column name="" property="PageSetup.HeaderMargin" value="22.6771653543307" type="Double" /><column name="" property="PageSetup.FooterMargin" value="22.6771653543307" type="Double" /></columnFormats></table>');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,'View Websites','<?xml version="1.0" encoding="Unicode"?>
<table name=".View Websites">
<columnFormats>
<column name="" property="ListObjectName" value="Websites_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="Domain" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Domain" property="Address" value="$C$4" type="String" />
<column name="Domain" property="ColumnWidth" value="36.14" type="Double" />
<column name="Domain" property="Validation.Type" value="6" type="Double" />
<column name="Domain" property="Validation.AlertStyle" value="1" type="Double" />
<column name="Domain" property="Validation.Operator" value="8" type="Double" />
<column name="Domain" property="Validation.Formula1" value="255" type="String" />
<column name="Domain" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="Domain" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="Domain" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="Domain" property="Validation.ShowError" value="True" type="Boolean" />
<column name="Website" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Website" property="Address" value="$D$4" type="String" />
<column name="Website" property="ColumnWidth" value="41.71" type="Double" />
<column name="Website" property="Validation.Type" value="6" type="Double" />
<column name="Website" property="Validation.AlertStyle" value="1" type="Double" />
<column name="Website" property="Validation.Operator" value="8" type="Double" />
<column name="Website" property="Validation.Formula1" value="255" type="String" />
<column name="Website" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="Website" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="Website" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="Website" property="Validation.ShowError" value="True" type="Boolean" />
<column name="Comment" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Comment" property="Address" value="$E$4" type="String" />
<column name="Comment" property="ColumnWidth" value="20.29" type="Double" />
<column name="Comment" property="Validation.Type" value="6" type="Double" />
<column name="Comment" property="Validation.AlertStyle" value="1" type="Double" />
<column name="Comment" property="Validation.Operator" value="8" type="Double" />
<column name="Comment" property="Validation.Formula1" value="255" type="String" />
<column name="Comment" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="Comment" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="Comment" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="Comment" property="Validation.ShowError" value="True" type="Boolean" />
<column name="Checked" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Checked" property="Address" value="$F$4" type="String" />
<column name="Checked" property="ColumnWidth" value="10.14" type="Double" />
<column name="Checked" property="HorizontalAlignment" value="-4108" type="Double" />
<column name="Checked" property="Font.Size" value="10" type="Double" />
<column name="Checked" property="Validation.Type" value="1" type="Double" />
<column name="Checked" property="Validation.AlertStyle" value="1" type="Double" />
<column name="Checked" property="Validation.Operator" value="1" type="Double" />
<column name="Checked" property="Validation.Formula1" value="0" type="String" />
<column name="Checked" property="Validation.Formula2" value="255" type="String" />
<column name="Checked" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="Checked" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="Checked" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="Checked" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SourceDomainContactCount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceDomainContactCount" property="Address" value="$G$4" type="String" />
<column name="SourceDomainContactCount" property="ColumnWidth" value="28" type="Double" />
<column name="SourceDomainContactCount" property="Validation.Type" value="1" type="Double" />
<column name="SourceDomainContactCount" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SourceDomainContactCount" property="Validation.Operator" value="1" type="Double" />
<column name="SourceDomainContactCount" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="SourceDomainContactCount" property="Validation.Formula2" value="2147483647" type="String" />
<column name="SourceDomainContactCount" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SourceDomainContactCount" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SourceDomainContactCount" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SourceDomainContactCount" property="Validation.ShowError" value="True" type="Boolean" />
<column name="DomainContactCount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="DomainContactCount" property="Address" value="$H$4" type="String" />
<column name="DomainContactCount" property="ColumnWidth" value="21.71" type="Double" />
<column name="DomainContactCount" property="Validation.Type" value="1" type="Double" />
<column name="DomainContactCount" property="Validation.AlertStyle" value="1" type="Double" />
<column name="DomainContactCount" property="Validation.Operator" value="1" type="Double" />
<column name="DomainContactCount" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="DomainContactCount" property="Validation.Formula2" value="2147483647" type="String" />
<column name="DomainContactCount" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="DomainContactCount" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="DomainContactCount" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="DomainContactCount" property="Validation.ShowError" value="True" type="Boolean" />
<column name="WebsiteContactCount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="WebsiteContactCount" property="Address" value="$I$4" type="String" />
<column name="WebsiteContactCount" property="ColumnWidth" value="22.43" type="Double" />
<column name="WebsiteContactCount" property="Validation.Type" value="1" type="Double" />
<column name="WebsiteContactCount" property="Validation.AlertStyle" value="1" type="Double" />
<column name="WebsiteContactCount" property="Validation.Operator" value="1" type="Double" />
<column name="WebsiteContactCount" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="WebsiteContactCount" property="Validation.Formula2" value="2147483647" type="String" />
<column name="WebsiteContactCount" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="WebsiteContactCount" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="WebsiteContactCount" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="WebsiteContactCount" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HasErrors" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HasErrors" property="Address" value="$J$4" type="String" />
<column name="HasErrors" property="ColumnWidth" value="10.14" type="Double" />
<column name="HasErrors" property="HorizontalAlignment" value="-4108" type="Double" />
<column name="HasErrors" property="Font.Size" value="10" type="Double" />
<column name="HasErrors" property="Validation.Type" value="1" type="Double" />
<column name="HasErrors" property="Validation.AlertStyle" value="1" type="Double" />
<column name="HasErrors" property="Validation.Operator" value="1" type="Double" />
<column name="HasErrors" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="HasErrors" property="Validation.Formula2" value="2147483647" type="String" />
<column name="HasErrors" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="HasErrors" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="HasErrors" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="HasErrors" property="Validation.ShowError" value="True" type="Boolean" />
<column name="Checked" property="FormatConditions(1).AppliesTo.Address" value="$F$4:$F$98" type="String" />
<column name="Checked" property="FormatConditions(1).Type" value="6" type="Double" />
<column name="Checked" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="Checked" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" />
<column name="Checked" property="FormatConditions(1).IconSet.ID" value="8" type="Double" />
<column name="Checked" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" />
<column name="Checked" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" />
<column name="Checked" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" />
<column name="Checked" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" />
<column name="Checked" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" />
<column name="Checked" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" />
<column name="SourceDomainContactCount" property="FormatConditions(1).AppliesTo.Address" value="$G$4:$G$98" type="String" />
<column name="SourceDomainContactCount" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="SourceDomainContactCount" property="FormatConditions(1).Priority" value="3" type="Double" />
<column name="SourceDomainContactCount" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="SourceDomainContactCount" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="1" type="Double" />
<column name="SourceDomainContactCount" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="7039480" type="Double" />
<column name="SourceDomainContactCount" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="5" type="Double" />
<column name="SourceDomainContactCount" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="50" type="Double" />
<column name="SourceDomainContactCount" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8711167" type="Double" />
<column name="SourceDomainContactCount" property="FormatConditions(1).ColorScaleCriteria(3).Type" value="2" type="Double" />
<column name="SourceDomainContactCount" property="FormatConditions(1).ColorScaleCriteria(3).Value" value="910" type="Double" />
<column name="SourceDomainContactCount" property="FormatConditions(1).ColorScaleCriteria(3).FormatColor.Color" value="8109667" type="Double" />
<column name="DomainContactCount" property="FormatConditions(1).AppliesTo.Address" value="$H$4:$H$98" type="String" />
<column name="DomainContactCount" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="DomainContactCount" property="FormatConditions(1).Priority" value="4" type="Double" />
<column name="DomainContactCount" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="DomainContactCount" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="1" type="Double" />
<column name="DomainContactCount" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="7039480" type="Double" />
<column name="DomainContactCount" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="5" type="Double" />
<column name="DomainContactCount" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="50" type="Double" />
<column name="DomainContactCount" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8711167" type="Double" />
<column name="DomainContactCount" property="FormatConditions(1).ColorScaleCriteria(3).Type" value="2" type="Double" />
<column name="DomainContactCount" property="FormatConditions(1).ColorScaleCriteria(3).Value" value="910" type="Double" />
<column name="DomainContactCount" property="FormatConditions(1).ColorScaleCriteria(3).FormatColor.Color" value="8109667" type="Double" />
<column name="WebsiteContactCount" property="FormatConditions(1).AppliesTo.Address" value="$I$4:$I$98" type="String" />
<column name="WebsiteContactCount" property="FormatConditions(1).Type" value="3" type="Double" />
<column name="WebsiteContactCount" property="FormatConditions(1).Priority" value="5" type="Double" />
<column name="WebsiteContactCount" property="FormatConditions(1).ColorScaleCriteria(1).Type" value="1" type="Double" />
<column name="WebsiteContactCount" property="FormatConditions(1).ColorScaleCriteria(1).Value" value="1" type="Double" />
<column name="WebsiteContactCount" property="FormatConditions(1).ColorScaleCriteria(1).FormatColor.Color" value="7039480" type="Double" />
<column name="WebsiteContactCount" property="FormatConditions(1).ColorScaleCriteria(2).Type" value="5" type="Double" />
<column name="WebsiteContactCount" property="FormatConditions(1).ColorScaleCriteria(2).Value" value="50" type="Double" />
<column name="WebsiteContactCount" property="FormatConditions(1).ColorScaleCriteria(2).FormatColor.Color" value="8711167" type="Double" />
<column name="WebsiteContactCount" property="FormatConditions(1).ColorScaleCriteria(3).Type" value="2" type="Double" />
<column name="WebsiteContactCount" property="FormatConditions(1).ColorScaleCriteria(3).Value" value="27" type="Double" />
<column name="WebsiteContactCount" property="FormatConditions(1).ColorScaleCriteria(3).FormatColor.Color" value="8109667" type="Double" />
<column name="HasErrors" property="FormatConditions(1).AppliesTo.Address" value="$J$4:$J$98" type="String" />
<column name="HasErrors" property="FormatConditions(1).Type" value="6" type="Double" />
<column name="HasErrors" property="FormatConditions(1).Priority" value="2" type="Double" />
<column name="HasErrors" property="FormatConditions(1).ReverseOrder" value="True" type="Boolean" />
<column name="HasErrors" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" />
<column name="HasErrors" property="FormatConditions(1).IconSet.ID" value="8" type="Double" />
<column name="HasErrors" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" />
<column name="HasErrors" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" />
<column name="HasErrors" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" />
<column name="HasErrors" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" />
<column name="HasErrors" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" />
<column name="HasErrors" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" />
<column name="SortFields(1)" property="KeyfieldName" value="Domain" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="0" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
<column name="" property="PageSetup.LeftMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.RightMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.TopMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.BottomMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.HeaderMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.FooterMargin" value="22.6771653543307" type="Double" />
</columnFormats>
<views>
<view name="By Domain">
<column name="" property="ListObjectName" value="Countries_Table113" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Domain" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Website" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Comment" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Checked" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceDomainContactCount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="DomainContactCount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="WebsiteContactCount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ContactCategoryCount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HasErrors" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SortFields(1)" property="KeyfieldName" value="Domain" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="2" type="Double" />
</view>
<view name="By Contact Count">
<column name="" property="ListObjectName" value="Countries_Table113" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Domain" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Website" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Comment" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Checked" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceDomainContactCount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="DomainContactCount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="WebsiteContactCount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ContactCategoryCount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HasErrors" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SortFields(1)" property="KeyfieldName" value="DomainContactCount" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="2" type="Double" />
<column name="SortFields(1)" property="DataOption" value="2" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="Domain" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="1" type="Double" />
<column name="SortFields(2)" property="DataOption" value="2" type="Double" />
</view>
<view name="New Websites">
<column name="" property="ListObjectName" value="Countries_Table113" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Domain" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Website" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Comment" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Checked" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceDomainContactCount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="DomainContactCount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="WebsiteContactCount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ContactCategoryCount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HasErrors" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Checked" property="AutoFilter.Criteria1" value="=" type="String" />
<column name="SortFields(1)" property="KeyfieldName" value="DomainContactCount" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="2" type="Double" />
<column name="SortFields(1)" property="DataOption" value="0" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="Domain" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="1" type="Double" />
<column name="SortFields(2)" property="DataOption" value="0" type="Double" />
</view>
<view name="With Errors">
<column name="" property="ListObjectName" value="Countries_Table113" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Domain" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Website" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Comment" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Checked" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceDomainContactCount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="DomainContactCount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="WebsiteContactCount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ContactCategoryCount" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HasErrors" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HasErrors" property="AutoFilter.Criteria1" value="&#60;&#62;" type="String" />
<column name="SortFields(1)" property="KeyfieldName" value="DomainContactCount" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="2" type="Double" />
<column name="SortFields(1)" property="DataOption" value="0" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="Domain" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="1" type="Double" />
<column name="SortFields(2)" property="DataOption" value="0" type="Double" />
</view>
</views>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,'View Source Contacts','<?xml version="1.0" encoding="Unicode"?>
<table name=".View Source Contacts">
<columnFormats>
<column name="" property="ListObjectName" value="SourceContacts_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="True" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Source" property="Address" value="$C$4" type="String" />
<column name="Source" property="ColumnWidth" value="11.29" type="Double" />
<column name="Source" property="Validation.Type" value="6" type="Double" />
<column name="Source" property="Validation.AlertStyle" value="1" type="Double" />
<column name="Source" property="Validation.Operator" value="8" type="Double" />
<column name="Source" property="Validation.Formula1" value="50" type="String" />
<column name="Source" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="Source" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="Source" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="Source" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceID" property="Address" value="$D$4" type="String" />
<column name="SourceID" property="Validation.Type" value="6" type="Double" />
<column name="SourceID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SourceID" property="Validation.Operator" value="8" type="Double" />
<column name="SourceID" property="Validation.Formula1" value="50" type="String" />
<column name="SourceID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SourceID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SourceID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SourceID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="MergeDate" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="MergeDate" property="Address" value="$E$4" type="String" />
<column name="MergeDate" property="NumberFormat" value="m/d/yyyy h:mm" type="String" />
<column name="MergeDate" property="Validation.Type" value="4" type="Double" />
<column name="MergeDate" property="Validation.AlertStyle" value="1" type="Double" />
<column name="MergeDate" property="Validation.Operator" value="5" type="Double" />
<column name="MergeDate" property="Validation.Formula1" value="01.01.1900" type="String" />
<column name="MergeDate" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="MergeDate" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="MergeDate" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="MergeDate" property="Validation.ShowError" value="True" type="Boolean" />
<column name="IsJunk" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="IsJunk" property="Address" value="$F$4" type="String" />
<column name="IsJunk" property="ColumnWidth" value="8" type="Double" />
<column name="IsJunk" property="Validation.Type" value="1" type="Double" />
<column name="IsJunk" property="Validation.AlertStyle" value="1" type="Double" />
<column name="IsJunk" property="Validation.Operator" value="1" type="Double" />
<column name="IsJunk" property="Validation.Formula1" value="0" type="String" />
<column name="IsJunk" property="Validation.Formula2" value="255" type="String" />
<column name="IsJunk" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="IsJunk" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="IsJunk" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="IsJunk" property="Validation.ShowError" value="True" type="Boolean" />
<column name="ContactID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ContactID" property="Address" value="$G$4" type="String" />
<column name="ContactID" property="ColumnWidth" value="11.14" type="Double" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="Address" value="$H$4" type="String" />
<column name="SourceFirstName" property="ColumnWidth" value="25.29" type="Double" />
<column name="SourceFirstName" property="Validation.Type" value="6" type="Double" />
<column name="SourceFirstName" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SourceFirstName" property="Validation.Operator" value="8" type="Double" />
<column name="SourceFirstName" property="Validation.Formula1" value="255" type="String" />
<column name="SourceFirstName" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SourceFirstName" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SourceFirstName" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SourceFirstName" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="Address" value="$I$4" type="String" />
<column name="SourceLastName" property="ColumnWidth" value="17.43" type="Double" />
<column name="SourceLastName" property="Validation.Type" value="6" type="Double" />
<column name="SourceLastName" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SourceLastName" property="Validation.Operator" value="8" type="Double" />
<column name="SourceLastName" property="Validation.Formula1" value="255" type="String" />
<column name="SourceLastName" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SourceLastName" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SourceLastName" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SourceLastName" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceEmail" property="Address" value="$J$4" type="String" />
<column name="SourceEmail" property="ColumnWidth" value="31.71" type="Double" />
<column name="SourceEmail" property="Validation.Type" value="6" type="Double" />
<column name="SourceEmail" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SourceEmail" property="Validation.Operator" value="8" type="Double" />
<column name="SourceEmail" property="Validation.Formula1" value="255" type="String" />
<column name="SourceEmail" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SourceEmail" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SourceEmail" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SourceEmail" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SourceSecondaryEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceSecondaryEmail" property="Address" value="$K$4" type="String" />
<column name="SourceSecondaryEmail" property="ColumnWidth" value="23" type="Double" />
<column name="SourceSecondaryEmail" property="Validation.Type" value="6" type="Double" />
<column name="SourceSecondaryEmail" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SourceSecondaryEmail" property="Validation.Operator" value="8" type="Double" />
<column name="SourceSecondaryEmail" property="Validation.Formula1" value="255" type="String" />
<column name="SourceSecondaryEmail" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SourceSecondaryEmail" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SourceSecondaryEmail" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SourceSecondaryEmail" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SourceMobile" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceMobile" property="Address" value="$L$4" type="String" />
<column name="SourceMobile" property="ColumnWidth" value="17.29" type="Double" />
<column name="SourceMobile" property="Validation.Type" value="6" type="Double" />
<column name="SourceMobile" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SourceMobile" property="Validation.Operator" value="8" type="Double" />
<column name="SourceMobile" property="Validation.Formula1" value="255" type="String" />
<column name="SourceMobile" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SourceMobile" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SourceMobile" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SourceMobile" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SourcePhone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourcePhone" property="Address" value="$M$4" type="String" />
<column name="SourcePhone" property="ColumnWidth" value="14.29" type="Double" />
<column name="SourcePhone" property="Validation.Type" value="6" type="Double" />
<column name="SourcePhone" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SourcePhone" property="Validation.Operator" value="8" type="Double" />
<column name="SourcePhone" property="Validation.Formula1" value="255" type="String" />
<column name="SourcePhone" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SourcePhone" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SourcePhone" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SourcePhone" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SourceCompany" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceCompany" property="Address" value="$N$4" type="String" />
<column name="SourceCompany" property="ColumnWidth" value="17.86" type="Double" />
<column name="SourceCompany" property="Validation.Type" value="6" type="Double" />
<column name="SourceCompany" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SourceCompany" property="Validation.Operator" value="8" type="Double" />
<column name="SourceCompany" property="Validation.Formula1" value="255" type="String" />
<column name="SourceCompany" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SourceCompany" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SourceCompany" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SourceCompany" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SourceJobTitle" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceJobTitle" property="Address" value="$O$4" type="String" />
<column name="SourceJobTitle" property="ColumnWidth" value="19.71" type="Double" />
<column name="SourceHeadline" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceHeadline" property="Address" value="$P$4" type="String" />
<column name="SourceHeadline" property="ColumnWidth" value="16.71" type="Double" />
<column name="SourceHeadline" property="Validation.Type" value="6" type="Double" />
<column name="SourceHeadline" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SourceHeadline" property="Validation.Operator" value="8" type="Double" />
<column name="SourceHeadline" property="Validation.Formula1" value="255" type="String" />
<column name="SourceHeadline" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SourceHeadline" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SourceHeadline" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SourceHeadline" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SourceIndustry" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceIndustry" property="Address" value="$Q$4" type="String" />
<column name="SourceIndustry" property="ColumnWidth" value="16" type="Double" />
<column name="SourceIndustry" property="Validation.Type" value="6" type="Double" />
<column name="SourceIndustry" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SourceIndustry" property="Validation.Operator" value="8" type="Double" />
<column name="SourceIndustry" property="Validation.Formula1" value="255" type="String" />
<column name="SourceIndustry" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SourceIndustry" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SourceIndustry" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SourceIndustry" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SourceLocationName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLocationName" property="Address" value="$R$4" type="String" />
<column name="SourceLocationName" property="ColumnWidth" value="21.57" type="Double" />
<column name="SourceLocationName" property="Validation.Type" value="6" type="Double" />
<column name="SourceLocationName" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SourceLocationName" property="Validation.Operator" value="8" type="Double" />
<column name="SourceLocationName" property="Validation.Formula1" value="255" type="String" />
<column name="SourceLocationName" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SourceLocationName" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SourceLocationName" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SourceLocationName" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SourceCountryCode" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceCountryCode" property="Address" value="$S$4" type="String" />
<column name="SourceCountryCode" property="ColumnWidth" value="20.43" type="Double" />
<column name="SourceCountryCode" property="Validation.Type" value="6" type="Double" />
<column name="SourceCountryCode" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SourceCountryCode" property="Validation.Operator" value="8" type="Double" />
<column name="SourceCountryCode" property="Validation.Formula1" value="2" type="String" />
<column name="SourceCountryCode" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SourceCountryCode" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SourceCountryCode" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SourceCountryCode" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SourceProfileUrl" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceProfileUrl" property="Address" value="$T$4" type="String" />
<column name="SourceProfileUrl" property="ColumnWidth" value="17.43" type="Double" />
<column name="SourceProfileUrl" property="Validation.Type" value="6" type="Double" />
<column name="SourceProfileUrl" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SourceProfileUrl" property="Validation.Operator" value="8" type="Double" />
<column name="SourceProfileUrl" property="Validation.Formula1" value="255" type="String" />
<column name="SourceProfileUrl" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SourceProfileUrl" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SourceProfileUrl" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SourceProfileUrl" property="Validation.ShowError" value="True" type="Boolean" />
<column name="Source" property="FormatConditions(1).ColumnsCount" value="2" type="Double" />
<column name="Source" property="FormatConditions(1).AppliesTo.Address" value="$C$4:$D$4900" type="String" />
<column name="Source" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="Source" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="Source" property="FormatConditions(1).Formula1" value="=ISBLANK(C4)" type="String" />
<column name="Source" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="Source" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="Source" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="2" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="2" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
<column name="" property="PageSetup.LeftMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.RightMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.TopMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.BottomMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.HeaderMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.FooterMargin" value="22.6771653543307" type="Double" />
</columnFormats>
<views>
<view name="All">
<column name="" property="ListObjectName" value="SourceContacts" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="MergeDate" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="IsJunk" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ContactID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceSecondaryEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceMobile" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourcePhone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceCompany" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceTitle" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceHeadline" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceIndustry" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLocationName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceCountryCode" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceProfileUrl" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
<view name="Main Fields">
<column name="" property="ListObjectName" value="SourceContacts" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="MergeDate" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="IsJunk" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ContactID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceSecondaryEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceMobile" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourcePhone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceCompany" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceTitle" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceHeadline" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceIndustry" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLocationName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceCountryCode" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceProfileUrl" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
</views>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,'View Contacts','<?xml version="1.0" encoding="Unicode"?>
<table name=".View Contacts">
<columnFormats>
<column name="" property="ListObjectName" value="Contacts_Table" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="True" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$4" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ContactStatus" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ContactStatus" property="Address" value="$D$4" type="String" />
<column name="ContactStatus" property="ColumnWidth" value="2.14" type="Double" />
<column name="ContactStatus" property="HorizontalAlignment" value="-4108" type="Double" />
<column name="ContactStatus" property="Font.Size" value="10" type="Double" />
<column name="IsDoubleName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="IsDoubleName" property="Address" value="$E$4" type="String" />
<column name="IsDoubleName" property="ColumnWidth" value="3.14" type="Double" />
<column name="ContactCategory" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ContactCategory" property="Address" value="$F$4" type="String" />
<column name="ContactCategory" property="ColumnWidth" value="17.29" type="Double" />
<column name="FirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="FirstName" property="Address" value="$G$4" type="String" />
<column name="FirstName" property="ColumnWidth" value="25.29" type="Double" />
<column name="LastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LastName" property="Address" value="$H$4" type="String" />
<column name="LastName" property="ColumnWidth" value="29.71" type="Double" />
<column name="Email" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Email" property="Address" value="$I$4" type="String" />
<column name="Email" property="ColumnWidth" value="31.71" type="Double" />
<column name="Mobile" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Mobile" property="Address" value="$J$4" type="String" />
<column name="Mobile" property="ColumnWidth" value="17.29" type="Double" />
<column name="Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Phone" property="Address" value="$K$4" type="String" />
<column name="Phone" property="ColumnWidth" value="8.57" type="Double" />
<column name="Country" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Country" property="Address" value="$L$4" type="String" />
<column name="Country" property="ColumnWidth" value="19.29" type="Double" />
<column name="Domain" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Domain" property="Address" value="$M$4" type="String" />
<column name="Website" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Website" property="Address" value="$N$4" type="String" />
<column name="Website" property="ColumnWidth" value="27.71" type="Double" />
<column name="Company" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Company" property="Address" value="$O$4" type="String" />
<column name="Company" property="ColumnWidth" value="29" type="Double" />
<column name="JobTitle" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="JobTitle" property="Address" value="$P$4" type="String" />
<column name="JobTitle" property="ColumnWidth" value="22.29" type="Double" />
<column name="LinkedInHeadline" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LinkedInHeadline" property="Address" value="$Q$4" type="String" />
<column name="LinkedInHeadline" property="ColumnWidth" value="28.43" type="Double" />
<column name="LinkedInProfileUrl" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="LinkedInProfileUrl" property="Address" value="$R$4" type="String" />
<column name="GooglePlusProfileUrl" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="GooglePlusProfileUrl" property="Address" value="$S$4" type="String" />
<column name="Industry" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Industry" property="Address" value="$T$4" type="String" />
<column name="Industry" property="ColumnWidth" value="19.14" type="Double" />
<column name="LocationName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LocationName" property="Address" value="$U$4" type="String" />
<column name="LocationName" property="ColumnWidth" value="19.14" type="Double" />
<column name="String1" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="String1" property="Address" value="$V$4" type="String" />
<column name="String1" property="ColumnWidth" value="19.14" type="Double" />
<column name="String2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="String2" property="Address" value="$W$4" type="String" />
<column name="String2" property="ColumnWidth" value="19.14" type="Double" />
<column name="String3" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="String3" property="Address" value="$X$4" type="String" />
<column name="String3" property="ColumnWidth" value="19.14" type="Double" />
<column name="Number1" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Number1" property="Address" value="$Y$4" type="String" />
<column name="Number1" property="ColumnWidth" value="19.14" type="Double" />
<column name="Number2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Number2" property="Address" value="$Z$4" type="String" />
<column name="Number2" property="ColumnWidth" value="19.14" type="Double" />
<column name="Number3" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Number3" property="Address" value="$AA$4" type="String" />
<column name="Number3" property="ColumnWidth" value="19.14" type="Double" />
<column name="ContactStatus" property="FormatConditions(1).AppliesTo.Address" value="$D$4:$D$2590" type="String" />
<column name="ContactStatus" property="FormatConditions(1).Type" value="6" type="Double" />
<column name="ContactStatus" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="ContactStatus" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" />
<column name="ContactStatus" property="FormatConditions(1).IconSet.ID" value="13" type="Double" />
<column name="ContactStatus" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" />
<column name="ContactStatus" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" />
<column name="ContactStatus" property="FormatConditions(1).IconCriteria(2).Value" value="1" type="Double" />
<column name="ContactStatus" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" />
<column name="ContactStatus" property="FormatConditions(1).IconCriteria(3).Value" value="2" type="Double" />
<column name="ContactStatus" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" />
<column name="ContactStatus" property="FormatConditions(1).IconCriteria(4).Value" value="3" type="Double" />
<column name="ContactStatus" property="FormatConditions(1).IconCriteria(4).Operator" value="7" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="2" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="2" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
<column name="" property="PageSetup.LeftMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.RightMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.TopMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.BottomMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.HeaderMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.FooterMargin" value="22.6771653543307" type="Double" />
</columnFormats>
<views>
<view name="All">
<column name="" property="ListObjectName" value="SourceContacts8" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ContactStatus" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="IsDoubleName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ContactCategory" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="FirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Email" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Mobile" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Domain" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Website" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Company" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Title" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LinkedInHeadline" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LinkedInProfileUrl" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="GooglePlusProfileUrl" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
<view name="Main Fields">
<column name="" property="ListObjectName" value="SourceContacts8" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ContactStatus" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="IsDoubleName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ContactCategory" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="FirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Email" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Mobile" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Country" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Domain" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Website" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Company" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Title" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LinkedInHeadline" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LinkedInProfileUrl" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="GooglePlusProfileUrl" property="EntireColumn.Hidden" value="True" type="Boolean" />
</view>
</views>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,'Source Contacts By ContactID','<?xml version="1.0" encoding="Unicode"?>
<table name=".Source Contacts By ContactID">
<columnFormats>
<column name="" property="ListObjectName" value="ContactDetails_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium2" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="True" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$3" type="String" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Source" property="Address" value="$C$3" type="String" />
<column name="Source" property="ColumnWidth" value="11.29" type="Double" />
<column name="SourceID" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceID" property="Address" value="$D$3" type="String" />
<column name="MergeDate" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="MergeDate" property="Address" value="$E$3" type="String" />
<column name="MergeDate" property="NumberFormat" value="m/d/yyyy" type="String" />
<column name="IsJunk" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="IsJunk" property="Address" value="$F$3" type="String" />
<column name="IsJunk" property="ColumnWidth" value="8" type="Double" />
<column name="IsJunk" property="HorizontalAlignment" value="-4108" type="Double" />
<column name="IsJunk" property="Font.Size" value="10" type="Double" />
<column name="ContactID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ContactID" property="Address" value="$G$3" type="String" />
<column name="ContactID" property="ColumnWidth" value="11.14" type="Double" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="Address" value="$H$3" type="String" />
<column name="SourceFirstName" property="ColumnWidth" value="19" type="Double" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="Address" value="$I$3" type="String" />
<column name="SourceLastName" property="ColumnWidth" value="18" type="Double" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceEmail" property="Address" value="$J$3" type="String" />
<column name="SourceEmail" property="ColumnWidth" value="27.29" type="Double" />
<column name="SourceSecondaryEmail" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceSecondaryEmail" property="Address" value="$K$3" type="String" />
<column name="SourceMobile" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceMobile" property="Address" value="$L$3" type="String" />
<column name="SourcePhone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourcePhone" property="Address" value="$M$3" type="String" />
<column name="SourceCompany" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceCompany" property="Address" value="$N$3" type="String" />
<column name="SourceJobTitle" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceJobTitle" property="Address" value="$O$3" type="String" />
<column name="SourceJobTitle" property="ColumnWidth" value="12.57" type="Double" />
<column name="SourceHeadline" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceHeadline" property="Address" value="$P$3" type="String" />
<column name="SourceHeadline" property="ColumnWidth" value="51.86" type="Double" />
<column name="SourceIndustry" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceIndustry" property="Address" value="$Q$3" type="String" />
<column name="SourceIndustry" property="ColumnWidth" value="34.43" type="Double" />
<column name="SourceLocationName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLocationName" property="Address" value="$R$3" type="String" />
<column name="SourceLocationName" property="ColumnWidth" value="43" type="Double" />
<column name="SourceCountryCode" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceCountryCode" property="Address" value="$S$3" type="String" />
<column name="SourceCountryCode" property="ColumnWidth" value="20.43" type="Double" />
<column name="SourceProfileUrl" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceProfileUrl" property="Address" value="$T$3" type="String" />
<column name="SourceProfileUrl" property="ColumnWidth" value="19.43" type="Double" />
<column name="IsJunk" property="FormatConditions(1).AppliesTo.Address" value="$F$3:$F$4" type="String" />
<column name="IsJunk" property="FormatConditions(1).Type" value="6" type="Double" />
<column name="IsJunk" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="IsJunk" property="FormatConditions(1).ReverseOrder" value="True" type="Boolean" />
<column name="IsJunk" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" />
<column name="IsJunk" property="FormatConditions(1).IconSet.ID" value="8" type="Double" />
<column name="IsJunk" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" />
<column name="IsJunk" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" />
<column name="IsJunk" property="FormatConditions(1).IconCriteria(2).Value" value="0.5" type="Double" />
<column name="IsJunk" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" />
<column name="IsJunk" property="FormatConditions(1).IconCriteria(3).Value" value="1" type="Double" />
<column name="IsJunk" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.Zoom" value="100" type="Double" />
</columnFormats>
<views>
<view name="All">
<column name="" property="ListObjectName" value="ContactDetails_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="MergeDate" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="IsJunk" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ContactID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceSecondaryEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceMobile" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourcePhone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceCompany" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceTitle" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceHeadline" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceIndustry" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLocationName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceCountryCode" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceProfileUrl" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
<view name="Main Fields">
<column name="" property="ListObjectName" value="ContactDetails_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceID" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="MergeDate" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="IsJunk" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ContactID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceSecondaryEmail" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceMobile" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourcePhone" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceCompany" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceTitle" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SourceHeadline" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceIndustry" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceLocationName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceCountryCode" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SourceProfileUrl" property="EntireColumn.Hidden" value="False" type="Boolean" />
</view>
</views>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,'Contacts By Country','<?xml version="1.0" encoding="Unicode"?>
<table name=".Contacts By Country">
<columnFormats>
<column name="" property="ListObjectName" value="CountryDetails_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium2" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="True" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$3" type="String" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$3" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ContactStatus" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ContactStatus" property="Address" value="$D$3" type="String" />
<column name="ContactStatus" property="ColumnWidth" value="14.86" type="Double" />
<column name="ContactStatus" property="HorizontalAlignment" value="-4108" type="Double" />
<column name="ContactStatus" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ContactStatus" property="Font.Size" value="10" type="Double" />
<column name="IsDoubleName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="IsDoubleName" property="Address" value="$E$3" type="String" />
<column name="IsDoubleName" property="ColumnWidth" value="17.29" type="Double" />
<column name="ContactCategory" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ContactCategory" property="Address" value="$F$3" type="String" />
<column name="ContactCategory" property="ColumnWidth" value="17.29" type="Double" />
<column name="FirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="FirstName" property="Address" value="$G$3" type="String" />
<column name="FirstName" property="ColumnWidth" value="11.71" type="Double" />
<column name="LastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LastName" property="Address" value="$H$3" type="String" />
<column name="LastName" property="ColumnWidth" value="21.71" type="Double" />
<column name="Email" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Email" property="Address" value="$I$3" type="String" />
<column name="Email" property="ColumnWidth" value="30" type="Double" />
<column name="Mobile" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Mobile" property="Address" value="$J$3" type="String" />
<column name="Mobile" property="ColumnWidth" value="9" type="Double" />
<column name="Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Phone" property="Address" value="$K$3" type="String" />
<column name="Phone" property="ColumnWidth" value="8.29" type="Double" />
<column name="Country" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Country" property="Address" value="$L$3" type="String" />
<column name="Country" property="ColumnWidth" value="11.29" type="Double" />
<column name="Domain" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Domain" property="Address" value="$M$3" type="String" />
<column name="Domain" property="ColumnWidth" value="27.57" type="Double" />
<column name="Website" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Website" property="Address" value="$N$3" type="String" />
<column name="Website" property="ColumnWidth" value="10.14" type="Double" />
<column name="Company" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Company" property="Address" value="$O$3" type="String" />
<column name="Company" property="ColumnWidth" value="27.57" type="Double" />
<column name="JobTitle" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="JobTitle" property="Address" value="$P$3" type="String" />
<column name="JobTitle" property="ColumnWidth" value="18.43" type="Double" />
<column name="LinkedInHeadline" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LinkedInHeadline" property="Address" value="$Q$3" type="String" />
<column name="LinkedInHeadline" property="ColumnWidth" value="21.71" type="Double" />
<column name="Industry" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Industry" property="Address" value="$R$3" type="String" />
<column name="Industry" property="ColumnWidth" value="21.71" type="Double" />
<column name="LocationName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LocationName" property="Address" value="$S$3" type="String" />
<column name="LocationName" property="ColumnWidth" value="21.71" type="Double" />
<column name="LinkedInProfileUrl" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LinkedInProfileUrl" property="Address" value="$T$3" type="String" />
<column name="LinkedInProfileUrl" property="ColumnWidth" value="21.71" type="Double" />
<column name="GooglePlusProfileUrl" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="GooglePlusProfileUrl" property="Address" value="$U$3" type="String" />
<column name="GooglePlusProfileUrl" property="ColumnWidth" value="21.71" type="Double" />
<column name="String1" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="String1" property="Address" value="$V$3" type="String" />
<column name="String1" property="ColumnWidth" value="21.71" type="Double" />
<column name="String2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="String2" property="Address" value="$W$3" type="String" />
<column name="String2" property="ColumnWidth" value="21.71" type="Double" />
<column name="String3" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="String3" property="Address" value="$X$3" type="String" />
<column name="String3" property="ColumnWidth" value="21.71" type="Double" />
<column name="Number1" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Number1" property="Address" value="$Y$3" type="String" />
<column name="Number1" property="ColumnWidth" value="21.71" type="Double" />
<column name="Number2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Number2" property="Address" value="$Z$3" type="String" />
<column name="Number2" property="ColumnWidth" value="21.71" type="Double" />
<column name="Number3" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Number3" property="Address" value="$AA$3" type="String" />
<column name="Number3" property="ColumnWidth" value="21.71" type="Double" />
<column name="ContactStatus" property="FormatConditions(1).AppliesTo.Address" value="$D$3:$D$6" type="String" />
<column name="ContactStatus" property="FormatConditions(1).Type" value="6" type="Double" />
<column name="ContactStatus" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="ContactStatus" property="FormatConditions(1).ShowIconOnly" value="True" type="Boolean" />
<column name="ContactStatus" property="FormatConditions(1).IconSet.ID" value="13" type="Double" />
<column name="ContactStatus" property="FormatConditions(1).IconCriteria(1).Type" value="3" type="Double" />
<column name="ContactStatus" property="FormatConditions(1).IconCriteria(1).Operator" value="7" type="Double" />
<column name="ContactStatus" property="FormatConditions(1).IconCriteria(2).Value" value="1" type="Double" />
<column name="ContactStatus" property="FormatConditions(1).IconCriteria(2).Operator" value="7" type="Double" />
<column name="ContactStatus" property="FormatConditions(1).IconCriteria(3).Value" value="2" type="Double" />
<column name="ContactStatus" property="FormatConditions(1).IconCriteria(3).Operator" value="7" type="Double" />
<column name="ContactStatus" property="FormatConditions(1).IconCriteria(4).Value" value="3" type="Double" />
<column name="ContactStatus" property="FormatConditions(1).IconCriteria(4).Operator" value="7" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="2" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
<column name="" property="PageSetup.LeftMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.RightMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.TopMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.BottomMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.HeaderMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.FooterMargin" value="22.6771653543307" type="Double" />
</columnFormats>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,'Contacts By Domain','<?xml version="1.0" encoding="Unicode"?>
<table name=".Contacts By Domain">
<columnFormats>
<column name="" property="ListObjectName" value="WebsiteDetails_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium2" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="True" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$3" type="String" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$3" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ContactStatus" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ContactStatus" property="Address" value="$D$3" type="String" />
<column name="ContactStatus" property="ColumnWidth" value="14.86" type="Double" />
<column name="IsDoubleName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="IsDoubleName" property="Address" value="$E$3" type="String" />
<column name="IsDoubleName" property="ColumnWidth" value="17.29" type="Double" />
<column name="ContactCategory" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ContactCategory" property="Address" value="$F$3" type="String" />
<column name="ContactCategory" property="ColumnWidth" value="17.29" type="Double" />
<column name="FirstName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="FirstName" property="Address" value="$G$3" type="String" />
<column name="FirstName" property="ColumnWidth" value="11.71" type="Double" />
<column name="LastName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LastName" property="Address" value="$H$3" type="String" />
<column name="LastName" property="ColumnWidth" value="11.29" type="Double" />
<column name="Email" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Email" property="Address" value="$I$3" type="String" />
<column name="Email" property="ColumnWidth" value="29.29" type="Double" />
<column name="Mobile" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Mobile" property="Address" value="$J$3" type="String" />
<column name="Mobile" property="ColumnWidth" value="9" type="Double" />
<column name="Phone" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Phone" property="Address" value="$K$3" type="String" />
<column name="Phone" property="ColumnWidth" value="8.29" type="Double" />
<column name="Country" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Country" property="Address" value="$L$3" type="String" />
<column name="Country" property="ColumnWidth" value="12.14" type="Double" />
<column name="Domain" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Domain" property="Address" value="$M$3" type="String" />
<column name="Domain" property="ColumnWidth" value="70.71" type="Double" />
<column name="Website" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Website" property="Address" value="$N$3" type="String" />
<column name="Website" property="ColumnWidth" value="24.57" type="Double" />
<column name="Company" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Company" property="Address" value="$O$3" type="String" />
<column name="Company" property="ColumnWidth" value="70.71" type="Double" />
<column name="JobTitle" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="JobTitle" property="Address" value="$P$3" type="String" />
<column name="JobTitle" property="ColumnWidth" value="26.14" type="Double" />
<column name="LinkedInHeadline" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LinkedInHeadline" property="Address" value="$Q$3" type="String" />
<column name="LinkedInHeadline" property="ColumnWidth" value="39.57" type="Double" />
<column name="Industry" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Industry" property="Address" value="$R$3" type="String" />
<column name="Industry" property="ColumnWidth" value="17.86" type="Double" />
<column name="LocationName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LocationName" property="Address" value="$S$3" type="String" />
<column name="LocationName" property="ColumnWidth" value="29" type="Double" />
<column name="LinkedInProfileUrl" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LinkedInProfileUrl" property="Address" value="$T$3" type="String" />
<column name="LinkedInProfileUrl" property="ColumnWidth" value="70.71" type="Double" />
<column name="GooglePlusProfileUrl" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="GooglePlusProfileUrl" property="Address" value="$U$3" type="String" />
<column name="GooglePlusProfileUrl" property="ColumnWidth" value="21.71" type="Double" />
<column name="String1" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="String1" property="Address" value="$V$3" type="String" />
<column name="String1" property="ColumnWidth" value="70.71" type="Double" />
<column name="String2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="String2" property="Address" value="$W$3" type="String" />
<column name="String2" property="ColumnWidth" value="26.14" type="Double" />
<column name="String3" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="String3" property="Address" value="$X$3" type="String" />
<column name="String3" property="ColumnWidth" value="39.57" type="Double" />
<column name="Number1" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Number1" property="Address" value="$Y$3" type="String" />
<column name="Number1" property="ColumnWidth" value="17.86" type="Double" />
<column name="Number2" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Number2" property="Address" value="$Z$3" type="String" />
<column name="Number2" property="ColumnWidth" value="29" type="Double" />
<column name="Number3" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Number3" property="Address" value="$AA$3" type="String" />
<column name="Number3" property="ColumnWidth" value="70.71" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
<column name="" property="PageSetup.LeftMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.RightMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.TopMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.BottomMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.HeaderMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.FooterMargin" value="22.6771653543307" type="Double" />
</columnFormats>
</table>
');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,'Contacts','<table name="Contacts"><columnFormats><column name="" property="ListObjectName" value="SourceContacts8" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium2" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="True" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ID" property="Address" value="$C$4" type="String" /><column name="ID" property="ColumnWidth" value="4.43" type="Double" /><column name="ID" property="Validation.Type" value="1" type="Double" /><column name="ID" property="Validation.AlertStyle" value="1" type="Double" /><column name="ID" property="Validation.Operator" value="1" type="Double" /><column name="ID" property="Validation.Formula1" value="-2147483648" type="String" /><column name="ID" property="Validation.Formula2" value="2147483647" type="String" /><column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" /><column name="ID" property="Validation.ShowInput" value="True" type="Boolean" /><column name="ID" property="Validation.ShowError" value="True" type="Boolean" /><column name="ContactStatus" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ContactStatus" property="Address" value="$D$4" type="String" /><column name="ContactStatus" property="ColumnWidth" value="14.86" type="Double" /><column name="ContactStatus" property="Validation.Type" value="1" type="Double" /><column name="ContactStatus" property="Validation.AlertStyle" value="1" type="Double" /><column name="ContactStatus" property="Validation.Operator" value="1" type="Double" /><column name="ContactStatus" property="Validation.Formula1" value="0" type="String" /><column name="ContactStatus" property="Validation.Formula2" value="255" type="String" /><column name="ContactStatus" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="ContactStatus" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="ContactStatus" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="ContactStatus" property="Validation.ErrorMessage" value="The column requires values of the tinyint datatype." type="String" /><column name="ContactStatus" property="Validation.ShowInput" value="True" type="Boolean" /><column name="ContactStatus" property="Validation.ShowError" value="True" type="Boolean" /><column name="ContactCategory" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ContactCategory" property="Address" value="$E$4" type="String" /><column name="ContactCategory" property="ColumnWidth" value="17.29" type="Double" /><column name="ContactCategory" property="Validation.Type" value="6" type="Double" /><column name="ContactCategory" property="Validation.AlertStyle" value="1" type="Double" /><column name="ContactCategory" property="Validation.Operator" value="8" type="Double" /><column name="ContactCategory" property="Validation.Formula1" value="255" type="String" /><column name="ContactCategory" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="ContactCategory" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="ContactCategory" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="ContactCategory" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="ContactCategory" property="Validation.ShowInput" value="True" type="Boolean" /><column name="ContactCategory" property="Validation.ShowError" value="True" type="Boolean" /><column name="FirstName" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="FirstName" property="Address" value="$F$4" type="String" /><column name="FirstName" property="ColumnWidth" value="22.86" type="Double" /><column name="FirstName" property="Validation.Type" value="6" type="Double" /><column name="FirstName" property="Validation.AlertStyle" value="1" type="Double" /><column name="FirstName" property="Validation.Operator" value="8" type="Double" /><column name="FirstName" property="Validation.Formula1" value="255" type="String" /><column name="FirstName" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="FirstName" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="FirstName" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="FirstName" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="FirstName" property="Validation.ShowInput" value="True" type="Boolean" /><column name="FirstName" property="Validation.ShowError" value="True" type="Boolean" /><column name="LastName" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="LastName" property="Address" value="$G$4" type="String" /><column name="LastName" property="ColumnWidth" value="12.71" type="Double" /><column name="LastName" property="Validation.Type" value="6" type="Double" /><column name="LastName" property="Validation.AlertStyle" value="1" type="Double" /><column name="LastName" property="Validation.Operator" value="8" type="Double" /><column name="LastName" property="Validation.Formula1" value="255" type="String" /><column name="LastName" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="LastName" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="LastName" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="LastName" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="LastName" property="Validation.ShowInput" value="True" type="Boolean" /><column name="LastName" property="Validation.ShowError" value="True" type="Boolean" /><column name="Email" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="Email" property="Address" value="$H$4" type="String" /><column name="Email" property="ColumnWidth" value="31.71" type="Double" /><column name="Email" property="Validation.Type" value="6" type="Double" /><column name="Email" property="Validation.AlertStyle" value="1" type="Double" /><column name="Email" property="Validation.Operator" value="8" type="Double" /><column name="Email" property="Validation.Formula1" value="255" type="String" /><column name="Email" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="Email" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="Email" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="Email" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="Email" property="Validation.ShowInput" value="True" type="Boolean" /><column name="Email" property="Validation.ShowError" value="True" type="Boolean" /><column name="Mobile" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="Mobile" property="Address" value="$I$4" type="String" /><column name="Mobile" property="ColumnWidth" value="17.43" type="Double" /><column name="Mobile" property="Validation.Type" value="6" type="Double" /><column name="Mobile" property="Validation.AlertStyle" value="1" type="Double" /><column name="Mobile" property="Validation.Operator" value="8" type="Double" /><column name="Mobile" property="Validation.Formula1" value="255" type="String" /><column name="Mobile" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="Mobile" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="Mobile" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="Mobile" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="Mobile" property="Validation.ShowInput" value="True" type="Boolean" /><column name="Mobile" property="Validation.ShowError" value="True" type="Boolean" /><column name="Phone" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="Phone" property="Address" value="$J$4" type="String" /><column name="Phone" property="ColumnWidth" value="16" type="Double" /><column name="Phone" property="Validation.Type" value="6" type="Double" /><column name="Phone" property="Validation.AlertStyle" value="1" type="Double" /><column name="Phone" property="Validation.Operator" value="8" type="Double" /><column name="Phone" property="Validation.Formula1" value="255" type="String" /><column name="Phone" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="Phone" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="Phone" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="Phone" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="Phone" property="Validation.ShowInput" value="True" type="Boolean" /><column name="Phone" property="Validation.ShowError" value="True" type="Boolean" /><column name="Website" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="Website" property="Address" value="$K$4" type="String" /><column name="Website" property="ColumnWidth" value="15" type="Double" /><column name="Website" property="Validation.Type" value="6" type="Double" /><column name="Website" property="Validation.AlertStyle" value="1" type="Double" /><column name="Website" property="Validation.Operator" value="8" type="Double" /><column name="Website" property="Validation.Formula1" value="255" type="String" /><column name="Website" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="Website" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="Website" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="Website" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="Website" property="Validation.ShowInput" value="True" type="Boolean" /><column name="Website" property="Validation.ShowError" value="True" type="Boolean" /><column name="Company" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="Company" property="Address" value="$L$4" type="String" /><column name="Company" property="ColumnWidth" value="15.71" type="Double" /><column name="Company" property="Validation.Type" value="6" type="Double" /><column name="Company" property="Validation.AlertStyle" value="1" type="Double" /><column name="Company" property="Validation.Operator" value="8" type="Double" /><column name="Company" property="Validation.Formula1" value="255" type="String" /><column name="Company" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="Company" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="Company" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="Company" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="Company" property="Validation.ShowInput" value="True" type="Boolean" /><column name="Company" property="Validation.ShowError" value="True" type="Boolean" /><column name="Title" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="Title" property="Address" value="$M$4" type="String" /><column name="Title" property="ColumnWidth" value="24.71" type="Double" /><column name="Title" property="Validation.Type" value="6" type="Double" /><column name="Title" property="Validation.AlertStyle" value="1" type="Double" /><column name="Title" property="Validation.Operator" value="8" type="Double" /><column name="Title" property="Validation.Formula1" value="255" type="String" /><column name="Title" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="Title" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="Title" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="Title" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="Title" property="Validation.ShowInput" value="True" type="Boolean" /><column name="Title" property="Validation.ShowError" value="True" type="Boolean" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="2" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="2" type="Double" /><column name="" property="PageSetup.PaperSize" value="1" type="Double" /><column name="" property="PageSetup.LeftMargin" value="22.6771653543307" type="Double" /><column name="" property="PageSetup.RightMargin" value="22.6771653543307" type="Double" /><column name="" property="PageSetup.TopMargin" value="25.511811023622" type="Double" /><column name="" property="PageSetup.BottomMargin" value="25.511811023622" type="Double" /><column name="" property="PageSetup.HeaderMargin" value="22.6771653543307" type="Double" /><column name="" property="PageSetup.FooterMargin" value="22.6771653543307" type="Double" /></columnFormats></table>');
GO
INSERT INTO [TableFormats] ([TABLE_SCHEMA],[TABLE_NAME],[TABLE_EXCEL_FORMAT_XML]) VALUES (NULL,'SourceContacts','<table name="SourceContacts"><columnFormats><column name="" property="ListObjectName" value="SourceContacts" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium2" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="True" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="Source" property="Address" value="$C$4" type="String" /><column name="Source" property="ColumnWidth" value="8.57" type="Double" /><column name="Source" property="Validation.Type" value="6" type="Double" /><column name="Source" property="Validation.AlertStyle" value="1" type="Double" /><column name="Source" property="Validation.Operator" value="8" type="Double" /><column name="Source" property="Validation.Formula1" value="50" type="String" /><column name="Source" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="Source" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="Source" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="Source" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(50) datatype." type="String" /><column name="Source" property="Validation.ShowInput" value="True" type="Boolean" /><column name="Source" property="Validation.ShowError" value="True" type="Boolean" /><column name="SourceID" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="SourceID" property="Address" value="$D$4" type="String" /><column name="SourceID" property="Validation.Type" value="6" type="Double" /><column name="SourceID" property="Validation.AlertStyle" value="1" type="Double" /><column name="SourceID" property="Validation.Operator" value="8" type="Double" /><column name="SourceID" property="Validation.Formula1" value="50" type="String" /><column name="SourceID" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="SourceID" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="SourceID" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="SourceID" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(50) datatype." type="String" /><column name="SourceID" property="Validation.ShowInput" value="True" type="Boolean" /><column name="SourceID" property="Validation.ShowError" value="True" type="Boolean" /><column name="MergeDate" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="MergeDate" property="Address" value="$E$4" type="String" /><column name="MergeDate" property="NumberFormat" value="m/d/yyyy h:mm" type="String" /><column name="MergeDate" property="Validation.Type" value="4" type="Double" /><column name="MergeDate" property="Validation.AlertStyle" value="1" type="Double" /><column name="MergeDate" property="Validation.Operator" value="5" type="Double" /><column name="MergeDate" property="Validation.Formula1" value="01.01.1900" type="String" /><column name="MergeDate" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="MergeDate" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="MergeDate" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="MergeDate" property="Validation.ErrorMessage" value="The column requires values of the datetime datatype." type="String" /><column name="MergeDate" property="Validation.ShowInput" value="True" type="Boolean" /><column name="MergeDate" property="Validation.ShowError" value="True" type="Boolean" /><column name="IsJunk" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="IsJunk" property="Address" value="$F$4" type="String" /><column name="IsJunk" property="ColumnWidth" value="8" type="Double" /><column name="IsJunk" property="Validation.Type" value="1" type="Double" /><column name="IsJunk" property="Validation.AlertStyle" value="1" type="Double" /><column name="IsJunk" property="Validation.Operator" value="1" type="Double" /><column name="IsJunk" property="Validation.Formula1" value="0" type="String" /><column name="IsJunk" property="Validation.Formula2" value="255" type="String" /><column name="IsJunk" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="IsJunk" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="IsJunk" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="IsJunk" property="Validation.ErrorMessage" value="The column requires values of the tinyint datatype." type="String" /><column name="IsJunk" property="Validation.ShowInput" value="True" type="Boolean" /><column name="IsJunk" property="Validation.ShowError" value="True" type="Boolean" /><column name="ContactID" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ContactID" property="Address" value="$G$4" type="String" /><column name="ContactID" property="ColumnWidth" value="11.14" type="Double" /><column name="ContactID" property="Validation.Type" value="1" type="Double" /><column name="ContactID" property="Validation.AlertStyle" value="1" type="Double" /><column name="ContactID" property="Validation.Operator" value="1" type="Double" /><column name="ContactID" property="Validation.Formula1" value="-2147483648" type="String" /><column name="ContactID" property="Validation.Formula2" value="2147483647" type="String" /><column name="ContactID" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="ContactID" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="ContactID" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="ContactID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" /><column name="ContactID" property="Validation.ShowInput" value="True" type="Boolean" /><column name="ContactID" property="Validation.ShowError" value="True" type="Boolean" /><column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceFirstName" property="Address" value="$H$4" type="String" /><column name="SourceFirstName" property="ColumnWidth" value="25.29" type="Double" /><column name="SourceFirstName" property="Validation.Type" value="6" type="Double" /><column name="SourceFirstName" property="Validation.AlertStyle" value="1" type="Double" /><column name="SourceFirstName" property="Validation.Operator" value="8" type="Double" /><column name="SourceFirstName" property="Validation.Formula1" value="255" type="String" /><column name="SourceFirstName" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="SourceFirstName" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="SourceFirstName" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="SourceFirstName" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="SourceFirstName" property="Validation.ShowInput" value="True" type="Boolean" /><column name="SourceFirstName" property="Validation.ShowError" value="True" type="Boolean" /><column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceLastName" property="Address" value="$I$4" type="String" /><column name="SourceLastName" property="ColumnWidth" value="17.43" type="Double" /><column name="SourceLastName" property="Validation.Type" value="6" type="Double" /><column name="SourceLastName" property="Validation.AlertStyle" value="1" type="Double" /><column name="SourceLastName" property="Validation.Operator" value="8" type="Double" /><column name="SourceLastName" property="Validation.Formula1" value="255" type="String" /><column name="SourceLastName" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="SourceLastName" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="SourceLastName" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="SourceLastName" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="SourceLastName" property="Validation.ShowInput" value="True" type="Boolean" /><column name="SourceLastName" property="Validation.ShowError" value="True" type="Boolean" /><column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceEmail" property="Address" value="$J$4" type="String" /><column name="SourceEmail" property="ColumnWidth" value="31.71" type="Double" /><column name="SourceEmail" property="Validation.Type" value="6" type="Double" /><column name="SourceEmail" property="Validation.AlertStyle" value="1" type="Double" /><column name="SourceEmail" property="Validation.Operator" value="8" type="Double" /><column name="SourceEmail" property="Validation.Formula1" value="255" type="String" /><column name="SourceEmail" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="SourceEmail" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="SourceEmail" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="SourceEmail" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="SourceEmail" property="Validation.ShowInput" value="True" type="Boolean" /><column name="SourceEmail" property="Validation.ShowError" value="True" type="Boolean" /><column name="SourceSecondaryEmail" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceSecondaryEmail" property="Address" value="$K$4" type="String" /><column name="SourceSecondaryEmail" property="ColumnWidth" value="23" type="Double" /><column name="SourceSecondaryEmail" property="Validation.Type" value="6" type="Double" /><column name="SourceSecondaryEmail" property="Validation.AlertStyle" value="1" type="Double" /><column name="SourceSecondaryEmail" property="Validation.Operator" value="8" type="Double" /><column name="SourceSecondaryEmail" property="Validation.Formula1" value="255" type="String" /><column name="SourceSecondaryEmail" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="SourceSecondaryEmail" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="SourceSecondaryEmail" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="SourceSecondaryEmail" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="SourceSecondaryEmail" property="Validation.ShowInput" value="True" type="Boolean" /><column name="SourceSecondaryEmail" property="Validation.ShowError" value="True" type="Boolean" /><column name="SourceMobile" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceMobile" property="Address" value="$L$4" type="String" /><column name="SourceMobile" property="ColumnWidth" value="17.29" type="Double" /><column name="SourceMobile" property="Validation.Type" value="6" type="Double" /><column name="SourceMobile" property="Validation.AlertStyle" value="1" type="Double" /><column name="SourceMobile" property="Validation.Operator" value="8" type="Double" /><column name="SourceMobile" property="Validation.Formula1" value="255" type="String" /><column name="SourceMobile" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="SourceMobile" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="SourceMobile" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="SourceMobile" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="SourceMobile" property="Validation.ShowInput" value="True" type="Boolean" /><column name="SourceMobile" property="Validation.ShowError" value="True" type="Boolean" /><column name="SourcePhone" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourcePhone" property="Address" value="$M$4" type="String" /><column name="SourcePhone" property="ColumnWidth" value="14.29" type="Double" /><column name="SourcePhone" property="Validation.Type" value="6" type="Double" /><column name="SourcePhone" property="Validation.AlertStyle" value="1" type="Double" /><column name="SourcePhone" property="Validation.Operator" value="8" type="Double" /><column name="SourcePhone" property="Validation.Formula1" value="255" type="String" /><column name="SourcePhone" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="SourcePhone" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="SourcePhone" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="SourcePhone" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="SourcePhone" property="Validation.ShowInput" value="True" type="Boolean" /><column name="SourcePhone" property="Validation.ShowError" value="True" type="Boolean" /><column name="SourceCompany" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceCompany" property="Address" value="$N$4" type="String" /><column name="SourceCompany" property="ColumnWidth" value="17.86" type="Double" /><column name="SourceCompany" property="Validation.Type" value="6" type="Double" /><column name="SourceCompany" property="Validation.AlertStyle" value="1" type="Double" /><column name="SourceCompany" property="Validation.Operator" value="8" type="Double" /><column name="SourceCompany" property="Validation.Formula1" value="255" type="String" /><column name="SourceCompany" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="SourceCompany" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="SourceCompany" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="SourceCompany" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="SourceCompany" property="Validation.ShowInput" value="True" type="Boolean" /><column name="SourceCompany" property="Validation.ShowError" value="True" type="Boolean" /><column name="SourceTitle" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceTitle" property="Address" value="$O$4" type="String" /><column name="SourceTitle" property="ColumnWidth" value="12.57" type="Double" /><column name="SourceTitle" property="Validation.Type" value="6" type="Double" /><column name="SourceTitle" property="Validation.AlertStyle" value="1" type="Double" /><column name="SourceTitle" property="Validation.Operator" value="8" type="Double" /><column name="SourceTitle" property="Validation.Formula1" value="255" type="String" /><column name="SourceTitle" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="SourceTitle" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="SourceTitle" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="SourceTitle" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="SourceTitle" property="Validation.ShowInput" value="True" type="Boolean" /><column name="SourceTitle" property="Validation.ShowError" value="True" type="Boolean" /><column name="SourceHeadline" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceHeadline" property="Address" value="$P$4" type="String" /><column name="SourceHeadline" property="ColumnWidth" value="16.71" type="Double" /><column name="SourceHeadline" property="Validation.Type" value="6" type="Double" /><column name="SourceHeadline" property="Validation.AlertStyle" value="1" type="Double" /><column name="SourceHeadline" property="Validation.Operator" value="8" type="Double" /><column name="SourceHeadline" property="Validation.Formula1" value="255" type="String" /><column name="SourceHeadline" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="SourceHeadline" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="SourceHeadline" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="SourceHeadline" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="SourceHeadline" property="Validation.ShowInput" value="True" type="Boolean" /><column name="SourceHeadline" property="Validation.ShowError" value="True" type="Boolean" /><column name="SourceIndustry" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceIndustry" property="Address" value="$Q$4" type="String" /><column name="SourceIndustry" property="ColumnWidth" value="16" type="Double" /><column name="SourceIndustry" property="Validation.Type" value="6" type="Double" /><column name="SourceIndustry" property="Validation.AlertStyle" value="1" type="Double" /><column name="SourceIndustry" property="Validation.Operator" value="8" type="Double" /><column name="SourceIndustry" property="Validation.Formula1" value="255" type="String" /><column name="SourceIndustry" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="SourceIndustry" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="SourceIndustry" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="SourceIndustry" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="SourceIndustry" property="Validation.ShowInput" value="True" type="Boolean" /><column name="SourceIndustry" property="Validation.ShowError" value="True" type="Boolean" /><column name="SourceLocationName" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceLocationName" property="Address" value="$R$4" type="String" /><column name="SourceLocationName" property="ColumnWidth" value="21.57" type="Double" /><column name="SourceLocationName" property="Validation.Type" value="6" type="Double" /><column name="SourceLocationName" property="Validation.AlertStyle" value="1" type="Double" /><column name="SourceLocationName" property="Validation.Operator" value="8" type="Double" /><column name="SourceLocationName" property="Validation.Formula1" value="255" type="String" /><column name="SourceLocationName" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="SourceLocationName" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="SourceLocationName" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="SourceLocationName" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="SourceLocationName" property="Validation.ShowInput" value="True" type="Boolean" /><column name="SourceLocationName" property="Validation.ShowError" value="True" type="Boolean" /><column name="SourceCountryCode" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceCountryCode" property="Address" value="$S$4" type="String" /><column name="SourceCountryCode" property="ColumnWidth" value="20.43" type="Double" /><column name="SourceCountryCode" property="Validation.Type" value="6" type="Double" /><column name="SourceCountryCode" property="Validation.AlertStyle" value="1" type="Double" /><column name="SourceCountryCode" property="Validation.Operator" value="8" type="Double" /><column name="SourceCountryCode" property="Validation.Formula1" value="2" type="String" /><column name="SourceCountryCode" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="SourceCountryCode" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="SourceCountryCode" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="SourceCountryCode" property="Validation.ErrorMessage" value="The column requires values of the char(2) datatype." type="String" /><column name="SourceCountryCode" property="Validation.ShowInput" value="True" type="Boolean" /><column name="SourceCountryCode" property="Validation.ShowError" value="True" type="Boolean" /><column name="SourceProfileUrl" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceProfileUrl" property="Address" value="$T$4" type="String" /><column name="SourceProfileUrl" property="ColumnWidth" value="17.43" type="Double" /><column name="SourceProfileUrl" property="Validation.Type" value="6" type="Double" /><column name="SourceProfileUrl" property="Validation.AlertStyle" value="1" type="Double" /><column name="SourceProfileUrl" property="Validation.Operator" value="8" type="Double" /><column name="SourceProfileUrl" property="Validation.Formula1" value="255" type="String" /><column name="SourceProfileUrl" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="SourceProfileUrl" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="SourceProfileUrl" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="SourceProfileUrl" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="SourceProfileUrl" property="Validation.ShowInput" value="True" type="Boolean" /><column name="SourceProfileUrl" property="Validation.ShowError" value="True" type="Boolean" /><column name="Source" property="FormatConditions(1).AppliesTo.Address" value="$C$4:$C$59" type="String" /><column name="Source" property="FormatConditions(1).Type" value="2" type="Double" /><column name="Source" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="Source" property="FormatConditions(1).Formula1" value="=ISBLANK(C4)" type="String" /><column name="Source" property="FormatConditions(1).Interior.Color" value="65535" type="Double" /><column name="Source" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" /><column name="SourceID" property="FormatConditions(1).AppliesTo.Address" value="$D$4:$D$59" type="String" /><column name="SourceID" property="FormatConditions(1).Type" value="2" type="Double" /><column name="SourceID" property="FormatConditions(1).Priority" value="2" type="Double" /><column name="SourceID" property="FormatConditions(1).Formula1" value="=ISBLANK(D4)" type="String" /><column name="SourceID" property="FormatConditions(1).Interior.Color" value="65535" type="Double" /><column name="SourceID" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="2" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="2" type="Double" /><column name="" property="PageSetup.PaperSize" value="1" type="Double" /><column name="" property="PageSetup.LeftMargin" value="22.6771653543307" type="Double" /><column name="" property="PageSetup.RightMargin" value="22.6771653543307" type="Double" /><column name="" property="PageSetup.TopMargin" value="25.511811023622" type="Double" /><column name="" property="PageSetup.BottomMargin" value="25.511811023622" type="Double" /><column name="" property="PageSetup.HeaderMargin" value="22.6771653543307" type="Double" /><column name="" property="PageSetup.FooterMargin" value="22.6771653543307" type="Double" /></columnFormats><views><view name="All"><column name="" property="ListObjectName" value="SourceContacts" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceID" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="MergeDate" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="IsJunk" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ContactID" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceSecondaryEmail" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceMobile" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourcePhone" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceCompany" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceTitle" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceHeadline" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceIndustry" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceLocationName" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceCountryCode" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceProfileUrl" property="EntireColumn.Hidden" value="False" type="Boolean" /></view><view name="Main Fields"><column name="" property="ListObjectName" value="SourceContacts" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="Source" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceID" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="MergeDate" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="IsJunk" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="ContactID" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceFirstName" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceLastName" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceEmail" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceSecondaryEmail" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceMobile" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourcePhone" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceCompany" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceTitle" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceHeadline" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceIndustry" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceLocationName" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceCountryCode" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SourceProfileUrl" property="EntireColumn.Hidden" value="False" type="Boolean" /></view></views></table>');
GO
-- print TableFormats have been inserted

-- print Social Contacts Application has been installed
